<?php

namespace App;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Session;

class CatalogueArticles extends Model
{

    protected $fillable = [
        'slug', 'name', 'price', 'is_panier', 'show_price', 'active', 'quantity', 'reference', 'private_key', 'description', 'on_sale', 'minimal_quantity', 'categorie_slug', 'user_slug', 'type_user', 'boutique_slug', 'stock', 'state', 'maker', 'maker_country', 'create', 'expire', 'corbeil', 'productor_slug', 'article_slug', 'is_coffret'
    ];

    public function categorie()
    {
        return $this->belongsTo('App\CategorieCatalogue', 'categorie_slug', 'slug');
    }

    /** get all article */

    public function boutique()
    {
        return $this->belongsTo('App\Boutique', 'boutique_slug', 'slug');
    }

    public function getArticles()
    {
        $boutique = Session::get('boutique');
        $articlesListe = DB::table('select_articles')->where('boutique_slug');
        $articles =  $this::all()->where('active', 1)->where('boutique_slug', $boutique['slug']);
        foreach ($articles as $article) {
            $categorie = CategorieCatalogue::all()->where('slug', $article->categorie_slug)->first();
            $article->categorie = $categorie;
        }

        return $articles;
    }

    public function caracteristique()
    {
        return $this->hasMany('App\CategorieCaracteristique', 'categorie_id', 'categorie_slug');
    }

    public function article_meta()
    {
        return $this->hasMany(ArticleMeta::class, 'article_slug', 'slug');
    }

    public function command_article_()
    {
        return $this->hasMany(CommandArticle::class, 'article_slug', 'slug');
    }

    public function promoArticles()
    {
        $boutique = Session::get('boutique');
        $articles =  $this::all()->where('on_sale', 1)->where('active', 1)->where('boutique_slug', $boutique['slug']);
        foreach ($articles as $article) {
            $categorie = CategorieCatalogue::all()->where('slug', $article->categorie_slug)->first();
            $article->categorie = $categorie;
        }
        return $articles;
    }

    public function wishlist_article()
    {
        return $this->hasMany('App\wishlist_article', 'boutique_slug', 'slug');
    }

    public function newsletter_article()
    {
        return $this->hasMany('App\NewslettersArticle', 'article_slug', 'slug');
    }

    public function images()
    {
        return $this->hasMany('App\Images', 'key', 'slug');
    }

    public function coffret()
    {
        return $this->hasMany('App\ArticleCoffret', 'id', 'coffret_id');
    }

    public function article_coffret()
    {
        return $this->hasMany('App\ArticleCoffret', 'id', 'article_id');
    }
}
