<?php

namespace App\Http\Controllers\Actualite;

use App\Actualite;
use App\Annonce;
use App\Boutique;
use App\Http\Controllers\MailController;
use App\PointVente;
use App\ProfileAnnonceur;
use App\User;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Str;
use Intervention\Image\Facades\Image;

class ActualiteController extends Controller
{
    public function index()
    {
        $actualites = Actualite::with("user")->where("user_id", Auth::id())->get();
        return view('dashboard.Actualite.index', compact("actualites"));
    }

    public function add_up(Request $request)
    {
        $data = $request->all();
        try {
            $rules = array(
                'titre' => 'required',
                'image' => isset($request->id)?'mimes:jpg,png,jpeg':'required:mimes:jpg,png,jpeg',
                'resume' => 'required|string',
                'contenu' => 'required|string',
            );

            $validator = \Illuminate\Support\Facades\Validator::make($request->all(), $rules);
            if ($validator->fails()) {
                return back()->withErrors($validator)->withInput();
            }
            unset($data["action"]);
            $data["user_id"]=Auth::id();
            if ($request->image){
                $time = time();
                $originalImage = $request->image;
                $thumbnailImage = Image::make($originalImage);
                $originalPath = public_path('Uploads/actualites/');
                $location = $originalPath . $time . $originalImage->getClientOriginalName();
                $thumbnailImage->save($originalPath . $time . $originalImage->getClientOriginalName());
                $filename = $time . $originalImage->getClientOriginalName();
                $data['image'] = asset('Uploads/actualites/' . $filename);
            }
            if (!isset($data['id'])) {
                $data['slug'] = "ac_".Annonce::generate_slug_for_table("actualites");
                $data['state'] = true;
                $return = Actualite::create($data);
                if (isset($return->id)) {
                    $emails=User::all()->pluck('email')->toArray();
                    $subject = Auth::user()['last_name'] . ' ' . Auth::user()['first_name'] . ' à ajouter une nouvelle actualité sur sungrocery.';
                    $messages = Str::limit($data['resume'], 250);
                    $msg=['msg'=>$messages,'route'=>route('actualite',$data['slug']),'image'=>$data['image']];
                    MailController::SendMultipleGeneralUniqueMail('Mail.generale_with_link_blade', $subject, $msg, $emails, env('MAIL_USERNAME'));

                    Session::flash('success', 'Votre article est désormais disponible');
                } else {
                    Session::flash('error', 'Un  problème est survenue au cours du processus de publication de l\'annonce ');
                }
            } else {
                unset($data["id"]);
                $return = Actualite::find($request->id)->update($data);
                if ($return) {
                    Session::flash('success', 'Votre article a été modifié sur grocery');
                } else {
                    Session::flash('error', 'Un  problème est survenue au cours du processus de modification de l\'annonce ');
                }
            }

        } catch (\Exception $e) {
            Session::flash('error', 'Un  problème est survenue au cours de l\'exécution du processus ' . $e);
        }
        return back();

    }

    public function visibility($slug)
    {
        try {

            $ac = Actualite::whereSlug($slug)->first();
            if ($ac) {
                $text = $ac->state?"désactivé":"activé";
                $ac->state = !$ac->state;
                $ac->save();
                Session::flash('success', 'Votre acticle a été '.$text.' sur grocery');
            } else {
                Session::flash('error', 'Un  problème est survenue au cours du processus de modification de l\'annonce ');
            }

        } catch (\Exception $e) {
            Session::flash('error', 'Un  problème est survenue au cours de l\'exécution du processus ' . $e);
        }
        return back();

    }

    public function get_actualite(Request $request){
        try {
            $annonce = Actualite::whereSlug($request->slug)->first();
            return ["data" => $annonce, "msg" => "data", "error" => false];
        } catch (\Exception $e) {
            return ["data" => null, "msg" => $e->getMessage(), "error" => true];
        }

    }

    public function delete_actualite($slug)
    {
        try {
            Actualite::whereSlug($slug)->delete();
            Session::flash('success', 'Votre actualite a été supprimé sur grocery');
        } catch (\Exception $e) {
            Session::flash('error', 'Un  problème est survenue au cours de l\'exécution du processus ' . $e);
        }
        return back();

    }

}
