<?php

namespace App\Http\Controllers\AdminMarketOptions;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\globalPromos;
use App\User;
use App\helpers\helper;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\DB;

class PromotionController extends Controller
{
    
    public function store(Request $request)
    {
        $data= $request->all();
        $rules = array(
            'type' => 'required|in:code,special,offer',
            'code' => 'nullable|string',
            'max_user' => 'nullable|integer',
            'percentage' => 'nullable|integer',
            'name' => 'required|string',
            'debut' => 'required|date',
            'fin' => 'required|date',
        );
        $validator = \Illuminate\Support\Facades\Validator::make($request->all(), $rules);
        if ($validator->fails()) {
            return back()->withErrors($validator)->withInput();
        }

        if(isset($request->image)){
            $helper= new helper();
            $image = $helper->saveFile($request->image,'promotions');
            if($image) $data['image'] = $image;
        }

        if(isset($data["slug"])){
            $code_promo = globalPromos::where("code",$data['code'])->where("slug",'<>',$data['slug'])->first();
            if ($code_promo==null) {
                unset($data['_token']);
                unset($data['action']);
                $promo = DB::table("global_promos")->where("slug",$data["slug"])->update($data);
                if($promo){
                    Session::flash('success', 'Le code promo a été mis à jour avec succès !');
                }else{
                    Session::flash('error', 'une erreure est survenue au cours du processus !');
                }
            }
        }else{
            $code_promo = globalPromos::where("code",$data['code'])->first();
            if ($code_promo==null) {
                   $data['slug']=strtolower("gl-promo-".str_random(5));
                    $promo = globalPromos::create($data);
                if($promo){
                    Session::flash('success', 'Le code promo a été créé !');
                }else{
                    Session::flash('error', 'une erreure est survenue au cours du processus !');
                }
            }else{
                Session::flash('error', 'Le code promo existe déjà. veuillez en créer un autre !');
            }
        }
        return back();
    }



    public function index()
    { 
           $promotions =  globalPromos::orderBy("id",'DESC')->get();
           return view('dashboard.Promotion.index', compact("promotions"));   
    } 
    
    public function get(Request $request)
    {
        try {
           $promos =  globalPromos::whereSlug($request->slug)->first();
            return ['data'=>$promos,'message'=>"Code promo recupérer avec succès !"];
        } catch (\Exception $e) {
            return ['data'=>[],'message'=>"Une erreure est survenue qu cours du processus ".$e->getMessage()];
        }
        
    } 
    
    public function visibility($slug)
    {
        try {

            $ac = globalPromos::whereSlug($slug)->first();
            if ($ac) {
                $text = $ac->active? 0 : 1;
                $ac->active = $text;
                $ac->save();
                Session::flash('success', 'Le statut Code promo a été mis à jour');
            } else {
                Session::flash('error', 'Un  problème est survenue au cours du processus de modification du statut du code promo ');
            }

        } catch (\Exception $e) {
            Session::flash('error', 'Un  problème est survenue au cours de l\'exécution du processus ' . $e);
        }
        return back();

    }

    public function delete($slug)
    {
        try {
            globalPromos::whereSlug($slug)->delete();
            Session::flash('success', 'La promotion a été supprimé avec succès');
        } catch (\Exception $e) {
            Session::flash('error', 'Un  problème est survenue au cours de l\'exécution du processus ' . $e);
        }
        return back();

    }
}
