<?php

namespace App\Http\Controllers\AdminMarketOptions;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\PanierRecettes;
use App\CatalogueArticles;
use App\User;
use App\helpers\helper;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\DB;

class panierRecetteController extends Controller
{
    public function store(Request $request)
    {
        $data= $request->all();
        $rules = array(
            'name' => 'required|string',
            'resume' => 'required|string',
            'price' => 'nullable|integer',
        );
        $validator = \Illuminate\Support\Facades\Validator::make($data, $rules);
        if ($validator->fails()) {
            return back()->withErrors($validator)->withInput();
        }

        if(isset($request->image)){
            $helper= new helper();
            $image = $helper->saveFile($request->image,'panier');
            if($image) $data['image'] = $image;
        }
        
        if(isset($data["slug"])){
            $recettes_data = PanierRecettes::where("name",$data['name'])->where("slug",'<>',$data['slug'])->first();
            if ($recettes_data==null) {
                unset($data['_token']);
                unset($data['action']);
                $promo = DB::table("panier_recettes")->where("slug",$data["slug"])->update($data);
                if($promo){
                    $datas =  CatalogueArticles::whereIn('slug',$request->produits)->pluck('price')->toArray();
                    $total=0;
                    for($i=0; $i < count($datas); $i++){
                        $req=["panier_recette_slug"=>$promo->slug,"product_slug"=>$request->produits[$i],"price"=>$datas[$i],"number"=>$request->qte[$i]];
                        DB::table("panier_recette_produits")->insert($req);
                        $total+=$datas[$i] * $request->qte[$i];
                    }
                    DB::table("panier_recettes")->where("slug",$data["slug"])->update(["price"=>$total]);
                    Session::flash('success', 'Le panier a été mis à jour avec succès !');
                }else{
                    Session::flash('error', 'une erreure est survenue au cours du processus !');
                }
            }
        }else{
            $recettes_data = PanierRecettes::where("name",$data['name'])->first();
            if ($recettes_data==null) {
                   $data['slug']=strtolower("panier-".str_random(5));
                    $promo = PanierRecettes::create($data);
                if($promo){
                    $datas =  CatalogueArticles::whereIn('slug',$request->produits)->pluck('price')->toArray();
                    $total=0;
                    for($i=0; $i < count($datas); $i++){
                        $req=["panier_recette_slug"=>$promo->slug,"product_slug"=>$request->produits[$i],"price"=>$datas[$i],"number"=>$request->qte[$i]];
                        DB::table("panier_recette_produits")->insert($req);
                        $total+=$datas[$i] * $request->qte[$i];
                    }
                    DB::table("panier_recettes")->where("slug",$data["slug"])->update(["price"=>$total]);
                    Session::flash('success', 'Le panier a été créé !');
                }else{
                    Session::flash('error', 'une erreure est survenue au cours du processus !');
                }
            }else{
                Session::flash('error', 'Le panier existe déjà. veuillez en créer un autre !');
            }
        }
        return back();
    }



    public function index()
    { 
           $produitLists=  CatalogueArticles::with("images")->where("state",1)->where("corbeil",false)->orderBy("id",'DESC')->get();
           $paniers=  PanierRecettes::with("produits")->orderBy("id",'DESC')->get();
           return view('dashboard.Panier.index', compact("paniers","produitLists"));   
    } 
    
    public function get(Request $request)
    {
        try {
           $promos =  PanierRecettes::with("produits")->whereSlug($request->slug)->first();
            return ['data'=>$promos,'message'=>"Panier recupérer avec succès !"];
        } catch (\Exception $e) {
            return ['data'=>[],'message'=>"Une erreure est survenue qu cours du processus ".$e->getMessage()];
        }
        
    } 
    public function getProduit(Request $request)
    {
        try {
           $paniers =  PanierRecetteProduits::where("panier_recette_slug",$request->slug)->pluck("product_slug")->toArray();
            $produitLists=  CatalogueArticles::with("images")->whereIn("slug",$paniers)->get();
            return ['data'=>$produitLists,'message'=>"Produit recupérer avec succès !","error"=>false];
        } catch (\Exception $e) {
            return ['data'=>[],'message'=>"Une erreure est survenue qu cours du processus ".$e->getMessage(),"error"=>false];
        }
        
    } 
    public function get_product_sum(Request $request)
    {
        try {
           $datas =  CatalogueArticles::whereIn('slug',$request->products)->pluck('price')->toArray();
           $total=0;
           for($i=0; $i < count($datas); $i++){
                $total+=$datas[$i] * $request->qtes[$i];
           }
            return ['data'=>$total,'products'=>$request->products,'qtes'=>$request->qtes,'message'=>"sum recuperer avec succès", "error"=> false];
        } catch (\Exception $e) {
            return ['data'=>[], "error"=> true,'message'=>"Une erreure est survenue qu cours du processus ".$e->getMessage()];
        }
        
    } 
    
    public function visibility($slug)
    {
        try {

            $ac = PanierRecettes::whereSlug($slug)->first();
            if ($ac) {
                $text = $ac->active? 0 : 1;
                $ac->active = $text;
                $ac->save();
                Session::flash('success', 'Le statut du panier a été mis à jour');
            } else {
                Session::flash('error', 'Un  problème est survenue au cours du processus de modification du statut du code promo ');
            }

        } catch (\Exception $e) {
            Session::flash('error', 'Un  problème est survenue au cours de l\'exécution du processus ' . $e);
        }
        return back();

    }

    public function delete($slug)
    {
        try {
            PanierRecettes::whereSlug($slug)->delete();
            Session::flash('success', 'Le panier a été supprimé avec succès');
        } catch (\Exception $e) {
            Session::flash('error', 'Un  problème est survenue au cours de l\'exécution du processus ' . $e);
        }
        return back();

    }
}
