<?php

namespace App\Http\Controllers\Annonce;

use App\Annonce;
use App\Http\Controllers\MailController;
use App\ProfileAnnonceur;
use App\User;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Str;

class AnnonceController extends Controller
{
    public function index()
    {
        $pays = DB::table('countries')->get();
        $annonces = Annonce::with("user", "metier", "pays")->where("user_id", Auth::id())->get();
        $profileAnnonceur = ProfileAnnonceur::where("user_id", Auth::id())->first();
        return view('dashboard.Annonce.index', compact("pays", "annonces","profileAnnonceur"));
    }

    public function add_up(Request $request)
    {
        $data = $request->all();
        try {
            $rules = array(
                'type' => 'required',
                'sector' => 'required',
                'title' => 'required|string|max:255',
                'country' => 'required|string',
                'description' => 'required|string',
                'couverture' => 'required|string',
            );

            $validator = \Illuminate\Support\Facades\Validator::make($request->all(), $rules);
            if ($validator->fails()) {
                return back()->withErrors($validator)->withInput();
            }
            unset($data["action"]);
            if (!isset($data['id'])) {
                $data['slug'] = Annonce::generate_slug_for_table("annonces");
                $data["user_id"] = Auth::id();
                $return = Annonce::create($data);
                if (isset($return->id)) {
                    $emails=User::all()->pluck('email')->toArray();
                    $subject = Auth::user()['last_name'] . ' ' . Auth::user()['first_name'] . ' à ajouter une nouvelle annonce sur sungrocery.';
                    $messages = Str::limit($data['description'], 250);
                    $msg=['msg'=>$messages,'route'=>route('annonce',$data['slug'])];
                         MailController::SendMultipleGeneralUniqueMail('Mail.generale_with_link_blade', $subject, $msg, $emails, env('MAIL_USERNAME'));

                    Session::flash('success', 'Votre annonce a été publié sur grocery');
                } else {
                    Session::flash('error', 'Un  problème est survenue au cours du processus de publication de l\'annonce ');
                }
            } else {
                unset($data["id"]);
                $return = Annonce::find($request->id)->update($data);
                if ($return) {
                    Session::flash('success', 'Votre annonce a été modifié sur grocery');
                } else {
                    Session::flash('error', 'Un  problème est survenue au cours du processus de modification de l\'annonce ');
                }
            }

        } catch (\Exception $e) {
            Session::flash('error', 'Un  problème est survenue au cours de l\'exécution du processus ' . $e);
        }
        return back();

    }

    public function get_annonce(Request $request)
    {
        try {
            $annonce = Annonce::whereSlug($request->slug)->first();
            return ["data" => $annonce, "msg" => "data", "error" => false];
        } catch (\Exception $e) {
            return ["data" => null, "msg" => $e->getMessage(), "error" => true];
        }

    }


    public function delete_annonce($slug)
    {
        try {
            Annonce::whereSlug($slug)->delete();
            Session::flash('success', 'Votre annonce a été supprimé sur grocery');
        } catch (\Exception $e) {
            Session::flash('error', 'Un  problème est survenue au cours de l\'exécution du processus ' . $e);
        }
        return back();

    }

    public function annonceur_update(Request $request)
    {
        try {
            $data = $request->all();
            $profileAnnonceur = ProfileAnnonceur::where("user_id", Auth::id())->first();
            if ($profileAnnonceur) {
                $profileAnnonceur->update($data);
            } else {
                $data["user_id"] = Auth::id();
                ProfileAnnonceur::create($data);
            }
            Session::flash('success', 'Votre profile annonceur a été mise à jour');

        } catch (\Exception $e) {
            Session::flash('error', 'Un  problème est survenue au cours de l\'exécution du processus ' . $e);
        }
        return back();
    }


    public function visibility($slug)
    {
        try {

            $annonce = Annonce::whereSlug($slug)->first();
            if ($annonce) {
                $text = $annonce->state?"cloturée":"activé";
                $annonce->state = !$annonce->state;
                $annonce->save();
                Session::flash('success', 'Votre annoce a été '.$text.' sur grocery');
            } else {
                Session::flash('error', 'Un  problème est survenue au cours du processus de modification de l\'annonce ');
            }

        } catch (\Exception $e) {
            Session::flash('error', 'Un  problème est survenue au cours de l\'exécution du processus ' . $e);
        }
        return back();

    }


}
