<?php

namespace App\Http\Controllers;

use App\User;
use App\Retrait;
use App\Boutique;
use App\Enseigne;
use App\Commandes;
use Carbon\Carbon;
use App\BoutiqueMeta;
use App\Portefeuille;
use App\ProductImage;
use App\adminRetraits;
use Mockery\Exception;
use App\check_products;
use App\EtatAbonnement;
use App\check_boutiques;
use App\MessageBoutiques;
use App\wishlist_article;
use App\AbonnementPaiment;
use App\CatalogueArticles;
use App\NewslettersGlobal;
use App\wishlist_boutique;
use App\adminPortefeuilles;
use App\BoutiqueAbonnement;
use Illuminate\Support\Str;
use Illuminate\Http\Request;
use App\EtatCatalogueAbonnement;
use App\ReponseMessageBoutiques;
use Illuminate\Support\Collection;
use Illuminate\Support\Facades\DB;
use App\Demande_supression_boutique;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Input;
use Illuminate\Support\Facades\Session;
use \Cartalyst\Sentinel\Laravel\Facades\Sentinel;

class HomeController extends Controller
{

    public function __construct()
    {
        $this->middleware('auth');
        if(Auth::check()) {
            if (Auth::user()->country == null && Auth::user()->continent == null) {
                if (!Session::has('country')) {
                    $ip = $this->getVisIpAddr();
                    try {
                        $json = file_get_contents('https://freegeoip.app/json/' . $ip);
                        $data = json_decode($json, true);
                        $country = $data['country_name'];
                        $city = $data['city'];
                        $continent = explode('/', $data['time_zone'])[0];
                        $currency = '';
                        Session::put(['country' => $country, 'city' => $city, 'continent' => $continent, 'currency' => $currency]);
                    } catch (\Exception $e) {
                        if (Auth::check()) {
                            $user = Auth::user();
                            if (isset($user)) {
                                Session::put(['country' => $user->country, 'region' => $user->region, 'city' => $user->city, 'continent' => $user->continent]);
                            }
                        }
                    }
                }
            } else {
                $user = Auth::user();
                if (isset($user)) {
                    Session::put(['country' => $user->country, 'region' => $user->region, 'city' => $user->city, 'continent' => $user->continent]);
                }
            }
        }else{
            if (!Session::has('country')) {
                $ip = $this->getVisIpAddr();
                try {
                    $json = file_get_contents('https://freegeoip.app/json/' . $ip);
                    $data = json_decode($json, true);
                    $country = $data['country_name'];
                    $city = $data['city'];
                    $continent = explode('/', $data['time_zone'])[0];
                    $currency = '';
                    Session::put(['country' => $country, 'city' => $city, 'continent' => $continent, 'currency' => $currency]);
                } catch (\Exception $e) {

                }
            }
        }

    }

    function getVisIpAddr() {

        if (!empty($_SERVER['HTTP_CLIENT_IP'])) {
            return $_SERVER['HTTP_CLIENT_IP'];
        }
        else if (!empty($_SERVER['HTTP_X_FORWARDED_FOR'])) {
            return $_SERVER['HTTP_X_FORWARDED_FOR'];
        }
        else {
            return $_SERVER['REMOTE_ADDR'];
        }
    }

    public function adminMakeretrait(Request $request)
    {
        $data = $request->all();
        $rules = array(
            'montant' => 'required|integer',
            'password' => 'required|string',
            'motif' => 'required|string',
            'devise' => 'required|string',
        );
        $validator = \Illuminate\Support\Facades\Validator::make($request->all(), $rules);
        if ($validator->fails()) {
            return back()->with('error',$validator->getMessageBag()->first());
        }
        $user = Auth::user();
        if (Hash::check($data['password'], $user->password)) {

            $portefeuille_check=adminPortefeuilles::where('devise',$data['devise'])->first();
            if($portefeuille_check!=null) {
                $portefeuille = adminPortefeuilles::findOrFail($portefeuille_check['id']);
                if((double)$portefeuille->montant >= (double)$data['montant']) {
                    $portefeuille->montant = (double)$portefeuille->montant - (double)$data['montant'];
                    $portefeuille->save();
                    unset($data['_token']);
                    unset($data['password']);
                    $data['created_at'] = Carbon::now();
                    $data['updated_at'] = Carbon::now();
                    DB::table('admin_retraits')->insert($data);
                }else{
                    return back()->with('error', 'Fond insuffisant! Votre solde actuelle  est = '.(double)$data['montant']);
                }
            }else{
                return back()->with('error', 'Vous ne pouvez pas faire un retrait sur cette devise. Cette devise n\'a pas de fond suffisant.');
            }
            return back()->with('success', 'Retrait notifiez avec succès');
        }else{
            return back()->with('error', 'Une erreur s\'est produite.');
        }
    }

public function adminRetraitNotification(){
       $retraits= adminRetraits::all();
       $total= adminRetraits::all()->groupBy('devise')->map(function ($item) {
           return $item->sum('montant');
       });
       $portefeuilles=adminPortefeuilles::all()->groupBy('devise')->map(function ($item) {
           return $item->sum('montant');
       });
        return view('dashboard/Boutique/admin_retraits',compact('retraits','total','portefeuilles'));
}

public function adminPaiementList(){
       $abonnements= AbonnementPaiment::with('user')->get();
       $total= AbonnementPaiment::all()->groupBy('devise')->map(function ($item) {
           return $item->sum('montant');
       });
       $portefeuilles=adminPortefeuilles::all()->groupBy('devise')->map(function ($item) {
           return $item->sum('montant');
       });
        return view('dashboard/Boutique/admin_paiement',compact('abonnements','total','portefeuilles'));
}

    public function internationalize($slug){
        $check= BoutiqueMeta::where('boutique_id',$slug)->first();
        $boutique= BoutiqueMeta::findOrFail($slug);
        if(isset($check) && $check!=null){
            $metas= BoutiqueMeta::findOrFail($check['id']);
            !$metas->internationalize ? $metas->internationalize=true :  $metas->internationalize=false;
            !$metas->internationalize ? $name= 'désactivé' :  $name='activé';
            $metas->save();
            try{
                $subject = 'ACTIVATION DE LA VISIBILITE INTERNATIONAL DE  '.$boutique->nom_boutique;
                $messages='Félicitation, votre boutique '.$boutique->nom_boutique.' peut être visible à l\'international. Accéder à vos paramètres de gestion pour finaliser l\'activation.';
                MailController::SendGeneralUniqueMail('Mail.generale_blade',$subject, $messages, $boutique->user->email,env('MAIL_USERNAME'));
            }catch (\Exception $e){

            }
            Session::flash('success','Vous avez '.$name.' la visibilité international pour la boutique '.$boutique->nom_boutique);
        }else{
            Session::flash('error','Une erreure est survenue');
        }
        return back();
    }

    public function allAbonnementBoutique(){
        $abonnements=BoutiqueAbonnement::with('boutique','etat_abonnement')
            ->has("boutique")->get();
        return view('dashboard.Boutique.Abonnement.boutiqueAbonnees',compact('abonnements'));
    }

    public function abonnementBoutique(){
        $abonnements=EtatAbonnement::get();
        return view('dashboard.Boutique.Abonnement.optionsAbonnement',compact('abonnements'));
    }

    public function abonnementCatalogue(){
        $abonnements=EtatCatalogueAbonnement::get();
        return view('dashboard.Boutique.Abonnement.optionsCatalogueAbonnement',compact('abonnements'));
    }
    
    public function getAbonnementData($slug){
        $abonnement=EtatAbonnement::where('slug',$slug)->first();
        return json_encode($abonnement);
    }

    public function getAbonnementCatalogueData($slug){
        $abonnement=EtatCatalogueAbonnement::where('slug',$slug)->first();
        return json_encode($abonnement);
    }

    public function deleteAbonnement($slug){
        $checkAbonnemt=EtatAbonnement::where('slug',$slug)->first();
        if($checkAbonnemt!=null) {
            $abonnement = EtatAbonnement::findOrFail($checkAbonnemt['id']);
            $abonnement->corbeil=true;
            $abonnement->save();
        }
        return back()->with('sucess','Cet abonnement n\'est plus disponible');
    }

    public function deleteAbonnementCatalogue($slug){
        $checkAbonnemt=EtatCatalogueAbonnement::where('slug',$slug)->first();
        if($checkAbonnemt!=null) {
            $abonnement = EtatCatalogueAbonnement::findOrFail($checkAbonnemt['id']);
            $abonnement->corbeil=true;
            $abonnement->save();
        }
        return back()->with('sucess','Cet abonnement n\'est plus disponible');
    }

    public function create_abonnement_boutique(Request $request){
        $data=$request->all();
        $rules = array(
            'name' => 'required|string|max:255',
            'numberMonth' => 'required|integer',
            'price' => 'required|integer',
        );
        $validator = \Illuminate\Support\Facades\Validator::make($request->all(), $rules);
        if ($validator->fails()) {
            return back()->withErrors($validator)->withInput();
        }
        $data['slug']=Str::slug(time().'abonnement');
        $response=EtatAbonnement::create($data)->id;
        if($response!=null){
            Session::flash('success','Abonnement créer avec succès');
        }else{
            Session::flash('error','Echec d\'enregistrement de l\'abonnement');
        }
        return back();
    }

    public function create_abonnement_catalogue(Request $request){
        $data=$request->all();
        $rules = array(
            'name' => 'required|string|max:255',
            'numberPublication' => 'required|integer',
            'price' => 'required|integer',
        );
        $validator = \Illuminate\Support\Facades\Validator::make($request->all(), $rules);
        if ($validator->fails()) {
            return back()->withErrors($validator)->withInput();
        }
        $data['slug']=Str::slug(time().'abonnement');
        $response=EtatCatalogueAbonnement::create($data)->id;
        if($response!=null){
            Session::flash('success','Abonnement créer avec succès');
        }else{
            Session::flash('error','Echec d\'enregistrement de l\'abonnement');
        }
        return back();
    }

    public function update_abonnement_boutique(Request $request){
        $data=$request->all();
        $rules = array(
            'name' => 'required|string|max:255',
            'numberMonth' => 'required|integer',
            'price' => 'required|integer',
        );
        $validator = \Illuminate\Support\Facades\Validator::make($request->all(), $rules);
        if ($validator->fails()) {
            return back()->withErrors($validator)->withInput();
        }
        $checkAbonnemt=  EtatAbonnement::where('slug',$data['slug'])->first();
        if($checkAbonnemt!=null) {
            $abonnement = EtatAbonnement::findOrFail($checkAbonnemt['id']);
            $abonnement->name=$data['name'];
            $abonnement->price=$data['price'];
            $abonnement->description=$data['description'];
            $abonnement->numberMonth=$data['numberMonth'];
            $abonnement->save();
            Session::flash('sucess','Mise à jour effectué avec succès !');
        }else{
            Session::flash('error','Une erreur s\'est produite. Veuillez reéssayer la mise à jour.');
        }
        return back();
    }
    public function update_abonnement_catalogue(Request $request){
        $data=$request->all();
        $rules = array(
            'name' => 'required|string|max:255',
            'numberPublication' => 'required|integer',
            'price' => 'required|integer',
        );
        $validator = \Illuminate\Support\Facades\Validator::make($request->all(), $rules);
        if ($validator->fails()) {
            return back()->withErrors($validator)->withInput();
        }
        $checkAbonnemt=  EtatCatalogueAbonnement::where('slug',$data['slug'])->first();
        if($checkAbonnemt!=null) {
            $abonnement = EtatCatalogueAbonnement::findOrFail($checkAbonnemt['id']);
            $abonnement->name=$data['name'];
            $abonnement->price=$data['price'];
            $abonnement->description=$data['description'];
            $abonnement->numberPublication=$data['numberPublication'];
            $abonnement->save();
            Session::flash('sucess','Mise à jour effectué avec succès !');
        }else{
            Session::flash('error','Une erreur s\'est produite. Veuillez reéssayer la mise à jour.');
        }
        return back();
    }
    

    public function all_abonne(){
        $abonnes=NewslettersGlobal::orderBy('id','DESC')->get();
        return view('dashboard.abonnee',compact('abonnes'));
    }

    public function  portefeuille_admin (){
        $portefeuilles= Portefeuille::with(['user','user.boutique'=>function($q){
            $q->where('corbeil',false);
        }])->orderBy('id','DESC')->get();
        return view('dashboard.user_portefeuille_list',compact('portefeuilles'));
    }

    public function supprimer_boutique($slug){
        $boutique=Boutique::where('slug',$slug)->first()['id'];
        $boutique=Boutique::findOrFail($boutique);
        $boutique->corbeil=true;
        $boutique->save();
        return back()->with('success','Boutique supprimer avec succès');
    }

    public function demande_supression_boutique_admin(){
        $boutiques=Demande_supression_boutique::with('boutique')->orderBy('id','DESC')->get();
        return view('dashboard.demande_supression',compact('boutiques'));

    }


    public function adminrenewAbonnement(Request $request){
        $data=$request->all();
        try {
            $abonnement = EtatAbonnement::where('slug', $data['abonnement_slug'])->first();

            if($data['boutique_slug']=='all'){
                $boutiques=Boutique::where('corbeil',false)->where('installer',true)->get();
                foreach ($boutiques as $boutique){
                    $boutique = Boutique::where('slug', $boutique->slug)->first();
                    $data['slug'] = Str::slug(time() . 'boutique' . time() . 'abonnement');
                    $data['boutique_id'] = $boutique['id'];
                    $data['etat_abonnement_id'] = $abonnement['id'];
                    $data['expired'] = false;
                    DB::table('boutique_abonnements')->where('boutique_id', $boutique['id'])->where('etat_abonnement_id', $abonnement['id'])->update(['expired' => false]);
                    $boutique['expired']
                        ? $expireBoutique = \Illuminate\Support\Carbon::now()->format('M d Y H:i:s')
                        : $expireBoutique = Carbon::create($boutique['expired_to'])->format('M d Y H:i:s');
                    $user = Session::get('user');
                    $expired_to = strtotime("+" . $abonnement['numberMonth'] . " months", strtotime($expireBoutique));
                    $myShop = Boutique::findOrFail($boutique['id']);
                    $myShop->expired_to = Carbon::createFromFormat('Y-m-d H:i:s', date('Y-m-d H:i:s', $expired_to));
                    $myShop->expired = false;
                    $myShop->adminActivatePaiement = $user['id'];
                    $myShop->save();
                    $data['expired_at'] = $myShop->expired_to;
                    BoutiqueAbonnement::create($data);
                }
                $status = 'success';
                $message = 'Toutes les boutiques bénéficient d\'un abonnement de  ' . $abonnement['numberMonth'] . ' mois supplémentaires d\'accès à notre espace de vente.';
            }else {
                $boutique = Boutique::where('slug', $data['boutique_slug'])->first();
                $data['slug'] = Str::slug(time() . 'boutique' . time() . 'abonnement');
                $data['boutique_id'] = $boutique['id'];
                $data['etat_abonnement_id'] = $abonnement['id'];
                $data['expired'] = false;
                DB::table('boutique_abonnements')->where('boutique_id', $boutique['id'])->where('etat_abonnement_id', $abonnement['id'])->update(['expired' => false]);
                $boutique['expired']
                    ? $expireBoutique = \Illuminate\Support\Carbon::now()->format('M d Y H:i:s')
                    : $expireBoutique = Carbon::create($boutique['expired_to'])->format('M d Y H:i:s');
                $user = Session::get('user');
                $expired_to = strtotime("+" . $abonnement['numberMonth'] . " months", strtotime($expireBoutique));
                $myShop = Boutique::findOrFail($boutique['id']);
                $myShop->expired_to = Carbon::createFromFormat('Y-m-d H:i:s', date('Y-m-d H:i:s', $expired_to));
                $myShop->expired = false;
                $myShop->adminActivatePaiement = $user['id'];
                $myShop->save();
                $data['expired_at'] = $myShop->expired_to;
                BoutiqueAbonnement::create($data);
                $status = 'success';
                $boutique['expired']
                    ?
                    $message = 'Abonnement activé pour ' . $abonnement['numberMonth'] . ' mois.'
                    :
                    $message = 'L\'abonnement de cette boutique à été mis à jour avec succès. Cette boutique bénéficie de ' . $abonnement['numberMonth'] . ' mois supplémentaire d\'accès à notre espace de vente.';
            }
            return json_encode(['response' => $status, 'message' => $message]);
        }catch (\Exception $e){
            return json_encode(['response' => 'error', 'message' => $e->getMessage()]);
        }
    }


    public function delete_message($slug){
        $message=  MessageBoutiques::where('slug',$slug)->first();
        $msg=MessageBoutiques::findOrfail($message->id);
        $msg->corbeil=true;
        $msg->save();
        Session::flash('success', 'Message supprimé avec succès.');
        return back();
    }

    public function user_doc_validate($slug){
        $find_user=User::where('slug',$slug)->first();
        if($find_user!=null){
            $user=User::findOrFail($find_user['id']);
            if($user->doc_validated){
                $user->doc_validated=false;
                $user->cni=null;
                $user->cnir=null;
                $user->cniv=null;
                Session::flash('success','Document de l\'utilisateur '.$user->first_name.' '.$user->last_name.' invalider');
            }else{
                $user->doc_validated=true;
                Session::flash('success','Document de l\'utilisateur '.$user->first_name.' '.$user->last_name.' valider');
            }
            $user->save();
        }else{
            Session::flash('error','Utilisateur introuvable');
        }
        return back();
    }

    public function list_user(){
        $users=User::with("code_promo")->orderBy('id','DESC')->get();
        return view('dashboard.users',compact('users'));
    }

    public function message_response(Request $request){
        $data=$request->all();
        $rules = array(
            'name' => 'required|string|max:255',
            'email' => 'required|string|max:255',
            'message' => 'required',
        );
        $validator = \Illuminate\Support\Facades\Validator::make($request->all(), $rules);
        if ($validator->fails()) {
            return back()->withErrors($validator)->withInput();
        }
        $message=  ReponseMessageBoutiques::create($data)->id;
        if(isset($message)) {
            Session::flash('success', 'Votre message à été transmis au client ' .$data['name']);
            $message=MessageBoutiques::where('slug',$data['message_boutique_slug'])->first();
            $boutique=Boutique::where('slug',$message->boutique_slug)->first();
            $metas = BoutiqueMeta::all()->where('boutique_id',$boutique['id'])->first();
            $logo=$metas->logo_boutique;
            $mail=$metas->email_boutique;
            $telephone=$metas->telephone_boutique;
            $subject = $boutique['nom_boutique'].' vous a repondu à votre message du '.$message['created_at']->format('d-m-Y à H:i');
            $messages = ['name'=>$message['name'],'nom_boutique'=>$boutique['nom_boutique'],'message'=>$data['message'],'old_message'=>$message['message'],'logo'=>$logo,'email'=>$mail,'telephone'=>$telephone];
            MailController::SendGeneralUniqueMail('Mail.reponse_contact_client',$subject, $messages, $message['email'],env('MAIL_USERNAME'));


        }else{
            Session::flash('error', 'Nous ne parvenons pas à transmettre votre message au client ' .$data['name'].', veuillez reéssayer.');
        }
        return back();
    }

    public function liste_contact(){
        $boutique=  Session::get('boutique')['slug'];
        $messages=MessageBoutiques::with('reponse_message_boutiques')->where('boutique_slug',$boutique)->where('corbeil',false)->get();
        DB::table('message_boutiques')->where('check',false)->update(['check'=>true]);
        return \view('dashboard.Boutique.message_boutique',compact('messages'));
    }

    public function chart_vente($startDate,$endDate){
        $user=Session::get('user')['slug'];
        $user_id =Session::get('user')['id'];
        $privilegecheck=new \App\Users_controle();
        $check_privilege=$privilegecheck->has_privilege($user_id,'super_administrateur');
        if($check_privilege) {
            $boutique_all_slug = Boutique::pluck('slug')->toArray();

        }else{
            $boutique_all_slug = Boutique::where('user_slug', Session::get('user')['slug'])->pluck('slug')->toArray();
        }
        $commandes = Commandes::whereIn('boutique_slug',$boutique_all_slug)->where('statut_paiement',true)->whereBetween('created_at',array($startDate,$endDate))->orderBy('created_at', 'ASC')->get()
            ->groupBy(function($val) {
                return Carbon::parse($val->created_at)->format('m');
            });
        $comandes_tot=[];
        $i=0;
        foreach ($commandes as $commande){
            $price=0;
            foreach ($commande as $cmd){
                $comandes_tot['month'][$i]=Carbon::parse($cmd->created_at)->format('M - Y');
                $price+=$cmd->total_price;
            }
            $comandes_tot['price'][$i]=$price;
            $i++;
        }
        return $comandes_tot;
    }


    public function chart_achat($startDate,$endDate){
        $user=Session::get('user')['slug'];
        $user_id =Session::get('user')['id'];
        $privilegecheck=new \App\Users_controle();
        $check_privilege=$privilegecheck->has_privilege($user_id,'super_administrateur');
        if($check_privilege) {
            $commandes = Commandes::where('statut_paiement',true)->whereBetween('created_at',array($startDate,$endDate))->orderBy('created_at', 'ASC')->get()
                ->groupBy(function($val) {
                    return Carbon::parse($val->created_at)->format('m');
                });
        }else{
            $commandes = Commandes::where('user_slug',$user)->where('statut_paiement',true)->whereBetween('created_at',array($startDate,$endDate))->orderBy('created_at', 'ASC')->get()
                ->groupBy(function($val) {
                    return Carbon::parse($val->created_at)->format('m');
                });
        }

        $comandes_tot=[];
        $i=0;
        foreach ($commandes as $commande){
            $price=0;
            foreach ($commande as $cmd){
                $comandes_tot['month'][$i]=Carbon::parse($cmd->created_at)->format('M - Y');
                $price+=$cmd->total_price;
            }
            $comandes_tot['price'][$i]=$price;
            $i++;
        }
        return $comandes_tot;
    }

    public function chart_vente_single($boutique){
        $commandes = Commandes::where('boutique_slug',$boutique)->where('statut_paiement',true)->orderBy('created_at', 'ASC')->get()
            ->groupBy(function($val) {
                return Carbon::parse($val->created_at)->format('m');
            });
        $comandes_tot=[];
        $i=0;
        foreach ($commandes as $commande){
            $price=0;
            foreach ($commande as $cmd){
                $comandes_tot['month'][$i]=''.Carbon::parse($cmd->created_at)->format('M - Y');
                $price+=$cmd->total_price;
            }
            $comandes_tot['price'][$i]=$price;
            $i++;
        }
        return $comandes_tot;
    }

    public function totalActif(Request $request){
        $data=$request->all();
        $slug= Session::get('user')['slug'];
        $total=0;
        if(isset($data['slug'])){
            $commandes = Commandes::where('boutique_slug',$data['slug'])->where('statut_paiement',true)->where('corbeil',false)->get();
            foreach($commandes as $cmd) {
                $total += $cmd->total_price;
            }
        }else{
            $portefeuille=Portefeuille::where('user_slug',$slug)->first();
            if(isset($portefeuille->id)) {
                $total = $portefeuille['montant'];
                if ($total == null) {
                    $total = 0;
                }
            }
        }
        return json_encode($total);
    }

    public function demanderetraitvalidate(Request $request){
        $data=$request->all();
        $slug=$data['slug'];
        $fslug=Retrait::where('slug',$slug)->first();
        $retrait=Retrait::findOrfail($fslug['id']);
        $retrait->status_demande=true;
        $retrait->date_validate=\Illuminate\Support\Carbon::now();
        $retrait->save();
        if($retrait->moyen_paiement=='mobile_money'){
            $numero=$retrait->numero;
        }else{
            $numero=$retrait->compte_bancaire;
        }
        $user=User::where('slug',$retrait->user_slug)->first();
        $subject = 'Compte crédité';
        $messages = ['first_name'=>$user['first_name'],'last_name'=>$user['last_name'],'numero'=>$numero,'compte'=>$retrait->moyen_paiement,'montant'=>$retrait->montant];
        MailController::SendGeneralUniqueMail('Mail.retrait_valid',$subject, $messages, $user['email'],env('MAIL_USERNAME'));

        return json_encode(true);
    }
    public function retraitvalidate(Request $request){
        $data=$request->all();
        $slug=$data['slug'];
        $fslug=Retrait::where('slug',$slug)->first();
        $retrait=Retrait::findOrfail($fslug['id']);
        $retrait->status_retrait=true;
        $retrait->date_validate=\Illuminate\Support\Carbon::now();
        $retrait->save();
        $fportefeuille=Portefeuille::where('user_slug',$retrait->user_slug)->first()['id'];
        $portefeuille = Portefeuille::findOrFail($fportefeuille);
        $portefeuille->montant = $portefeuille->montant - $retrait->montant;
        $portefeuille->save();

        if($retrait->moyen_paiement=='mobile money'){
            $numero=$retrait->numero;
        }else{
            $numero=$retrait->compte_bancaire;
        }
        $user=User::where('slug',$retrait->user_slug)->first();
        $subject = 'Demande de retrait approuvée';
        $messages = ['first_name'=>$user['first_name'],'last_name'=>$user['last_name'],'numero'=>$numero,'compte'=>$retrait->moyen_paiement,'montant'=>$retrait->montant];
        MailController::SendGeneralUniqueMail('Mail.retrait_valid_make',$subject, $messages, $user['email'],env('MAIL_USERNAME'));
        return json_encode(true);
    }

    public function retrait_index(){
        $retrait=Retrait::where('status_retrait',true)->pluck('montant')->toArray();
        $total_retrait=0;
        if(count($retrait)>0) {
            $total_retrait = array_sum($retrait);
        }
        $retraits=Retrait::with('user','admin','user.boutique')->orderBy('updated_at','DESC')->get();
        return view('dashboard.Boutique.retrait_admin',compact('retraits','total_retrait'));
    }

    public function list_retrait_user(){
        $retrait=Retrait::where('user_slug',Session::get('user')['slug'])->where('status_retrait',true)->pluck('montant')->toArray();
        $total_retrait=0;
        if(count($retrait)>0) {
            $total_retrait = array_sum($retrait);
        }

        $portefeuilles=Portefeuille::where('user_slug',Session::get('user')['slug'])->get();
        $retraits=Retrait::where('user_slug',Session::get('user')['slug'])->orderBy('updated_at','DESC')->get();
        return view('dashboard.Boutique.retrait',compact('retraits','total_retrait','portefeuilles'));
    }

    public function makedemande_retrait(Request $request)
    {
        $data = $request->all();
        $rules = array(
            'montant' => 'required|integer',
            'password' => 'required|string',
            'devise' => 'required|string',
        );
        $validator = \Illuminate\Support\Facades\Validator::make($request->all(), $rules);
        if ($validator->fails()) {
            return ['error'=>true,'message'=>$validator->getMessageBag()->first()];
        }
        $credentials = [
            'email'=>Session::get('user')['email'],
        ];

        $user = Auth::user();
        if(Hash::check($data['password'],$user->password)) {
            // si l'utilisateur à choisis un retrait par retrait
            if(isset($data['numero']) && $data['numero']!= null && $data['numero']!='' && $data['moyen_paiement']=='mobile_money') {
                $data['numero'] = $data['full_number'];
                $data['compte_bancaire'] = null;
                $numero=$data['full_number'];
                $compte='mobile money';
            }else
                //si l'utilisateur à choisis un compte bancaire
                if(isset($data['compte_bancaire']) && $data['compte_bancaire']!=null && $data['compte_bancaire']!=''  && $data['moyen_paiement']=='compate_bancaire'){
                    $data['numero'] = null;
                    $numero=$data['compte_bancaire'];
                    $compte='compte bancaire';
                }
            //si l'utilisateur à choisis un compte bancaire
            if(isset($data['paypal']) && $data['paypal']!=null && $data['paypal']!='' &&   $data['moyen_paiement']=='paypal'){
                $data['numero'] = null;
                $numero=$data['paypal'];
                $compte='paypal';
            }
            $data['compte_bancaire']=$numero;
            $data['moyen_paiement']=$compte;
            $data['slug'] = Str::slug(time() . 'retrait' . time());
            $data['user_slug'] = $user->slug;
            $data['status_demande'] = false;
            $data['status_retrait'] = false;
            Retrait::create($data);

            try {
                //Envoyer un email au client pour la demande de retrait
                $subject = 'Demande de retrait en cours d\'évaluation';
                $messages = ['first_name' => $user->first_name, 'last_name' => $user->last_name, 'numero' => $numero, 'compte' => $compte, 'montant' => $data['montant']];
                MailController::SendGeneralUniqueMail('Mail.retrait_demand', $subject, $messages, $user->email, env('MAIL_USERNAME'));

                $subject = 'Demande de retrait ';
                $messages = 'Une demande de retrait à été envoyé';
                MailController::SendGeneralUniqueMail('generale_blade', $subject, $messages, env('MAIL_FINANCE'), env('MAIL_USERNAME'));
            }catch (\Exception $e){

            }
            return ['error'=>false,'message'=>'Demande éffectuée avec succès. Un email de confirmation vous sera envoyé.'];
        }else{
            return ['error'=>true,'message'=>'Mot de passe incorrecte.'];
        }
    }

    public function setsession_detail(Request $request){
        $data=$request->all();
        $boutique = Boutique::where('slug',$data['slug'])->first();
        Session::put('boutique',$boutique);
        return json_encode(true);
    }

    public function have_enseigne_check(){
        $enseignes =  Enseigne::where('id_user_fk_enseigne','=',Session::get('user')['id'])->get();
        return count($enseignes);
    }

    public function home(Request $request){
        $user = Auth::user();
        $privilegecheck=new \App\Users_controle();
        $check_privilege=$privilegecheck->has_privilege($user->id,'super_administrateur');
        $check_productor=$privilegecheck->has_privilege($user->id,'producteur');
        $startDate = $request->startDay ? $request->startDay : date('Y-01-01');
        $endDate = $request->endDay ? $request->endDay : date('Y-12-31');
        if($check_privilege){
            $articleProducteur = [];
            $article_merchant = 0;
            $producerPercentage = [];
            $boutique_all_slug = Boutique::pluck('slug')->toArray();
            $total_boutique = count($boutique_all_slug);
            $achatTotal = Commandes::where('corbeil', false)->where('statut_paiement', true)->whereBetween('created_at',array($startDate,$endDate))->pluck('total_price')->toArray();
            $total_achat = 0;
            if (count($achatTotal) > 0) $total_achat = array_sum($achatTotal);
            $retrait = Retrait::where('status_retrait', true)->whereBetween('created_at',array($startDate,$endDate))->pluck('montant')->toArray();
            $total_retrait = 0;
            if (count($retrait) > 0) $total_retrait = array_sum($retrait);
            $portefeuilles = Portefeuille::where('user_slug', $user->slug)->whereBetween('created_at',array($startDate,$endDate))->get();
            $total_commande = Commandes::whereIn('boutique_slug', $boutique_all_slug)->whereBetween('created_at',array($startDate,$endDate))->where('corbeil',false)->count();
            $totalvente = Commandes::whereIn('boutique_slug', $boutique_all_slug)->whereBetween('created_at',array($startDate,$endDate))->where('statut_paiement', true)->pluck('total_price')->where('corbeil',false)->toArray();;
            $total_vente = 0;
            if (count($totalvente) > 0) $total_vente = array_sum($totalvente);
            $total_shipping = Commandes::whereIn('boutique_slug', $boutique_all_slug)->where('statut_shipping', true)->whereBetween('created_at',array($startDate,$endDate))->count();
            $articlesListe = DB::table('select_articles')->pluck('article_slug')->toArray();
            $total_articles_activer = CatalogueArticles::whereIn('slug', $articlesListe)->orwhereIn('boutique_slug', $boutique_all_slug)->where('active', true)->whereBetween('created_at',array($startDate,$endDate))->count();
            //$total_articles_desactiver = CatalogueArticles::whereIn('slug', $articlesListe)->where('active', false)->count();
            // $total_achat = Commandes::where('user_slug',Session::get('user')['slug'])->count();
            $favoris_boutique_slug = wishlist_boutique::pluck('boutique_slug')->toArray();
            $favoris_article_slug = wishlist_article::pluck('catalogue_article_slug')->toArray();
            $favoris_boutique = Boutique::whereIn('slug', $favoris_boutique_slug)->take(3)->get();
            $boutique_slug = check_boutiques::orderBy('id', 'DESC')->pluck('boutique_slug');
            $article_list_slug = check_products::distinct('catalogue_article_slug')->pluck('catalogue_article_slug')->toArray();
            $article_list_slug = array_reverse($article_list_slug);
            $boutiques = Boutique::with('metier', 'meta', 'publicites')->where('installer', true)->whereBetween('created_at',array($startDate,$endDate))->whereIn('slug', $boutique_slug)->take(3)->get();
            $articles_lists = CatalogueArticles::with('categorie', 'images', 'boutique')
                            ->whereBetween('created_at',array($startDate,$endDate))
                            ->whereIn('slug', $article_list_slug)
                            ->where('active', true);
            if ($request->has('name')) {
                $articles_lists->where('name', 'like', '%' . $request->name . '%');
            }
            
            $articles_lists = $articles_lists->take(8)->get();

            $favoris_article = CatalogueArticles::with('categorie', 'images', 'boutique')->whereBetween('created_at',array($startDate,$endDate))->whereIn('slug', $favoris_article_slug)->where('active', true)->take(8)->get();
            $marketers = DB::table('marketers')->where('visibility', true)->get();
            $code=null;
        }else {
            $articleProducteur = [];
            $article_merchant = 0;
            $producerPercentage = [];
            if ($check_productor) {
                $producerPercentage = \App\ProducerPercentage::first();
                $articleProducteur = \App\ArticleProducteur::where('user_id', $user->id)->whereBetween('created_at',array($startDate,$endDate))->get();
                $article_merchant = 0;
                foreach ($articleProducteur as $item) {
                    $articles = \App\CatalogueArticles::where('article_slug', $item->slug)->with('boutique')->count();
                    $article_merchant += $articles;
                    $total_commande = \App\CommandArticle::where('article_slug', $item->slug)->count();
                }
            }
            $boutique_all_slug = Boutique::where('user_slug', $user['slug'])->pluck('slug')->toArray();
            $total_boutique = count($boutique_all_slug);
            $achatTotal = Commandes::where('user_slug', $user['slug'])->where('corbeil', false)->where('statut_paiement', true)->whereBetween('created_at',array($startDate,$endDate))->pluck('total_price')->toArray();
            $total_achat = 0;
            if (count($achatTotal) > 0) $total_achat = array_sum($achatTotal);
            $retrait = Retrait::where('user_slug', Session::get('user')['slug'])->where('status_retrait', true)->whereBetween('created_at',array($startDate,$endDate))->pluck('montant')->toArray();
            $total_retrait = 0;
            if (count($retrait) > 0) $total_retrait = array_sum($retrait);
            $portefeuilles = Portefeuille::where('user_slug', $user['slug'])->whereBetween('created_at',array($startDate,$endDate))->get();
            $total_commande = Commandes::whereIn('boutique_slug', $boutique_all_slug)->whereBetween('created_at',array($startDate,$endDate))->where('corbeil',false)->count();
            $totalvente = Commandes::whereIn('boutique_slug', $boutique_all_slug)->where('statut_paiement', true)->where('corbeil',false)->whereBetween('created_at',array($startDate,$endDate))->pluck('total_price')->toArray();;
            $total_vente = 0;
            if (count($totalvente) > 0) $total_vente = array_sum($totalvente);
            $total_shipping = Commandes::whereIn('boutique_slug', $boutique_all_slug)->where('statut_shipping', true)->where('corbeil',false)->whereBetween('created_at',array($startDate,$endDate))->count();
            $articlesListe = DB::table('select_articles')->where('user_slug', Session::get('user')['slug'])->pluck('article_slug')->whereBetween('created_at',array($startDate,$endDate))->toArray();
            $total_articles_activer = CatalogueArticles::whereIn('slug', $articlesListe)->orwhereIn('boutique_slug', $boutique_all_slug)->where('active', true)->where('corbeil',false)->whereBetween('created_at',array($startDate,$endDate))->count();
            //$total_articles_desactiver = CatalogueArticles::whereIn('slug', $articlesListe)->where('active', false)->count();
            // $total_achat = Commandes::where('user_slug',Session::get('user')['slug'])->count();
            $favoris_boutique_slug = wishlist_boutique::where('user_slug', Session::get('user')['slug'])->pluck('boutique_slug')->whereBetween('created_at',array($startDate,$endDate))->toArray();
            $favoris_article_slug = wishlist_article::where('user_slug', Session::get('user')['slug'])->pluck('catalogue_article_slug')->whereBetween('created_at',array($startDate,$endDate))->toArray();
            $favoris_boutique = Boutique::whereIn('slug', $favoris_boutique_slug)->take(3)->get();
            $boutique_slug = check_boutiques::where('user_slug', Session::get('user')['slug'])->orderBy('id', 'DESC')->pluck('boutique_slug');
            $article_list_slug = check_products::where('user_slug', Session::get('user')['slug'])->distinct('catalogue_article_slug')->pluck('catalogue_article_slug')->toArray();
            $article_list_slug = array_reverse($article_list_slug);
            $boutiques = Boutique::with('metier', 'meta', 'publicites')->where('installer', true)->whereBetween('created_at',array($startDate,$endDate))->whereIn('slug', $boutique_slug)->take(3)->get();
            $articles_lists = CatalogueArticles::with('categorie', 'images', 'boutique')
            ->whereBetween('created_at',array($startDate,$endDate))
            ->whereIn('slug', $article_list_slug)
            ->where('active', true);
            if ($request->has('name')) {
                $articles_lists->where('name', 'like', '%' . $request->name . '%');
            }
            $articles_lists = $articles_lists->take(8)->get();
            $favoris_article = CatalogueArticles::with('categorie', 'images', 'boutique')->whereBetween('created_at',array($startDate,$endDate))->whereIn('slug', $favoris_article_slug)->where('active', true)->take(8)->get();
            $marketers = DB::table('marketers')->where('visibility', true)->get();
            $code=DB::table('code_promos')->where('user_id',Session::get('user')['id'])->first();
        }
        return view('dashboard/index', compact('producerPercentage', 'articleProducteur', 'article_merchant', 'code','marketers','user','total_retrait','boutiques','favoris_boutique','favoris_article','articles_lists','total_achat','total_articles_activer','total_commande','total_shipping','total_vente','total_boutique','portefeuilles'));
    }

    public function gerer_boutique($slug){
        $boutique = Boutique::with('meta', 'partenaires', 'publicites', 'demande_supression','paiement_echelonner','mibSubscribe')->where('slug', $slug)->first();
        $commande= Commandes::where('check',false)->where('boutique_slug',$boutique['slug'])->count();
        $cmd=$commande;
        Session::put('boutique',$boutique);
        Session::put('boutique_admin',$boutique);
        return view('dashboard.Boutique.menu',compact('boutique','cmd'));
    }


    public function menu(){
        return view('Prestashop/menu');
    }
    public function accueil(){
        $user = Auth::user();
        return view('welcome', compact('user'));

    }

    public function logout_web(){
        Session::forget('user');
        if($this->logout()){
            return redirect('/');
        }else{
            return back();
        }
    }
public function logout_web_boutique(){
        Session::forget('user');
        if($this->logout()){
            return back();
        }else{
            return back();
        }
    }

    public function logout(){
        $user=Auth::logout();
        $statut=true;
        if(!$user) {
            $statut=false;
        }
        return  $response=json_encode(['statut'=>$statut]);
    }

}
