<?php

namespace App\Http\Controllers\Investment;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Http\Controllers\MailController;
use App\InvestissementNews;
use App\InvestmentProjetContribution;
use App\InvestmentProject;
use App\Annonce;
use App\User;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Str;
use Intervention\Image\Facades\Image;

class InvestissementNewsController extends Controller
{
    public function index($slug)
    {
        $project = InvestmentProject::where('slug',$slug)->first();
        $actualites = InvestissementNews::where("project_id", $project->id)->get();
        return view('dashboard.Investment.actualite', compact("actualites","project"));
    }

    public function createNews(Request $request)
    {
        $data = $request->all();
        try {
            $rules = array(
                'title' => 'required',
                'type' => 'required',
                'image' => 'mimes:jpg,png,jpeg',
                'resume' => 'required|string',
                'contenu' => 'required|string',
            );

            $validator = \Illuminate\Support\Facades\Validator::make($request->all(), $rules);
            if ($validator->fails()) {
                return back()->withErrors($validator)->withInput();
            }
            unset($data["action"]);
            //$data["user_id"]=Auth::id();
            $data["created_by"]=Auth::id();
            $project = InvestmentProject::find($data['project_id']);
            if ($request->image){
                $time = time();
                $originalImage = $request->image;
                $thumbnailImage = Image::make($originalImage);
                $originalPath = public_path('Uploads/investissement_news/');
                $location = $originalPath . $time . $originalImage->getClientOriginalName();
                $thumbnailImage->save($originalPath . $time . $originalImage->getClientOriginalName());
                $filename = $time . $originalImage->getClientOriginalName();
                $data['image'] = asset('Uploads/investissement_news/' . $filename);
            }
            if (!isset($data['id'])) {
                $data['slug'] = "inv_".Annonce::generate_slug_for_table("investissement_news");
                $data['status'] = false;
                $return = InvestissementNews::create($data);
                if (isset($return->id)) {
                    $contributors=InvestmentProjetContribution::with('user')->where('investment_project_id',$project->id)->pluck('sgi_user_id')->toArray();
                    $emails=User::whereIn('id',$contributors)->pluck('email')->toArray();
                    $subject = 'Des nouvelles de votre investissement sur le projet '.$project->titre;
                    $messages = Str::limit($data['resume'], 250);
                    $msg=['msg'=>$messages,'route'=>env('INVESTISSEMENT_URL').'/project/'.$project['slug'],'image'=>$data['image']];
                    MailController::SendMultipleGeneralUniqueMail('Mail.generale_with_link_blade', $subject, $msg, $emails, env('MAIL_USERNAME'));
                    Session::flash('success', 'Votre article est désormais disponible');
                } else {
                    Session::flash('error', 'Un  problème est survenue au cours du processus de publication de l\'article ');
                }
            } else {
                unset($data["id"]);
                $return = InvestissementNews::find($request->id)->update($data);
                if ($return) {
                    Session::flash('success', 'Votre article a été modifié.');
                } else {
                    Session::flash('error', 'Un  problème est survenue au cours du processus de modification de l\'article ');
                }
            }

        } catch (\Exception $e) {
            Session::flash('error', 'Un  problème est survenue au cours de l\'exécution du processus ' . $e);
        }
        return back();

    }

    public function visibility($slug)
    {
        try {
            $ac = InvestissementNews::whereSlug($slug)->first();
            if ($ac) {
                $text = $ac->status? false : true;
                $ac->status = $text;
                $ac->save();
                Session::flash('success', 'le status de votre article à été mis à jour');
            } else {
                Session::flash('error', 'Un  problème est survenue au cours du processus de modification de l\'article ');
            }

        } catch (\Exception $e) {
            Session::flash('error', 'Un  problème est survenue au cours de l\'exécution du processus ' . $e);
        }
        return back();

    }
    public function publish($slug)
        {
            try {
                $ac = InvestissementNews::whereSlug($slug)->first();
                if ($ac) {
                    $text = $ac->public? 'private' : 'public';
                    $ac->public = $text;
                    $ac->save();
                    Session::flash('success', 'le status de votre article est ');
                } else {
                    Session::flash('error', 'Un  problème est survenue au cours du processus de modification de l\'article ');
                }

            } catch (\Exception $e) {
                Session::flash('error', 'Un  problème est survenue au cours de l\'exécution du processus ' . $e);
            }
            return back();

        }

    public function get_investissement_news(Request $request){
        try {
            $annonce = InvestissementNews::whereSlug($request->slug)->first();
            return ["data" => $annonce, "msg" => "data", "error" => false];
        } catch (\Exception $e) {
            return ["data" => null, "msg" => $e->getMessage(), "error" => true];
        }

    }

    public function delete_investissement_news($slug)
    {
        try {
            InvestissementNews::whereSlug($slug)->delete();
            Session::flash('success', 'Votre article a été supprimé avec succès.');
        } catch (\Exception $e) {
            Session::flash('error', 'Un  problème est survenue au cours de l\'exécution du processus ' . $e);
        }
        return back();

    }
}
