<?php

namespace App\Http\Controllers\Investment;

use App\Actualite;
use App\Annonce;
use App\AskInvestmentProjectAllow;
use App\File;
use App\Http\Controllers\MailController;
use App\InvestmentProject;
use App\InvestmentProjectAllow;
use App\User;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Str;
use Intervention\Image\Facades\Image;

class InvestmentController extends Controller
{
    public function index()
    {
        $user = Auth::user()->load("investment_project_allow", "ask_investment_project_allow");
        $investment_projects = InvestmentProject::with("files","comments","user","contributions")
            ->where("user_id",$user->id)->orderByDesc("id")->get();
        return view('dashboard.Investment.index', compact("user","investment_projects"));
    }
    
    public function params()
    {
        return view('dashboard.Investment.params');
    }

    public function askPermission()
    {
        AskInvestmentProjectAllow::create([
            "user_id" => Auth::id()
        ]);

        $user = Auth::user();
        $subject = "Nouvelle demande";
        $messages = ["text" => "Une nouvelle demande  pour devenir promoteur de projet a été envoyé par " . $user['first_name'] . ' ' . $user['last_name']];
        $email = env("MAIL_FINANCE");
        MailController::AlertAskPromotionMail($subject, $messages, $email);
        Session::flash('success', 'Votre demande a été envoyé à l\'équipe SUNGROCEY, merci de patienter');
        return back();
    }

    public function allPermissionProject()
    {
        $users = User::with("investment_project_allow", "ask_investment_project_allow")
            ->has("ask_investment_project_allow")->get();
        return view('dashboard.Investment.admin.index', compact("users"));
    }

    public function givePermissionProject(Request $request)
    {

        try {
            $rules = $request->response == "refused" ?array(
                'slug' => 'required',
                'response' => 'required|string',
                'motif' =>  'required|string',
            ):array(
                'slug' => 'required',
                'response' => 'required|string',
            );

            $validator = \Illuminate\Support\Facades\Validator::make($request->all(), $rules);
            if ($validator->fails()) {
                return back()->withErrors($validator)->withInput();
            }

            $askInvestmentProjectAllow = AskInvestmentProjectAllow::find($request->slug);
            $askInvestmentProjectAllow->update($request->only("response", "motif"));
            switch ($request->response) {
                case "refused":
                    InvestmentProjectAllow::where("user_id", $askInvestmentProjectAllow->user_id)->delete();
                    break;
                case "accepted":
                    InvestmentProjectAllow::create(["user_id" => $askInvestmentProjectAllow->user_id]);
                    break;

            }
            Session::flash('success', 'Votre réponse a été ajouté à cette demande');
        } catch (\Exception $e) {
            Session::flash('error', 'Un  problème est survenue au cours de l\'exécution du processus ' . $e);
        }
        return back();
    }

    public function addImage(Request $request){
        try {
            $rules = array(
                'couverture' => 'required',
                'couverture.*' => 'mimes:jpg,png,jpeg',
                'investment_id'=>"required"
            );
            $validator = \Illuminate\Support\Facades\Validator::make($request->all(), $rules);
            if ($validator->fails()) {
                return back()->withErrors($validator)->withInput();
            }
            $pos = 0;
            foreach ($request->couverture as $image){
                $time = time()."_".$pos;
                $originalImage =$image;
                $thumbnailImage = Image::make($originalImage);
                $path='Uploads/investment-projects/';
                $originalPath = public_path($path);
                $location = $originalPath . $time .".". $originalImage->getClientOriginalExtension();
                $thumbnailImage->save($location);
                $filename = $time .".". $originalImage->getClientOriginalExtension();
                $file = asset($path . $filename);
                $investment = InvestmentProject::find($request->investment_id);
                $investment->files()->create(['title' => $originalImage->getClientOriginalName(), 'url' => $file]);
                $pos++;
            }
            Session::flash('success', 'Les images ont été ajoutées');
        }catch (\Exception $e){
            Session::flash('error', 'Un  problème est survenue au cours de l\'exécution du processus ' . $e);
        }
        return back();
    }

    public function addOrUpdate(Request $request)
    {
        $data = $request->all();
        try {
            $rules = array(
                'titre' => 'required|string',
                'image' => isset($request->id)?'mimes:jpg,png,jpeg':'required:mimes:jpg,png,jpeg',
                'resume' => 'required|string',
                'youtube' => 'required|string',
                'date_debut_participation' => 'required|date',
                'date_fin_participation' => 'required|date|after:date_debut_participation',
                'contenu' => 'required|string',
            );

            $validator = \Illuminate\Support\Facades\Validator::make($request->all(), $rules);
            if ($validator->fails()) {
                return back()->withErrors($validator)->withInput();
            }
            unset($data["action"]);
            $data["user_id"]=Auth::id();
            if ($request->image){
                $time = time();
                $originalImage = $request->image;
                $thumbnailImage = Image::make($originalImage);
                $path='Uploads/investment-projects/';
                $originalPath = public_path($path);
                $name=$time .".". $originalImage->getClientOriginalExtension();
                $location = $originalPath .''. $name;
                $thumbnailImage->save($location);
                $data['couverture'] = asset($path . $name);
            }
            unset($data["image"]);
            if (!isset($data['id'])) {
                $data['slug'] = "project_".Annonce::generate_slug_for_table("investment_projects");
                $return = InvestmentProject::create($data);
                if (isset($return->id)) {
                    Session::flash('success', 'Votre projet à été créer avec succès. Un processus de validation est nécessaire avant la mise en ligne de votre projet. Veuillez patientez... Nous repondons généralement sous 48h.');
                } else {
                    Session::flash('error', 'Un  problème est survenue au cours du processus de publication du projet ');
                }
            } else {
                unset($data["id"]);
                $return = InvestmentProject::find($request->id)->update($data);
                if ($return) {
                    Session::flash('success', 'Les mises à jour ont été apportées sur votre projet.');
                } else {
                    Session::flash('error', 'Un  problème est survenue au cours du processus de modification  du projet ');
                }
            }

        } catch (\Exception $e) {
            dd($e);
            Session::flash('error', 'Un  problème est survenue au cours de l\'exécution du processus ' . $e);
        }
        return back();

    }

    public function getData(Request $request){
        try {
            $data = InvestmentProject::with("files")->whereSlug($request->slug)->first();
            if (isset($request->html)){
                $returnHTML = view('dashboard.Investment.image_update')->with('files', $data->files)->render();
                return ["data" => ["data"=>$data,"html"=>$returnHTML], "msg" => "data", "error" => false];
            }else{
                return ["data" => $data, "msg" => "data", "error" => false];
            }
        } catch (\Exception $e) {
            return ["data" => null, "msg" => $e->getMessage(), "error" => true];
        }

    }
    public function visibility($slug)
    {
        try {

            $ac = InvestmentProject::whereSlug($slug)->first();
            if ($ac) {
                $text = $ac->visibility?"désactivé":"activé";
                $ac->visibility = !$ac->visibility;
                $ac->save();
                Session::flash('success', 'Votre projet a été '.$text.' sur grocery');
            } else {
                Session::flash('error', 'Un  problème est survenue au cours du processus de modification de l\'annonce ');
            }

        } catch (\Exception $e) {
            Session::flash('error', 'Un  problème est survenue au cours de l\'exécution du processus ' . $e);
        }
        return back();

    }


    public function deleteData($slug)
    {
        try {
            InvestmentProject::whereSlug($slug)->delete();
            Session::flash('success', 'Le projet a été supprimé sur grocery');
        } catch (\Exception $e) {
            Session::flash('error', 'Un  problème est survenue au cours de l\'exécution du processus ' . $e);
        }
        return back();

    }


    public function deleteImage($id)
    {
        try {
            File::find($id)->delete();
            Session::flash('success', 'Le fichier a été supprimé sur grocery');
        } catch (\Exception $e) {
            Session::flash('error', 'Un  problème est survenue au cours de l\'exécution du processus ' . $e);
        }
        return back();

    }


}
