<?php

namespace App\Http\Controllers\Investment;

use App\Http\Controllers\Controller;
use App\investissementRemboursement;
use App\InvestmentProjetContribution;
use App\Portefeuille;
use App\User;
use App\InvestmentProject;
use App\Http\Traits\ProjectTrait;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use App\Http\Controllers\MailController;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Session;

class RemboursementController extends Controller
{
    use ProjectTrait;

    public function index($slug)
    {
        $contribution = InvestmentProjetContribution::with('user')->where('slug',$slug)->first();
        $project = InvestmentProject::with($this->projectRelation())->where('id',$contribution->investment_project_id)->first();
        $remboursements = investissementRemboursement::where('contribution_id',$contribution['id'])
            ->get();
        $total_rembourse = investissementRemboursement::where('contribution_id',$contribution['id'])
            ->where('status','done')
            ->sum('montant');
        return view('dashboard.Investment.remboursement', compact("remboursements","project","contribution","total_rembourse"));
    }
    
    
    public function make_global_remboursement(Request $request)
        {
               try {
                $data = $request->all();
                $user=Auth::user();
                $portefeuille=Portefeuille::where('user_slug',$user['slug'])->where('devise','XOF')->where('active',1)->first();
                $project = InvestmentProject::find($data['project_id']);
                $contributions= InvestmentProjetContribution::where($project['contribution_id'])->get();
                foreach($contributions as $contribution){
                    $invest = investissementRemboursement::where('id',$contribution->id)->where('year',$data['year'])->where('type',$data['type'])->first();
                    if(isset($invest) && isset($invest->montant)){
                        $total_remboursement=$invest->montant;
                        if($portefeuille['montant'] > $total_remboursement){
                            // Remove amount from admin wallet
                            $decrement_amount= intval($portefeuille['montant']) - intval($total_remboursement);
                            DB::table('portefeuilles')->where('id',$portefeuille['id'])->update(['montant'=>$decrement_amount]);
                            
                            // Decrement logs
                            DB::table('portefeuille_user_logs')->insert([
                                'motif'=>"Remboursement de l'investissement sur le projet ".$project->titre." pour le compte de l'année ".$invest->year,
                                "action"=>"REMBOURSEMENT",
                                "montant"=>$decrement_amount,
                                "devise"=>"XOF",
                                "boutique_slug"=>$user['slug'],
                                "admin"=>0,
                            ]);
                            
                            // Credit user account wallet
                            $contributor=User::where('id',$contribution->sgi_user_id)->first();
                            $contributor_wallet=Portefeuille::where('user_slug',$user['slug'])->where('devise','XOF')->where('active',1)->first();
                            $increment_amount= intval($contributor_wallet->montant) + intval($total_remboursement);
                            DB::table('portefeuilles')->where('id',$contributor_wallet->id)->update(['montant'=>$increment_amount]);
                            
                            // Increment logs
                            DB::table('portefeuille_user_logs')->insert([
                                'motif'=>"Remboursement de l'investissement sur le projet ".$project->titre." pour le compte de l'année ".$invest->year,
                                "action"=>"REMBOURSEMENT",
                                "montant"=>$increment_amount,
                                "devise"=>"XOF",
                                "boutique_slug"=>$contributor['slug'],
                                "admin"=>0,
                            ]);
                            DB::table('investissement_remboursements')->where('id',$invest->id)->update(['status'=>'done','payer_id'=>$user['id'],'paid_by'=>'admin']);
                        }else{
                            Session::flash('error', "Fonds insuffisant. Veuillez recharger votre compte pour continuer.");
                        }
                        //Envoyer un email au client remboursé
                        $subject = 'Sungrocery Remboursement';
                        $messages = ['project' => $project, 'remboursement' => $invest, 'user' => $user];
                        MailController::SendGeneralUniqueMail('Mail.sgi.remboursement', $subject, $messages, $user->email, env('MAIL_USERNAME'));
                    }
                }
                }catch (\Exception $e){
                    Session::flash('error', 'Une erreure est survenue au cours du processus. Veuillez rééssayer. '.$e->getMessage()." ".$e->getLine());
                    return back();
                }
                Session::flash('success', 'Remboursement éffectué avec succès.');
                return back();
        }


    
        public function make_remboursement(Request $request)
        {
               try {
                $data = $request->all();
                $user=Auth::user();
                $portefeuille=Portefeuille::where('user_slug',$user['slug'])->where('devise','XOF')->where('active',1)->first();
                $invest = investissementRemboursement::where('id',$data['remboursement_id'])->first();
                $total_remboursement=$invest->montant;
                if($portefeuille['montant'] > $total_remboursement){
                    $contribution= InvestmentProjetContribution::find($invest->contribution_id);
                    $project = InvestmentProject::find($contribution->investment_project_id);
                    
                    // Remove amount from admin wallet
                    $decrement_amount= intval($portefeuille['montant']) - intval($total_remboursement);
                    DB::table('portefeuilles')->where('id',$portefeuille['id'])->update(['montant'=>$decrement_amount]);
                    
                    // Decrement logs
                    DB::table('portefeuille_user_logs')->insert([
                        'motif'=>"Remboursement de l'investissement sur le projet ".$project->titre." pour le compte de l'année ".$invest->year,
                        "action"=>"REMBOURSEMENT",
                        "montant"=>$decrement_amount,
                        "devise"=>"XOF",
                        "boutique_slug"=>$user['slug'],
                        "admin"=>0,
                    ]);
                    
                    // Credit user account wallet
                    $contributor=User::where('id',$contribution->sgi_user_id)->first();
                    $contributor_wallet=Portefeuille::where('user_slug',$user['slug'])->where('devise','XOF')->where('active',1)->first();
                    $increment_amount= intval($contributor_wallet->montant) + intval($total_remboursement);
                    DB::table('portefeuilles')->where('id',$contributor_wallet->id)->update(['montant'=>$increment_amount]);
                    
                    // Increment logs
                    DB::table('portefeuille_user_logs')->insert([
                        'motif'=>"Remboursement de l'investissement sur le projet ".$project->titre." pour le compte de l'année ".$invest->year,
                        "action"=>"REMBOURSEMENT",
                        "montant"=>$increment_amount,
                        "devise"=>"XOF",
                        "boutique_slug"=>$contributor['slug'],
                        "admin"=>0,
                    ]);
                    DB::table('investissement_remboursements')->where('id',$data['remboursement_id'])->update(['status'=>'done','payer_id'=>$user['id'],'paid_by'=>'admin']);
                }else{
                    Session::flash('error', "Fonds insuffisant. Veuillez recharger votre compte pour continuer.");
                }
                //Envoyer un email au client pour le remboursement
                 $subject = 'Sungrocery Remboursement';
                 $messages = ['project' => $project, 'remboursement' => $invest, 'user' => $user];
                 MailController::SendGeneralUniqueMail('Mail.sgi.remboursement', $subject, $messages, $user->email, env('MAIL_USERNAME'));
                }catch (\Exception $e){
                    Session::flash('error', 'Une erreure est survenue au cours du processus. Veuillez rééssayer. '.$e->getMessage()." ".$e->getLine());
                    return back();
                }
                Session::flash('success', 'Remboursement éffectué avec succès.');
                return back();
        }

}
