<?php

namespace App\Http\Controllers;

use App\check_boutiques;
use App\Commandes;
use App\Enseigne;
use App\Mail\Mail;
use App\Metier;
use App\Privilege_access;
use App\ProfileAnnonceur;
use App\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Response;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Str;
use Intervention\Image\Facades\Image;
use Illuminate\Support\Facades\Log;

class LoginController extends Controller
{
    public function __construct()
    {
        if (Auth::check()) {
            if (Auth::user()->country == null && Auth::user()->continent == null) {
                if (!Session::has('country')) {
                    $ip = $this->getVisIpAddr();
                    try {
                        $json = file_get_contents('https://freegeoip.app/json/' . $ip);
                        $data = json_decode($json, true);
                        $country = $data['country_name'];
                        $city = $data['city'];
                        $continent = explode('/', $data['time_zone'])[0];
                        $currency = '';
                        Session::put(['country' => $country, 'city' => $city, 'continent' => $continent, 'currency' => $currency]);
                    } catch (\Exception $e) {
                        if (Auth::check()) {
                            $user = Auth::user();
                            if (isset($user)) {
                                Session::put(['country' => $user->country, 'region' => $user->region, 'city' => $user->city, 'continent' => $user->continent]);
                            }
                        }
                    }
                }
            } else {
                $user = Auth::user();
                if (isset($user)) {
                    Session::put(['country' => $user->country, 'region' => $user->region, 'city' => $user->city, 'continent' => $user->continent]);
                }
            }
        } else {
            if (!Session::has('country')) {
                $ip = $this->getVisIpAddr();
                try {
                    $json = file_get_contents('https://freegeoip.app/json/' . $ip);
                    $data = json_decode($json, true);
                    $country = $data['country_name'];
                    $city = $data['city'];
                    $continent = explode('/', $data['time_zone'])[0];
                    $currency = '';
                    Session::put(['country' => $country, 'city' => $city, 'continent' => $continent, 'currency' => $currency]);
                } catch (\Exception $e) {
                }
            }
        }
    }

    function getVisIpAddr()
    {

        if (!empty($_SERVER['HTTP_CLIENT_IP'])) {
            return $_SERVER['HTTP_CLIENT_IP'];
        } else if (!empty($_SERVER['HTTP_X_FORWARDED_FOR'])) {
            return $_SERVER['HTTP_X_FORWARDED_FOR'];
        } else {
            return $_SERVER['REMOTE_ADDR'];
        }
    }

    public function login(Request $request)
    {
        $privilegecheck=new \App\Users_controle();
        
        $data = $request->all();
        $validator = $request->validate([
            'email'     => 'required',
            'password'  => 'required|min:6'
        ]);
        $error = false;
        $url = '';
        try {
            $user = DB::table('users')->where('email', $data['email'])->orwhere('username', $data['email'])->first();
            $credentials = [
                'email' => $user->email,
                'password' => $data['password']
            ];
            if (Auth::attempt($credentials)) {
                Session::put('user', Auth::user());
                $user = Auth::user()->id;
                if (Session::has('command_id_new')) {
                    $cmd = Commandes::findOrFail(Session::get('command_id_new'));
                    $cmd->user_slug = Auth::user()->slug;
                    $cmd->save();
                    Session::forget('command_id_new');
                    Session::put(['panier' => 0, 'prix' => 0]);
                    Session::put('addedArticles', []);
                    Session::put('commandes', []);
                    //ENREGISTRER LA DERNIERE BOUTIQUE VISITER SI SOUSCRIPTION
                }
                if (Session::has('boutique')) {
                    $bouti = Session::get('boutique')['slug'];
                    if (Session::has('user')) {
                        $data['user_slug'] = Session::get('user')['slug'];
                    } else {
                        $data['user_slug'] = request()->ip();
                    }
                    $data['boutique_slug'] = $bouti;
                    $data['nclick'] = 1;
                    check_boutiques::create($data);
                }
                
                $check_productor_privilege=$privilegecheck->has_privilege($user,'producteur');
                if($check_productor_privilege){
                    // $url = route('landing');
                    $url = \session()->has('url.intended') ? ((\session()->get('url.intended') != route('login') || \session()->get('url.intended') != route('landing'))  ? \session()->get('url.intended') : route('home')) : route('home');
                } else {
                    $url = \session()->has('url.intended') ? ((\session()->get('url.intended') != route('login') || \session()->get('url.intended') != route('landing'))  ? \session()->get('url.intended') : route('home')) : route('home');
                }
                $message = 'Connexion établie avec succès. Redirection en cours ...';
            } else {
                $error = true;
                $message = 'Une erreur s\'est produite au cours de l\'authentification';
            }
        } catch (\Exception $e) {
            $error = true;
            $message = 'Une erreur s\'est produite au cours de l\'authentification ' . $e->getMessage();
        }
        return ['error' => $error, 'message' => $message, 'url' => $url];
    }

    public function login_for_boutique(Request $request)
    {
        $data = $request->all();
        $validator = $request->validate([
            'email'     => 'required',
            'password'  => 'required|min:6'
        ]);
        $error = false;
        $url = '';
        try {
            $user = DB::table('users')->where('email', $data['email'])->orwhere('username', $data['email'])->first();
            $credentials = [
                'email' => $user->email,
                'password' => $data['password']
            ];
            if (Auth::attempt($credentials)) {
                Session::put('user', Auth::user());
                $user = Auth::user()->id;
                $url = \session()->has('url.intended') ? ((\session()->get('url.intended') != route('login') || \session()->get('url.intended') != route('landing'))  ? \session()->get('url.intended') : route('home')) : route('home');
                $message = 'Connexion établie avec succès. Redirection en cours ...';
            } else {
                $error = true;
                $message = 'Une erreur s\'est produite au cours de l\'authentification';
            }
        } catch (\Exception $e) {
            $error = true;
            $message = 'Une erreur s\'est produite au cours de l\'authentification ' . $e->getMessage();
        }
        return ['error' => $error, 'message' => $message, 'url' => $url];
    }

    public function login_boutique()
    {
        if (Auth::guest()) {
            return view('dashboard/Boutique/boutique_login');
        } else {
            return redirect('home');
        }
    }

    public function register_boutique()
    {
        if (Auth::guest()) {
            $pays = DB::table('countries')->get();
            if (Session::has('user')) {
                return redirect('home');
            }
            if (Session::has('command_id_new')) {
                $cmd = Commandes::findOrFail(Session::get('command_id_new'));
                Session::put('user_command', $cmd);
            }
            return view('dashboard/Boutique/boutique_suscribe', compact('pays'));
        } else {
            return redirect('home');
        }
    }


    public function bienvenue()
    {
        return view('welcome');
    }

    public function update_user_data_view()
    {
        $this->middleware('auth');
        $user = Auth::user();
        if (isset($user)) {
            Session::put(['country' => $user->country, 'region' => $user->region, 'city' => $user->city, 'continent' => $user->continent]);
        }
        $pays = DB::table('countries')->get();
        $profileAnnonceur = ProfileAnnonceur::where("user_id", Auth::id())->first();
        return view('Auth/edit_profil', compact('pays', 'profileAnnonceur'));
    }

    public function update_user_password(Request $request)
    {
        $data = $request->all();
        if ($data['password'] != $data['cpassword']) {
            Session::flash('password_error', 'Mot de passe de confirmation incorrect');
            return back();
        }
        $user = User::findOrFail($data['user_id']);
        if (!Hash::check($data['oldpassword'], $user->password)) {
            Session::flash('password_error', 'Mot de passe non confimer!');
            return back();
        }
        $credentials = [
            'password' => Hash::make($data['password']),
        ];
        DB::table('users')->where('id', $data['user_id'])->update($credentials);
        $users = User::where('id', $data['user_id'])->first();
        if (isset($users)) {
            Session::forget('user');
            Session::put('user', $users);
            Session::flash('password_success', 'Mot de passe mis à jour avec succès');
            Session::flash('success', 'Mot de passe mis à jour avec succès');
        } else {
            Session::flash('password_error', 'Echec de modification de vos informations');
            Session::flash('error', 'Echec de modification de vos informations');
        }
        return back();
    }

    public function update_user_data(Request $request)
    {

        $imagepath = "logo_mini.jpg";
        $user_pic = 1;
        $data = $request->all();
        $user = User::findOrFail($data['user_id']);
        $city = '';
        if (isset($data['city'])) {
            $city = DB::table('cities')->where('id', $data['city'])->first();
            $city = $city->name;
        }
        $region = '';
        if (isset($data['region'])) {
            $region = DB::table('states')->where('id', $data['region'])->first();
            $region = $region->name;
        }
        $country = '';
        $continent = '';
        if (isset($data['country'])) {
            $country = DB::table('countries')->where('id', $data['country'])->first();
            $continent = DB::table('continents')->where('Two_Letter_Country_Code', $country->iso2)->first();
            $continent = $continent->Continent_Name;
            $country = $country->name;
        }

        $credentials = [
            'email' => $data['email'],
            'username' => $data['username'],
            'first_name' => $data['first_name'],
            'last_name' => $data['last_name'],
            'telephone' => $data['full_number'],
            'country' => $country,
            'region' => $region,
            'city' => $city,
            'continent' => $continent
        ];

        if ($request->file('cnir')) {
            $cni = $request->file('cnir');
            $path = public_path('images/boutiques/Uploads/cni/');
            $ifFilename = time() . $user->slug . '.' . $cni->getClientOriginalExtension();
            $cni->move($path, $ifFilename);
            $credentials['cnir'] = $path . $ifFilename;
        }
        if ($request->file('cniv')) {
            $cniv = $request->file('cniv');
            $path = public_path('images/boutiques/Uploads/cni/');
            $ifFilename = time() . $user->slug . '.' . $cniv->getClientOriginalExtension();
            $cniv->move($path, $ifFilename);
            $credentials['cniv'] = $path . $ifFilename;
        }

        if (isset($data['cni'])) {
            $credentials['cni'] = $data['cni'];
        }
        $users = DB::table('users')->where('id', $user->id)->update($credentials);
        if (isset($users)) {
            if ($request->has('photo_profil')) {
                $user_model = new \App\Users_meta();
                if (!is_string(request()->photo_profil) and request()->photo_profil) {
                    $originalImage = $request->photo_profil;
                    $thumbnailImage = Image::make($originalImage);
                    $thumbnailPath = public_path('Profil_picture/');
                    $originalPath = public_path('Profil_picture/full/');
                    $time = time();
                    $thumbnailImage->save($originalPath . $time . $originalImage->getClientOriginalExtension());
                    $thumbnailImage->resize(150, 150);
                    $thumbnailImage->save($thumbnailPath . $time . $originalImage->getClientOriginalExtension());
                    $imagepath = $time . $originalImage->getClientOriginalExtension();
                }
                $user_pic = $user_model->update_user_meta($data['user_id'], 'profil_picture', $imagepath);
            }
            if ($user_pic == 0) {
                Session::flash('error', 'Une erreur s\'est produite au cours de la modification. L\'image uploader n\'a pas pu être enregistrer');
            } else {
                Session::forget('user');
                $users = User::findOrFail($user->id);
                Session::put('user', $users);
                Session::flash('success', 'Votre profil utilisateur à été mis à jour avec succès.');
            }
        } else {
            Session::flash('error', 'Une erreur s\'est produite au cours de la modification');
        }
        return back();
    }

    public function login_panel()
    {

        return view('Auth/_blank_log');
    }

    public function presentation()
    {
        return view('dashboard/acceuil');
    }



    //    public function login_web(Request $request){
    //
    //        $response = $this->login($request);
    //
    //        $get_array_response=json_decode($response,true);
    //
    //        if($get_array_response['statut']){
    //            if(isset($get_array_response['data'][0]['id'])) {
    //                $credentials = Sentinel::findById($get_array_response['data'][0]['id']);
    //                Sentinel::authenticate($credentials);
    //                if ($activation = Activation::completed($credentials)) {
    //                    Session::put('user', $get_array_response['data'][0]);
    //                    $user=Session::get('user')['id'];
    //                     if(Session::has('command_id_new')){
    //                        $cmd=Commandes::findOrFail(Session::get('command_id_new'));
    //                        $cmd->user_slug=Session::get('user')['slug'];
    //                        $cmd->save();
    //                        Session::forget('command_id_new');
    //                        Session::put(['panier'=>0,'prix'=>0]);
    //                        Session::put('addedArticles',[]);
    //                        Session::put('commandes',[]);
    //                        //ENREGISTRER LA DERNIERE BOUTIQUE VISITER SI SOUSCRIPTION APRES CHOU
    //
    //                    }
    //                    if(Session::has('boutique')) {
    //                        $bouti = Session::get('boutique')['slug'];
    //                        if (Session::has('user')) {
    //                            $data['user_slug'] = Session::get('user')['slug'];
    //                        } else {
    //                            $data['user_slug'] = request()->ip();
    //                        }
    //                        $data['boutique_slug']=$bouti;
    //                        $data['nclick'] = 1;
    //                        check_boutiques::create($data);
    //                    }
    //                    return redirect()->intended('home');
    //                } else {
    //                    Session::flash('error', 'Les informations saisis sont erronées');
    //                    return back();
    //                }
    //            }else{
    //                Session::flash('error','Echec authentification ! Nom d\'utilisateur ou Mot de passe erronné ');
    //                return back();
    //            }
    //        }else{
    //            Session::flash('error',$get_array_response['message']);
    //            return back();
    //        }
    //
    //
    //    }

    /* public function register_web(Request $request){

         try{

             $rules = array(
                 'first_name'=> 'required|string',
                 'last_name'=> 'required|string',
                 'email'=> 'required|email|unique:users|max:255',
                 'username'=> 'required|string|unique:users|max:255',
                 'password'=> 'required|string|min:6'

             );

             $validator = \Illuminate\Support\Facades\Validator::make($request->all(,$rules);
            /* if ($validator->fails()) {
                 return back()
                     ->withErrors($validator)
                     ->withInput();
             }*/
    /* if ($validator->fails())
     {
         return \Illuminate\Support\Facades\Response::json(array('success'=>false,'errors'=>$validator->getMessageBag()->toArray()),400);
     }else{
         $response = $this->register($request);
         $get_array_response=json_decode($response,true);

         if($get_array_response['statut']){
             Session::flash('success',$get_array_response['message']);

         }else{
             Session::flash('error',$get_array_response['message']);

         }
     }

 }catch (\Exception $e){
     Session::flash('error',$e->getMessage());

 }


}*/

    public function confirm_account_web($id)
    {
        $response = $this->confirm_account($id);
        $get_array_response = json_decode($response, true);

        if ($get_array_response['statut']) {
            Session::flash('success', $get_array_response['message']);
        } else {
            Session::flash('error', $get_array_response['message']);
        }
        return redirect('login');
    }

    //
    //    public function login(Request $request)
    //    {
    //        $message='';
    //        $statut=true;
    //        $data = $request->all();
    //        $users=[];
    //        $error=false;
    //        $message='';
    //        $url='';
    //        if (filter_var($data['email'], FILTER_VALIDATE_EMAIL)) {
    //            $users=DB::table('users')->where('email',$data['email'])->get();
    //        } else {
    //            $users=DB::table('users')->where('username',$data['email'])->get();
    //        }
    //        if (count($users)>0) {
    //            foreach($users as $user){
    //                $credentials = [
    //                    'email' => $user->email,
    //                    'password' => $data['password']
    //                ];
    //                $get_user=User::findOrFail($user->id);
    //                $user_check_validation = Sentinel::validateCredentials($get_user, $credentials);
    //                if ($user_check_validation) {
    //                    if (!$activation = Activation::completed($get_user))
    //                    {
    //                        $error=true;
    //                        $message='Compte non actif! Un email vous à été envoyé pour la confirmation de votre compte';
    //                    }else{
    //                        if(isset($data['remember']) && $data['remember']=='remember') {
    //                            Sentinel::authenticateAndRemember($credentials);
    //                        }else{
    //                            Sentinel::authenticate($credentials);
    //                        }
    //                        Session::put('user', $get_user);
    //                         $user=Session::get('user')['id'];
    //                         if(Session::has('command_id_new')){
    //                            $cmd=Commandes::findOrFail(Session::get('command_id_new'));
    //                            $cmd->user_slug=Session::get('user')['slug'];
    //                            $cmd->save();
    //                            Session::forget('command_id_new');
    //                            Session::put(['panier'=>0,'prix'=>0]);
    //                            Session::put('addedArticles',[]);
    //                            Session::put('commandes',[]);
    //                            //ENREGISTRER LA DERNIERE BOUTIQUE VISITER SI SOUSCRIPTION APRES CHOU
    //
    //                        }
    //                        if(Session::has('boutique')) {
    //                            $bouti = Session::get('boutique')['slug'];
    //                            if (Session::has('user')) {
    //                                $data['user_slug'] = Session::get('user')['slug'];
    //                            } else {
    //                                $data['user_slug'] = request()->ip();
    //                            }
    //                            $data['boutique_slug']=$bouti;
    //                            $data['nclick'] = 1;
    //                            check_boutiques::create($data);
    //                        }
    //    $url=\session()->has('url.intended')!=null ? \session()->get('url.intended') : route('home') ;
    //                        $message='Connexion établis avec succès. Vous serez redirigé vers une autre page dans quelques instant.';
    //                    }
    //                } else {
    //                    $error=true;
    //                    $message='Une erreur s\'est produite au cours de l\'authentification';
    //                }
    //                break;
    //            }
    //        }else{
    //            $error=true;
    //            $message='Cet Utilisateur n\'existe pas veuillez créer un compte utilisateur';
    //        }
    //        return json_encode(['error'=>$error,'message'=>$message,'url'=>$url]);
    //
    //    }

    public function client_register(Request $request)
    {
        $data = $request->all();
        if ($data['password'] != $data['cpassword']) {
            return ['error' => true, 'message' => "le mot de passe de confirmation n'est pas valide"];
        }
        $response = $this->register($request);
        $error = false;
        $message = '';
        if ($response['statut']) {
            $message = 'Inscription effectué avec succès veuillez vous connecter avec les informations précedemment saisis';
        } else {
            if (isset($response['input_error'])) {
                $error_input = '';
                for ($i = 0; $i < count($response['input_error']); $i++) {
                    foreach ($response['input_error'] as $key => $value) {
                        $error_input .= '<i class="fa fa-exclamation-circle"></i> ' . $value[0] . '  <br>';
                    }
                }
                $error = true;
                $message = $error_input;
            } else {
                $error = true;
                $message = $response['message'];
            }
        }
        return json_encode(['error' => $error, 'message' => $message]);
    }

    public function register(Request $request)
    {

        $data = $request->all();
        if (!isset($data['type'])) {
            $data['type'] = 'admin';
        }
        try {
            $rules = array(
                'first_name' => 'required|string',
                'telephone' => 'required|string',
                'sexe' => 'required|string',
                'last_name' => 'required|string',
                'email' => 'required|email|unique:users|max:255',
                'username' => 'required|string|unique:users|max:255',
                'password' => 'required|string|min:6',
                'privilege' => 'required|string'
            );
            $validator = \Illuminate\Support\Facades\Validator::make($request->all(), $rules);
            if ($validator->fails()) {
                $message = $validator->getMessageBag()->first();
                return ['statut' => false, "message" => $message];
            } else {
                $data['slug'] = Str::slug('user' . time());
                $data['telephone'] = $data['full_number'];
                $data['password'] = Hash::make($data['password']);
                $country = DB::table('countries')->where('id', $data['country'])->first();
                $region = DB::table('states')->where('id', $data['region'])->first();
                $continent = DB::table('continents')->where('Two_Letter_Country_Code', $country->iso2)->first();
                $city = DB::table('cities')->where('id', $data['city'])->first();
                if ($city != null) {
                    $data['city'] = $city->name;
                }
                $data['country'] = $country->name;
                $data['region'] = $region->name;
                $data['continent'] = $continent->Continent_Name;
                $user =  User::create($data);
                $subject = 'Inscription à sungrocery réussie';
                $messages = ['first_name' => $data['first_name'], 'last_name' => $data['last_name']];
                if (Session::has('command_id_new')) {
                    $cmd = Commandes::findOrFail(Session::get('command_id_new'));
                    $cmd->user_slug = $data['slug'];
                    $cmd->save();
                    Session::forget('command_id_new');
                    Session::put(['panier' => 0, 'prix' => 0]);
                    Session::put('addedArticles', []);
                    Session::put('commandes', []);
                    //ENREGISTRER LA DERNIERE BOUTIQUE VISITER SI SOUSCRIPTION APRES
                }
                if (Session::has('boutique')) {
                    $bouti = Session::get('boutique')['slug'];
                    if (Session::has('user')) {
                        $data['user_slug'] = Session::get('user')['slug'];
                    } else {
                        $data['user_slug'] = request()->ip();
                    }
                    $data['boutique_slug'] = $bouti;
                    $data['nclick'] = 1;
                    check_boutiques::create($data);
                }

                if ($user) {
                    /*  $data=$user;
                      $subject = 'Validation de votre email';
                      $messages = array('password' => $data['password'], 'username' => $data['username'], 'email' => $data['email'],'id'=>$data['id']);
                      $render = 2;
                      $objet = '';
                      $sendMail = MailController::SendMail($subject, $messages, $request['email'], $render);
                      $message='Compte Inactif! Un email vous à été envoyé pour la confirmation de votre compte';
                      $statut=true;
                    */
                    $privilegeSlug = ($data['privilege'] == 'utilisateur') ? 'utilisateur' : 'producteur';
                    Privilege_access::create(['user_fk_user_controle' => $user['id'], 'privilege_slug' => $privilegeSlug]);
                    MailController::SendRegisterMail($subject, $messages, $data['email']); 
                    return ['statut' => true, "message" => "Inscription effectuée avec succès"];
                } else {
                    return ['statut' => false, "message" => "Une erreur s'est produite au cours du processus. Veuillez réactualiser la page et reéssayer ou contacter l'équipe si le problème persite"];
                }
            }
        } catch (\Exception $e) {
            $message = $e->getMessage();
            return ['statut' => false, "message" => "Une erreur s'est produite au cours du processus. " . $message];
        }
    }

    public function register_for_boutique(Request $request)
    {
        $data = $request->all();
        if (!isset($data['type'])) {
            $data['type'] = 'admin';
        }
        try {
            $rules = array(
                'first_name' => 'required|string',
                'telephone' => 'required|string',
                'sexe' => 'required|string',
                'last_name' => 'required|string',
                'email' => 'required|email|unique:users|max:255',
                'username' => 'required|string|unique:users|max:255',
                'password' => 'required|string|min:6'
            );
            $validator = \Illuminate\Support\Facades\Validator::make($request->all(), $rules);
            if ($validator->fails()) {
                $message = $validator->getMessageBag()->first();
                return ['error' => true, "message" => $message];
            } else {
                $data['slug'] = Str::slug('user' . time());
                $data['telephone'] = $data['full_number'];
                $password = $data['password'];
                $data['password'] = Hash::make($data['password']);
                $country = DB::table('countries')->where('id', $data['country'])->first();
                $region = DB::table('states')->where('id', $data['region'])->first();
                $continent = DB::table('continents')->where('Two_Letter_Country_Code', $country->iso2)->first();
                $city = DB::table('cities')->where('id', $data['city'])->first();
                if ($city != null) {
                    $data['city'] = $city->name;
                }
                $data['country'] = $country->name;
                $data['region'] = $region->name;
                $data['continent'] = $continent->Continent_Name;
                $user =  User::create($data);
                $subject = 'Inscription à sungrocery réussie';
                $messages = ['first_name' => $data['first_name'], 'last_name' => $data['last_name']];
                MailController::SendRegisterMail($subject, $messages, $data['email']);
                if ($user) {
                    $credentials = [
                        'email' => $data['email'],
                        'password' => $password
                    ];
                    Privilege_access::create(['user_fk_user_controle' => $user['id'], 'privilege_slug' => 'utilisateur']);
                    if (Auth::attempt($credentials)) {
                        Session::put('user', Auth::user());
                        $error = false;
                        $message = 'Inscription validée. Connexion établie avec succès. ';
                    } else {
                        $error = true;
                        $message = 'Une erreur s\'est produite au cours de l\'authentification';
                    }
                    return ['error' => $error, "message" => $message];
                } else {
                    return ['error' => true, "message" => "Une erreur s'est produite au cours du processus. Veuillez réactualiser la page et reéssayer ou contacter l'équipe si le problème persite"];
                }
            }
        } catch (\Exception $e) {
            $message = $e->getMessage();
            return ['error' => true, "message" => "Une erreur s'est produite au cours du processus. " . $message];
        }
    }

    public function confirm_account($id)
    {

        $satut = true;
        $message = '';
        $methode = new EnseigneController();
        $user = Sentinel::findById($id);

        $activation = Activation::create($user);

        if ($activation) {
            if (Activation::complete($user, $activation['code'])) {
                Privilege_access::create(['user_fk_user_controle' => $id, 'privilege_slug' => 'utilisateur']);
                $message = 'Confirmation effectué';
                $statut = true;
            } else {
                $message = 'Un problème est survenue lors de la confirmation de votre compte';
                $statut = true;
            }
        } else {

            $message = 'Une erreur s\'est produite lors de la validation de votre compte';
            $statut = true;
        }

        //$response=json_encode(['statut'=>$statut,'message'=>$message,'data'=>$user]);

        return Response::json(['statut' => $statut, 'message' => $message, 'data' => $user]);
    }

    public function generateRandomString($length = 6)
    {
        $characters = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
        $charactersLength = strlen($characters);
        $randomString = '';
        for ($i = 0; $i < $length; $i++) {
            $randomString .= $characters[random_int(0, $charactersLength - 1)];
        }
        return $randomString;
    }

    public function resetPass(Request $request)
    {
        $data = $request->all();
        $user = User::where('email', $data['email'])->orwhere('username', $data['email'])->first();
        if ($user != null) {
            $subject = 'Récupération de votre mot de passe';
            $newpass = Str::slug($this->generateRandomString());
            $messages = ['email' => $user['email'], 'password' => $newpass];
            $users = User::findOrFail($user['id']);
            $users->password = Hash::make($newpass);
            $users->save();
            $render = 2;
            MailController::SendPassMail($subject, $messages, $user['email'], $render);
            Log::info(['email' => $user['email'], 'password' => $newpass]);
            Session::flash('success', 'Le nouveau mot de passe a été envoyé à ce mail : ' . $user['email']);
            return redirect('login');
        }
        Session::flash('error', 'Nous ne parvenons pas à envoyez un mail sur l\'adresse mail ou le nom d\'utilisateur fournis. Verifiez que vous avez déjà un compte ou que votre adresse mail est valide. Veuillez rafraichir la page avant de soumettre une autre requête.');
        return back();
    }

    public function resetPassBoutique(Request $request)
    {
        try {
            $data = $request->all();
            return json_encode($data);
            $user = User::where('email', $data['email'])->orwhere('username', $data['email'])->first();
            if ($user != null) {
                $subject = 'Récupération de votre mot de passe';
                $newpass = Str::slug($this->generateRandomString());
                $messages = ['email' => $user['email'], 'password' => $newpass];
                $users = User::findOrFail($user['id']);
                $users->password = Hash::make($newpass);
                $users->save();
                $render = 2;
                MailController::SendPassMail($subject, $messages, $user['email'], $render);
                Log::info(['email' => $user['email'], 'password' => $newpass]);
                return ['error' => false, 'message' => 'Le nouveau mot de passe a été envoyé à ce mail :' . $user['email']];
            }
            return ['error' => true, 'message' => 'Nous ne parvenons pas à envoyez un mail sur l\'adresse mail ou le nom d\'utilisateur fournis. Verifiez que vous avez déjà un compte ou que votre adresse mail est valide.' . $data['email'] . '  Veuillez rafraichir la page avant de soumettre une autre requête.'];
        } catch (\Exception $e) {
            return ['error' => true, 'message' => $e->getMessage()];
        }
    }

    public function resetNewPassord(Request $request)
    {
        $data = $request->all();
        $user = User::all()->where('slug', $data['email'])->first();
        if (Hash::check($data['incomepassword'], $user['password'])) {
            if ($user) {
                $user->password = Hash::make($data['password']);
                $user->save();
                Session::flash('success', 'Votre mot de passe à été mis à jour avec succès.');
                return redirect('login');
            }
        } else {
            Session::flash('error', 'Une erreur s\'est produite au cours de la mise à jour de votre mot de passe. Si vous avez déjà cliquer une fois sur le lien envoyer sur votre mail, vous devez en generer une autre en suivant à nouveau l\'étape de recupération de votre mot de passe.');
        }
        return back();
    }

    public function resetPassView()
    {
        return view('dashboard.Boutique.password_forget');
    }

    public function resetPassPanel($email, $password)
    {
        return view('dashboard.Boutique.reset_password', compact('email', 'password'));
    }
}
