<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Mail;
use Mockery\Exception;

class MailController extends Controller
{
    static function SendMail($subject,$messages,$email,$render){
        try{
            $sms=array('msg'=>$messages,'render'=>$render);
            Mail::send('Mail.register_confirm', $sms, function($message) use($email,$subject){
                $message->to($email, 'Utilisateur')->subject
                ($subject);
            });
        }catch (Exception $e){
            Log::info(["email error send Mail"=>$e->getMessage()]);
            return false;
        }
    }

    static function RecommandationMail($subject,$messages,$email){
        try{
            $sms=$messages;
            Mail::send('Mail.recommandation', $sms, function($message) use($email,$subject){
                $message->to($email, 'Utilisateur')->subject
                ($subject);
            });
        }catch (Exception $e){
            Log::info(["email error send Mail"=>$e->getMessage()]);
            return false;
        }
    }

    static function AlertAddProductMail($subject,$messages,$email){
        try{
            $sms=$messages;
            Mail::send('Mail.add_articles', $sms, function($message) use($email,$subject){
                $message->to($email, 'Utilisateur')->subject
                ($subject);
            });
        }catch (Exception $e){
            Log::info(["email error send Mail"=>$e->getMessage()]);
            return false;
        }
    }

    static function AlertAskPromotionMail($subject,$messages,$email){
        try{
            $sms=$messages;
            Mail::send('Mail.ask_investment_project_allow', $sms, function($message) use($email,$subject){
                $message->to($email, 'Utilisateur')->subject
                ($subject);
            });
        }catch (Exception $e){
            Log::info(["email error send Mail"=>$e->getMessage()]);
            return false;
        }
        
    }

    static function SendPassMail($subject,$messages,$email,$render){
        try{
            $sms=array('msg'=>$messages,'render'=>$render);
            Mail::send('Mail.reset_pass', $sms, function($message) use($email,$subject){
                $message->to($email, 'Utilisateur')->subject
                ($subject)->from(env('MAIL_USERNAME'),'SUNGROCERY');
            });
        }catch (Exception $e){
            Log::info(["email error send Mail"=>$e->getMessage()]);
            return false;
        }
    }


    static function html_email($name,$email,$title,$code) {
        try{
            $data = array('name'=>$name,'email'=>strtolower($email),'title'=>$title,'code'=>$code,);
             Mail::send('Mail.sgi.mail', $data, function($message) use ($data) {
                $message->to($data['email'], $data['name'])->subject
                ($data['title'])->from(env('MAIL_USERNAME'),'sungrocery investissement');
            }); 
            return true;
        }catch (Exception $e){
            Log::info(["email error"=>$e->getMessage()]);
            return false;
        }
    }

    static function html_email_confirmation($name,$email,$title) {
        try{
            $data = array('name'=>$name,'email'=>strtolower($email),'title'=>$title);
            Mail::send('Mail.sgi.mail_confirmation', $data, function($message) use ($data) {
                $message->to($data['email'], $data['name'])->subject
                ($data['title'])->from(env('MAIL_USERNAME'),'sungrocery investissement');
            });
            return true;
        }catch (Exception $e){
            Log::info(["email error"=>$e->getMessage()]);
            return false;
        }
    }

    static function SendRegisterMail($subject,$messages,$email){
        try{
            $sms=array('msg'=>$messages);
            Mail::send('Mail.register_confirm', $sms, function($message) use($email,$subject){
                $message->to($email, 'Utilisateur')->subject
                ($subject)->from(env('MAIL_USERNAME'),'SUNGROCERY');
            });
        }catch (Exception $e){
            Log::info(["email error send Mail"=>$e->getMessage()]);
            return false;
        }    
    }

    static function SendPortefeuilleMail($subject,$messages,$email){
        try{
            $sms=array('msg'=>$messages);
            Mail::send('Mail.portefeuille', $sms, function($message) use($email,$subject){
                $message->to($email, 'Utilisateur')->subject
                ($subject)->from(env('MAIL_USERNAME'),'SUNGROCERY');
            });
        }catch (Exception $e){
            Log::info(["email error send Mail"=>$e->getMessage()]);
            return false;
        }
    }

    static function SendGeneralUniqueMail($template,$subject,$messages,$email,$from)
    {
        try{
            $sms = array('msg' => $messages);
            Mail::send($template, $sms, function ($message) use ($email, $subject, $from) {
                $message->to($email, 'Utilisateur')->subject
                ($subject)->from($from, 'SUNGROCERY');
            });
        }catch (Exception $e){
            Log::info(["email error send Mail"=>$e->getMessage()]);
            return false;
        }
    }
    static function SendMultipleGeneralUniqueMail($template,$subject,$messages,$email,$from){
        try{
            $sms=array('msg'=>$messages);
            Mail::send($template, $sms, function($message) use($email,$subject,$from){
                $message->to($email)->subject
                ($subject)->from($from,'SUNGROCERY');
            });
        }catch (Exception $e){
            Log::info(["email error send Mail"=>$e->getMessage()]);
            return false;
        }
    }
    static function SendGeneralUniqueMailWithAttachement($template,$subject,$messages,$email,$from,$file,$filename){
        try{
            $sms=array('msg'=>$messages);
            Mail::send($template, $sms, function($message) use($email,$subject,$from,$file,$filename){
                $message->to($email, 'prestataire de service')->subject
                ($subject)->from($from,'SUNGROCERY')->attach($file, [
                    'as' => $filename,
                    'mime' => 'application/pdf',
                ]);
            });
        }catch (Exception $e){
            Log::info(["email error send Mail"=>$e->getMessage()]);
            return false;
        }
    }

}
