<?php

namespace App\Http\Controllers;

use App\Boutique;
use App\MarchandShippingInformations;
use App\MoyenLivraison;
use App\PlantarifaireShippings;
use App\ServiceShipping;
use App\ShopShipping;
use Barryvdh\DomPDF\Facade as PDF;
use Illuminate\Http\Request;
use Illuminate\Support\Carbon;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Str;
use Mockery\Exception;

class MoyenLivraisonController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $pays = DB::table('countries')->get();
        $services = ServiceShipping::all();
        return view('dashboard.MoyenLivraisons.index',compact('pays','services'));
    }

    public function shipping_informations(Request $request){
        try {
            $data = $request->all();
            $check = MarchandShippingInformations::where('boutique_slug', $data['boutique_slug'])->first();
            DB::table('marchand_shipping_informations')->where('boutique_slug', $data['boutique_slug']);
            if ($check != null) {
                unset($data['_token']);
                DB::table('marchand_shipping_informations')->update($data);
            } else {
                MarchandShippingInformations::create($data);
            }
            return back()->with('success', 'Configuration effectuée avec succès');
        }catch (\Exception $e){
            return back()->with('error', 'Une erreure s\'est produite au cours de la configuration '.$e->getMessage());
        }
    }

public function guideTarifaire($slug)
    {
        $pays = DB::table('countries')->get();
        $service =DB::table('service_shippings')->where('slug',$slug)->first();
        $grilles = PlantarifaireShippings::where('service_slug',$slug)->get();
        return view('dashboard.MoyenLivraisons.guideTarifaire',compact('pays','grilles','service'));
    }

public function guideTarifaireClient($slug,$shop)
    {
        $shop = Boutique::with('meta')->where('slug', $shop)->first();
        if($shop['shipping_local'] || $shop['shipping_international']) {
            $pays = DB::table('countries')->get();
        $service =DB::table('service_shippings')->where('slug',$slug)->first();
        $grilles = PlantarifaireShippings::where('service_slug',$slug)->where('countries', 'like', '%' . $shop['meta']['country'] . '%')->get();
        return view('dashboard.MoyenLivraisons.ClientguideTarifaire',compact('pays','grilles','service'));
        }else{
            return back()->with('error','Vous devez activé l\'option livraison locale ou internationnal dans le menu option de votre boutique pour accéder à cette page');
        }
    }

    public function ShopShipping($slug)
    {
        if(!Session::has('boutique')){
            return redirect('boutique');
        }
        $shop = Boutique::with('meta','user')->where('slug', $slug)->first();
        $pays = DB::table('countries')->get();
        if($shop['shipping_local'] || $shop['shipping_international']) {
            if ($shop['meta']['internationalize']) {
                $services = ServiceShipping::whereHas('plan_tarifaire', function ($q) use ($shop) {
                    $q->where('countries', 'like', '%' . $shop['meta']['country'] . '%');
                })
                    ->with(['shop_shipping' => function ($q) use ($shop) {
                        $q->where('shop_slug', $shop->slug);
                    }])->get();
            } else {
                $services = ServiceShipping::whereHas('plan_tarifaire', function ($q) use ($shop) {
                    $q->where('countries', 'like', '%' . $shop['meta']['country'] . '%');
                })
                    ->with(['shop_shipping' => function ($q) use ($shop) {
                        $q->where('shop_slug', $shop->slug);
                    }])->where('type', 'locale')->get();
            }

            $shippingInfos= DB::table('marchand_shipping_informations')->where('boutique_slug', $shop['slug'])->first();

            return view('dashboard.MoyenLivraisons.ClientIndex',compact('services','pays','shop','shippingInfos'));
        }else{
            return back()->with('error','Vous devez activé l\'option livraison locale ou internationnal dans le menu option de votre boutique pour accéder à cette page');
        }
    }

    public function addShippingToShop(Request $request){
        try {
            $data = $request->all();
            $shop = $data['boutique_slug'];
            $slug = $data['service_slug'];
            $services = ServiceShipping::where('slug', $slug)->first();
            $shippingInfos= DB::table('marchand_shipping_informations')->where('boutique_slug', $shop)->first();
            $boutique = DB::table('boutiques')->where('slug', $shop)->first();
            $boutiqueRelate = Boutique::with('meta','user','metier')->where('slug', $shop)->first();
            $name = 'contrat_' . strtolower(str_replace(' ', '', $boutique->nom_boutique)) . '.pdf';
            try {
                $pdf = PDF::loadHtml($data['contrat']);
                $pdf->save(public_path('/Contrats/' . $name));
            } catch (\Dompdf\Exception $e) {
                return back()->with('error', 'Une erreure s\'est produite au cours de l\'jout '.$e->getMessage());
            }
            DB::table('shop_shippings')->insert(['service_slug' => $slug, 'shop_slug' => $shop, 'status' => true, 'created_at' => Carbon::now(), 'contrat' => $data['contrat'], 'contrat_pdf' => $name]);

            try{
                $template='Mail.contrat_prestation';$subject="Contrat de prestation de service";$email=$services->email;$from=env('MAIL_USERNAME');$file=public_path('/Contrats/' . $name);$filename=$name;
                $messages=['agence'=>$services->name,'name'=>$boutique->nom_boutique,'depart'=>$shippingInfos->depart,'description'=>$shippingInfos->Description,'adresse'=>$shippingInfos->adresse,'tel'=>$boutiqueRelate->meta->telephone_boutique,'first_name'=>$boutiqueRelate->user->first_name,'last_name'=>$boutiqueRelate->user->last_name,'metier'=>$boutiqueRelate->metier->intitule_metier];
                $mail=new MailController();
              //send to agence
                $mail->SendGeneralUniqueMailWithAttachement($template,$subject,$messages,$email,$from,$file,$filename);
               //send to client
                $mail->SendGeneralUniqueMailWithAttachement('Mail.contrat_prestation_client',$subject,$messages,$boutiqueRelate->meta->email_boutique,$from,$file,$filename);
            }catch (\Exception $e){
                return back()->with('error', 'Une erreure s\'est produite au cours de l\'ajout '.$e->getMessage());
            }
            return back()->with('success', 'Service de livraison ajouté avec succès. Vos clients pourrons desormais être livré via se service.');
        }catch (\Exception $e){
            return back()->with('error', 'Une erreure s\'est produite au cours de l\'ajout '.$e->getMessage());
        }
        }

    public function removeShippingShop($slug,$shop){
        DB::table('shop_shippings')->where("service_slug",$slug)->where('shop_slug',$shop)->delete();
        return back()->with('success','Service de livraison retirer. Vos clients ne pourrons plus desormais être livré via se service.');
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        try {
            $data = $request->all();
            $check_existing=DB::table('service_shippings')->where('name','like','%'.$data['name'].'%')->count();
           if($check_existing<=0){
               $service = [];
               $filename = '';
               if ($request->hasfile('logo')) {
                   $file=$request->file('logo');
                   $path = public_path('images/services/logo/');
                   $ifFilename = $data['name'] .'.'. $file->getClientOriginalExtension();
                   $file->move($path, $ifFilename);
                   $filename = asset('images/services/logo/'.$ifFilename);
               }
               $country=DB::table('countries')->where('name',$data['country'])->first();
               $service['country'] = $country->name;
               $service['adress'] = $data['adress'];
               $service['name'] = $data['name'];
               $service['logo'] = $filename;
               $service['tel'] = $data['tel'];
               $service['email'] = $data['email'];
               $service['status'] = true;
               $service['type'] = $data['type'];
               $service['slug'] = Str::slug('service_shipping' . time());
               $service['created_at']=Carbon::now();
               $services = DB::table('service_shippings')->insert($service);
               $slug=$service['slug'];
           }else{
               $services=DB::table('service_shippings')->where('name','like','%'.$data['name'].'%')->first();
               $slug=$services->slug;
           }
            $plan = [];
                if ($request->hasfile('filename')) {
                    $i = 0;
                    $filename='';
                    foreach ($request->file('filename') as $file) {
                        if ($file) {
                            $path = public_path('images/services/shipping/');
                            $ifFilename = $data['name'] .'-'.implode('-',$data['countries']) .'.'. $file->getClientOriginalExtension();
                            $file->move($path, $ifFilename);
                            $filename = asset('images/services/shipping/'. $ifFilename) ;
                        }
                        $countries=DB::table('countries')->whereIn('name',$data['countries'][$i])->pluck('name')->toArray();
                        array_push($plan, [
                            'service_slug' => $slug,
                            'countries' => json_encode($countries),
                            'filename' => $filename,
                            'status' => true
                        ]);
                        $i++;
                    }
                    DB::table('plantarifaire_shippings')->insert($plan);
                }
            return back()->with('success','Plan tarifaire uploader avec succès');
        }catch (Exception $e){
            return back()->with('error','Une erreur s\'est produite '.$e);
        }
    }

    public function storePlanTarifaire(Request $request){
        try {
            $plan = [];
            $data=$request->all();
            $slug=$data['service_slug'];
            if ($request->hasfile('filename')) {
                $i = 0;
                $filename = '';
                foreach ($request->file('filename') as $file) {
                    if ($file) {
                        $path = public_path('images/services/shipping/');
                        $ifFilename = time() . $slug .'.'. $file->getClientOriginalExtension();
                        $file->move($path, $ifFilename);
                        $filename = asset('images/services/shipping/' . $ifFilename);
                    }
                   $countries = DB::table('countries')->whereIn('name', $data['countries'])->pluck('name')->toArray();
                    array_push($plan, [
                        'service_slug' => $slug,
                        'countries' => json_encode($countries),
                        'filename' => $filename,
                        'status' => true
                    ]);
                    $i++;
                }
                DB::table('plantarifaire_shippings')->insert($plan);
            }
            return back()->with('success', 'Plan tarifaire uploader avec succès');
        }catch (Exception $e){
            return back()->with('error','erreur '.$e->getMessage());
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\MoyenLivraison  $livraison
     * @return \Illuminate\Http\Response
     */
    public function show(MoyenLivraison $livraison)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\MoyenLivraison  $livraison
     * @return \Illuminate\Http\Response
     */
    public function edit($livraison_id)
    {
        $moyen_livraison = MoyenLivraison::find($livraison_id);
        if ($moyen_livraison->type == env('LIVRAISON_INTERNATIONALE')){
            $pays_destination_ids = DB::table('countries')
                ->whereIn('name',json_decode($moyen_livraison->pays_destination))
                ->pluck("id")->toArray();
            $pays_provenance_id = DB::table('countries')
                ->where('name',$moyen_livraison->pays_provenance)
                ->first()
                ->id;
                $pays = DB::table('countries')->get();
                return [
                    'moyen'=>$moyen_livraison,
                    'pays_destination_ids'=>$pays_destination_ids,
                    'pays_provenance_id'=>$pays_provenance_id
                    ];
        }else{
            $ville_ids = DB::table('cities')
                ->whereIn('name',json_decode($moyen_livraison->ville))
                ->pluck("id")->toArray();
            $region_id = DB::table('states')
                ->where('name',$moyen_livraison->region)
                ->first()
                ->id;
            $pays_id = DB::table('countries')
                ->where('name',$moyen_livraison->pays)
                ->first()
                ->id;
            $regions = DB::table('states')->where('country_id',$pays_id)->get();
            $villes = DB::table('cities')->where('state_id',$region_id)->get();
            $region_view = view("dashboard.MoyenLivraisons.partials.regions",compact("regions"))->render();
            $ville_view =  view("dashboard.MoyenLivraisons.partials.villes",compact("villes"))->render();

            return [
                "moyen"=>$moyen_livraison,
                "pays_id"=>$pays_id,
                "region_id"=>$region_id,
                "ville_ids"=>$ville_ids,
                "region_html"=>$region_view,
                "ville_html"=>$ville_view
                ];
        }
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\MoyenLivraison  $livraison
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, MoyenLivraison $livraison)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\MoyenLivraison  $livraison
     * @return \Illuminate\Http\Response
     */
    public function destroy(MoyenLivraison $livraison)
    {
        //
    }
    public function getRegionsPays($pays_id){
        $regions = DB::table('states')->where('country_id',$pays_id)->get();
        return view("dashboard.MoyenLivraisons.partials.regions",compact("regions"))->render();

    }

    public function getVillesRegion($region_id){
        $villes = DB::table('cities')->where('state_id',$region_id)->get();
        return view("dashboard.MoyenLivraisons.partials.villes",compact("villes"))->render();

    }
}
