<?php

namespace App\Http\Controllers;

use App\Boutique;
use App\Partenaire;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Response;
use Illuminate\Support\Facades\Validator;

class PartenaireController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $partenaire = Partenaire::with('boutique')->get();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        try{
            $data = $request->all();
            $rules = [
                'nom'=>'required',
                'logo'=>'required|mimes:jpeg,png,gif,jpg',
                'boutique_id'=>'required'
            ];
            $validator = Validator::make($request->all(),$rules);
            if ($validator->fails()){
                return back()->withErrors($validator);
            }
            $boutique= Boutique::find($request->boutique_id);
            $logoName = $boutique->slug.'-part-logo-'.time().'.'.$request->logo->getClientOriginalExtension();
            $request->logo->move(public_path('images/boutiques/partenaires/logos/'),$logoName);
            $slug  = str_slug('part '.$boutique->slug.' '.str_random(4),'-');
            $data['slug'] = $slug;
            $data['logo']=asset('images/boutiques/partenaires/logos/'.$logoName);
            $partenaire = Partenaire::create($data);
            return back()->with('success','Nouveau partenaire ajouté');
        }catch (\Exception $exception){
            return back()->with('error',$exception->getMessage());
        }


    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Partenaire  $partenaire
     * @return \Illuminate\Http\JsonResponse
     */
    public function show($slug)
    {
        $partenaire  = Partenaire::with('boutique')->where('slug',$slug)->first();

        return Response::json($partenaire);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Partenaire  $partenaire
     * @return \Illuminate\Http\Response
     */
    public function edit($slug)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Partenaire  $partenaire
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $slug)
    {
        $partenaire  = Partenaire::with('boutique')->where('slug',$slug)->first();
        try{
            $rules = [
                'nom'=>'required',
                'logo'=>'required|mimes:jpeg,png,gif,jpg',
                'boutique_id'=>'required'
            ];

            $validator = Validator::make($request->all(),$rules);

            if ($validator->fails()){
                return back()->withErrors($validator);
            }
            $boutique= Boutique::find($request->boutique_id);

            if (isset($request->logo)){
                $logoName = $boutique->slug.'-part-logo-'.time().'.'.$request->logo->getClientOriginalExtension();

                $request->logo->move(public_path('images/boutiques/partenaires/logos/'),$logoName);
                $partenaire->logo = asset('images/boutiques/partenaires/logos/'.$logoName);

            }

            $partenaire->boutique_id = $request->boutique_id;
            $partenaire->nom = $request->nom;
            $partenaire->description = $request->description;

            $partenaire->save();

            return back()->with('success','Mis à jour effectué');


        }catch (\Exception $exception){
            return back()->with('error',$exception->getMessage());
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Partenaire  $partenaire
     * @return \Illuminate\Http\Response
     */
    public function destroy($slug)
    {
        $partenaire  = Partenaire::with('boutique')->where('slug',$slug)->first();

        $partenaire->delete();

        return back()->with('success','Partenaire supprimé');

    }
}
