<?php

namespace App\Http\Controllers\PointVente;

use App\Annonce;
use App\Boutique;
use App\PointVente;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Session;
use Intervention\Image\Facades\Image;

class PointVenteController extends Controller
{
    public function index($slug){
        $boutique = Boutique::whereSlug($slug)->first();
        $pointVentes = PointVente::where("boutique_id",$boutique->id)->orderByDesc("id")->get();
        return view("dashboard.Boutique.pointVente.index",compact("boutique","pointVentes"));
    }

    public function add_up(Request $request)
    {
        $data = $request->all();
        try {
            $rules = array(
                'nom' => 'required',
                'adresse' => 'required',
                'horaire' => 'required|string',
            );

            $validator = \Illuminate\Support\Facades\Validator::make($request->all(), $rules);
            if ($validator->fails()) {
                return back()->withErrors($validator)->withInput();
            }
            unset($data["action"]);
            unset($data["boutique_slug"]);
            $boutique = Boutique::whereSlug($request->boutique_slug)->first();
            $data["boutique_id"] = $boutique->id;
//            if ($request->image){
//                $time = time();
//                $originalImage = $request->image;
//                $thumbnailImage = Image::make($originalImage);
//                $originalPath = public_path('Uploads/pointVentes/');
//                $location = $originalPath . $time . $originalImage->getClientOriginalName();
//                $thumbnailImage->save($originalPath . $time . $originalImage->getClientOriginalName());
//                $filename = $time . $originalImage->getClientOriginalName();
//                $data['image'] = asset('Uploads/pointVentes/' . $filename);
//            }
            if (!isset($data['id'])) {
                $data['slug'] = "pv_".Annonce::generate_slug_for_table("point_ventes");
                $return = PointVente::create($data);
                if (isset($return->id)) {
                    Session::flash('success', 'Votre point de vente est désormais disponible sur '.Boutique::formatName($boutique->nom_boutique));
                } else {
                    Session::flash('error', 'Un  problème est survenue au cours du processus de publication de l\'annonce ');
                }
            } else {
                unset($data["id"]);
                $return = PointVente::find($request->id)->update($data);
                if ($return) {
                    Session::flash('success', 'Votre point de vente a été modifié sur grocery');
                } else {
                    Session::flash('error', 'Un  problème est survenue au cours du processus de modification de l\'annonce ');
                }
            }

        } catch (\Exception $e) {
            Session::flash('error', 'Un  problème est survenue au cours de l\'exécution du processus ' . $e);
        }
        return back();

    }

    public function get_pointvente(Request $request)
    {
        try {
            $pv = PointVente::whereSlug($request->slug)->first();
            return ["data" => $pv, "msg" => "data", "error" => false];
        } catch (\Exception $e) {
            return ["data" => null, "msg" => $e->getMessage(), "error" => true];
        }

    }

    public function delete_pointvente($slug)
    {
        try {
            PointVente::whereSlug($slug)->delete();
            Session::flash('success', 'Votre point de vente a été supprimé sur grocery');
        } catch (\Exception $e) {
            Session::flash('error', 'Un  problème est survenue au cours de l\'exécution du processus ' . $e);
        }
        return back();

    }

    public static function checkLocation($location)
    {
        $location = array_filter(explode('/', $location));
        $path = public_path();

        foreach ($location as $key) {
            $path .= "/$key";

            if (is_dir($path) != true) {
                mkdir($path, 0775, true);
            }
        }
    }
}
