<?php

namespace App\Http\Controllers;

use App\ArticleProducteur;
use Illuminate\Support\Str;
use Illuminate\Http\Request;
use App\AbonnementProducteur;
use Illuminate\Support\Facades\Session;

class ProductorArticleController extends Controller
{

    public function article_supplier_index()
    {
        $user = auth()->user();
        $categories = \App\CategorieCatalogue::all();
        $abonnement = \App\AbonnementProducteur::where('user_id', $user->id)->where('is_current', 1)->first();
        $etatCatalogue = \App\EtatCatalogueAbonnement::where('corbeil', false)->get();
        $producerPercentage = \App\ProducerPercentage::first();
        $articleProducteur = \App\ArticleProducteur::where('user_id', $user->id)->with('categorie')->get();

        foreach ($articleProducteur as $article) {
            $articles = \App\CatalogueArticles::where('article_slug', $article->slug)->with('boutique')->get();
            $article->articles = $articles->toArray(); 
            $article->nombre_achats = \App\CommandArticle::where('article_slug', $article->slug)->sum('quantity');
        }

        // dd($articleProducteur, $producerPercentage);

        return view('dashboard.CataloguesProducteur.articles', compact('categories', 'articleProducteur', 'abonnement', 'etatCatalogue', 'producerPercentage'));
    }

    public function  create_article(Request $request)
    {
        
        try {
            // DB::beginTransaction();
            $validatedData = $request->validate([
                'categorie_slug' => 'nullable|string',
                'reference' => 'required|string',
                'name' => 'required|string',
                'price' => 'required|numeric',
                'quantity' => 'required|integer',
                'maker' => 'required|string',
                'maker_country' => 'required|string',
                'create' => 'nullable|date',
                'expire' => 'nullable|date',
                'description' => 'nullable|string',
            ]);

            $data = $request->all();
            // $data['transaction_id'] = $data['response']['transactionId'];
            // $public_key = env('INTRAM_PUBLIC');
            // $secret = env('INTRAM_SECRET');
            // $private_key = env('INTRAM_PRIVATE');
            // $intram = new \Intram\Intram($public_key, $private_key, $secret, env('INTRAM_SANDBOX') == '1');
            // $transaction_id = $data['transaction_id'];
            // $verify = $intram->getTransactionStatus($transaction_id);
            // $status = $verify->status;
            
            // if ($status == 'SUCCESS') {
            // }
            // dd($data, $validatedData);
            $user = auth()->user();

            $lastSubscriber = AbonnementProducteur::where('user_id', $user->id)->where('is_current', 1)->first();
            
            
            $validatedData['user_id'] = $user->id;
            $validatedData['slug'] = Str::slug(time() . 'article');
            $fileNameToStore = '';
            if ($request->hasFile('images')) {
                $fileNameWithExt = $request->file('images')->getClientOriginalName();
                $fileName = pathinfo($fileNameWithExt, PATHINFO_FILENAME);
                $extension = $request->file('images')->getClientOriginalExtension();
                $fileNameToStore = $fileName.'_'.time().'.'.$extension;
                // $fileNameToStore = time() . '.' . $extension;
                $validatedData['file'] = $fileNameToStore;
                $path = $request->file('images')->storeAs('public/productor_products', $fileNameToStore);
            }
            $articleProducteur = ArticleProducteur::create($validatedData);
            if ($lastSubscriber) {
                $lastSubscriber->remaining_publication = $lastSubscriber->remaining_publication - 1;
                $lastSubscriber->save();
            }
            // DB::commit();
            if (!isset($articleProducteur)) {
                Session::flash('error', 'une erreur s\'est produite lors de l\'ajout du produit ' . $articleProducteur['name'] . ' à votre catalogue.');
            } else {
                Session::flash('success', 'Le produit ' . $articleProducteur['name'] . ' à été ajouté à votre catalogue avec succès.');
            }
            return back();

            // return response()->json(['status' => 1, 'message' => 'Produit ajouté avec succès', 'articleProducteur' => $articleProducteur]);
        } catch (\Exception $th) {
            // DB::rollBack();
            // return response()->json(['status' => 0, 'message' => 'Erreur inatendue']);
            return back()->with('error', 'Une erreur s\'est produite ' . $th->getMessage() . ' ' . $th->getLine());
        }
    }

    public function get_producteur_articles($productor_id){
        $article = ArticleProducteur::where('user_id', $productor_id)->where('corbeil', 0)->get();
        return json_encode($article);
    }

    // public function get_producteur_categorie($categorie_slug){
    //     dd($categorie_slug);
    //     // $article = ArticleProducteur::where('user_id', $productor_id)->where('corbeil', 0)->get();
    // }

    public function get_productor_by_categorie($productor_id)
    {
        $products = ArticleProducteur::where('user_id', $productor_id)->paginate(10);
        return response()->json($products);
    }

    public function get_article($slug)
    {
        $article = ArticleProducteur::where('slug', $slug)->first();
        return json_encode($article);
        // return response()->json(['status' => 1, 'article' => $article]);
    }

    public function update(Request $request, $slug)
    {
        $data = $request->all();
        $article = ArticleProducteur::where('slug', $slug)->first();
        $articleProducteur = $article->update($data);

        if (!isset($articleProducteur)) {
            Session::flash('error', 'Un problème est survenu au cours de la mise à jour du produit ' . $data['name']);
        } else {
            Session::flash('success', 'Le produit ' . $data['name'] . ' à été mis à jour avec succès');
        }
        return back();
    }

    public function delete_article($slug)
    {
        $article_find = ArticleProducteur::where('slug', $slug)->first();
        $article_find->corbeil = true;
        $reponse = $article_find->save();
       
        if (!isset($reponse)) {
            Session::flash('error', 'Une erreur s\'est produite au cours de la supression du produit ' . $article_find['name']);
        } else {
            Session::flash('success', 'Le produit ' . $article_find['name'] . ' à été supprimer avec succès.');
        }
        return back();
    }

    public function active_article($slug)
    {
        $article_find = ArticleProducteur::where('slug', $slug)->first();
        $article_find->corbeil = false;
        $reponse = $article_find->save();
       
        if (!isset($reponse)) {
            Session::flash('error', 'Une erreur s\'est produite au cours de l\'activation du produit ' . $article_find['name']);
        } else {
            Session::flash('success', 'Le produit ' . $article_find['name'] . ' à été activé avec succès.');
        }
        return back();
    }

    public function history(){
        $user = auth()->user();
        $categories = \App\CategorieCatalogue::all();
        $abonnement = \App\AbonnementProducteur::where('user_id', $user->id)->where('is_current', 1)->first();
        $etatCatalogue = \App\EtatCatalogueAbonnement::where('corbeil', false)->get();
        $producerPercentage = \App\ProducerPercentage::first();
        $articleProducteur = \App\ArticleProducteur::where('user_id', $user->id)->where('corbeil', false)->get();

        $histories = \App\ProducerGain::where('productor_slug', $user->slug)->with('marchant', 'productor', 'article')->get();
        // dd($histories);
        foreach ($articleProducteur as $article) {
            $articles = \App\CatalogueArticles::where('article_slug', $article->slug)->with('boutique')->get();
            $article->articles = $articles->toArray(); // Convertir en tableau
        }


        return view('dashboard.CataloguesProducteur.historique',  compact('articleProducteur', 'producerPercentage', 'histories'));
    }

}
