<?php

namespace App\Http\Controllers;

use App\Boutique;
use App\Publicite;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Validator;
use Intervention\Image\Facades\Image;

class PubliciteController extends Controller
{


    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $data = $request->all();
        try{
            $rules = [
                'image_pub'=>'required|mimes:jpeg,png,gif,jpg',
                'boutique_id'=>'required'
            ];

                $validator = Validator::make($request->all(), $rules);
                if ($validator->fails()) {
                    return back()->withErrors($validator);
                }
                $boutique = Boutique::find($request->boutique_id);
                $originalImage = $request->image_pub;
                $thumbnailImage = Image::make($originalImage);
                $thumbnailPath = public_path('images/boutiques/Publicites/images/');
                $time = time();
//                $thumbnailImage->resize(1600, 400);
                $thumbnailImage->save($thumbnailPath . $time .'.'.strtolower(str_replace(' ','_',$originalImage->getClientOriginalExtension())));
                $filename = $time .'.'. strtolower(str_replace(' ','_',$originalImage->getClientOriginalExtension()));

//                $request->image_pub->move(public_path('images/boutiques/Publicites/images/'), $filename);
                $slug = str_slug('pub ' . $boutique->slug . ' ' . str_random(4), '-');
                $data = array_add($data, 'slug', $slug);
                $data = array_add($data, 'image', asset('/images/boutiques/Publicites/images/' . $filename));
                $Publicite = Publicite::create($data);
                return back()->with('success', 'Mise à jour effectuée . Votre banière est maintenant visible à vos clients.');
        }catch (\Exception $exception){
            return back()->with('error',$exception->getMessage());
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Publicite  $publicite
     * @return \Illuminate\Http\Response
     */

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Publicite  $publicite
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $slug)
    {

            $publicite = Publicite::with('boutique')->where('slug', $slug)->first();
            if(isset($publicite)) {
                try {
                    $rules = [
                        'image_pub' => 'required|mimes:jpeg,png,gif,jpg',
                        'boutique_id' => 'required'
                    ];

                    $validator = Validator::make($request->all(), $rules);

                    if ($validator->fails()) {
                        return back()->withErrors($validator);
                    }
                    $boutique = Boutique::findOrFail($publicite['boutique_id']);

                    $filename = '';
                    if (isset($request->image_pub)) {
                        $originalImage = $request->image_pub;
                        $thumbnailImage = Image::make($originalImage);
                        $thumbnailPath = public_path('images/boutiques/Publicites/images/');
                        $time = time();
//                        $thumbnailImage->resize(1600, 400);
                        $thumbnailImage->save($thumbnailPath . $time . '.' . strtolower(str_replace(' ', '_', $originalImage->getClientOriginalExtension())));
                        $filename = $time . '.' . strtolower(str_replace(' ', '_', $originalImage->getClientOriginalExtension()));
//                $logoName = $boutique->slug.'-part-logo.'.time().'.'.$request->image_pub->getClientOriginalExtension();
//                $request->image_pub->move(public_path('images/boutiques/Publicites/images/'),$logoName);
                    }
                    $publicite = Publicite::findOrFail($publicite['id']);
                    $publicite->image = asset('/images/boutiques/Publicites/images/' . $filename);
                    $publicite->boutique_id = $request->boutique_id;
                    $publicite->description = $request->description;
                    $publicite->save();
                    return back()->with('success', 'Mis à jour effectué avec succès. Votre nouvel banière est prête à être utilisée.');
                } catch (\Exception $exception) {
                    return back()->with('error', $exception->getMessage());
                }
            }else{
                return back();
            }

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Publicite  $publicite
     * @return \Illuminate\Http\Response
     */
    public function destroy($slug)
    {
        $publicite = Publicite::where('slug',$slug)->first();
        Publicite::findOrFail($publicite['id'])->delete();
        return back()->with('success','Image d\'entête supprimée avec succès');
    }
}
