<?php

namespace App\Http\Controllers\Reclamations;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Reclamations;
use App\User;
use App\helpers\helper;
use App\Http\Controllers\MailController;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\DB;

class reclamationController extends Controller
{
    
    public function store(Request $request)
    {
        $data= $request->all();

        $rules = array(
            'type' => 'required|in:commande,mib',
            'message' => 'required|string',
            'name' => 'required|string',
            'telephone' => 'required|string',
            'email' => 'required|string',
            'date' => 'required|string'
        );
        $validator = \Illuminate\Support\Facades\Validator::make($request->all(), $rules);
        if ($validator->fails()) {
            return back()->withErrors($validator)->withInput();
        }

        if(isset($request->image)){
            $helper= new helper();
            $image = $helper->saveFile($request->image,'reclamations');
            if($image) $data['screen'] = $image;
        }
        $boutique = Session::get('boutique');
        $data["boutique_slug"]=$boutique['slug'];
      
                $data['slug']=strtolower("rl-".str_random(5));
                $reclamation = Reclamations::create($data);
                if($reclamation){
                    $subject = ' vous avez reçu une reclamation de ' . $data['name'];
                    $messages = "Le client " . $data['name'] . " vient de faire une reclamation. Veuillez prendre en compte s'il vous plait.";      
                    MailController::SendGeneralUniqueMail('Mail.generale_blade', $subject, $messages, env('MAIL_ADMIN'), env('MAIL_USERNAME'));
                    Session::flash('success', 'La reclamation a été envoyé aux administrateurs avec succès !');
                }else{
                    Session::flash('error', 'une erreure est survenue au cours du processus !');
                }
        return back();
    }



    public function index()
    { 
           $reclamations =  Reclamations::orderBy("id",'DESC')->get();
           return view('dashboard.Reclamations.index', compact("reclamations"));   
    } 
    
    public function get(Request $request)
    {
        try {
           $reclamations =  Reclamations::whereSlug($request->slug)->first();
            return ['data'=>$reclamations,'message'=>"Reclamation recupérer avec succès !"];
        } catch (\Exception $e) {
            return ['data'=>[],'message'=>"Une erreure est survenue qu cours du processus ".$e->getMessage()];
        }
        
    } 
    
    public function visibility($slug)
    {
        try {

            $ac = Reclamations::whereSlug($slug)->first();
            if ($ac) {
                $text = $ac->active? 0 : 1;
                $ac->active = $text;
                $ac->save();
                Session::flash('success', 'Le statut de la reclamation a été mis à jour');
            } else {
                Session::flash('error', 'Un  problème est survenue au cours du processus de modification du statut du code promo ');
            }

        } catch (\Exception $e) {
            Session::flash('error', 'Un  problème est survenue au cours de l\'exécution du processus ' . $e);
        }
        return back();

    }
    public function update_status(Request $request)
        {
            try {
                    $data=$request->all();
                    $ac = Reclamations::whereSlug($data["slug"])->first();
                    if ($ac) {
                        $data['status']=true;
                        unset($data['_token']);
                        unset($data['action']);
                        $promo = DB::table("reclamations")->where("slug",$data["slug"])->update($data);
                        $subject = 'Reclamation '.$data["slug"];
                        $messages = "Le status de votre réclamation à été mis à jour avec le motif suivant : ".$data['motif'];      
                        MailController::SendGeneralUniqueMail('Mail.generale_blade', $subject, $messages, $ac['email'], env('MAIL_USERNAME'));
                        Session::flash('success', 'Le statut de la reclamation a été mis à jour');
                    } else {
                        Session::flash('error', 'Un  problème est survenue au cours du processus de modification du statut du code promo ');
                    }

            } catch (\Exception $e) {
                Session::flash('error', 'Un  problème est survenue au cours de l\'exécution du processus ' . $e);
            }
            return back();
        }

    public function delete($slug)
    {
        try {
            Reclamations::whereSlug($slug)->delete();
            Session::flash('success', 'La reclamation a été supprimé avec succès');
        } catch (\Exception $e) {
            Session::flash('error', 'Un  problème est survenue au cours de l\'exécution du processus ' . $e);
        }
        return back();

    }
}