<?php

namespace App\Http\Controllers\SGI;

use App\Annonce;
use App\Http\Controllers\MailController;
use App\Models\Functions;
use App\Models\Role;
use App\User;
use App\Portefeuille;
use App\SgiPortefeuille;
use App\SgiUser;
use App\UserInvestissementRegisterPaymentLogs;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Validator;
use Mockery\Exception;
    
class AuthController extends ApiController
{
    function setUserhasInvestissor(Request $request){
        try{
            $data=$request->all();
            $user = User::where('email',$data['email'])->first();
            if(isset($data['reference'])){
                $udata=['user_id'=>$user['id'],'price'=>10000,'reference'=>$data['reference'],'year'=>date('Y')];
                UserInvestissementRegisterPaymentLogs::create($udata);
                $user = DB::table('users')->where('id',$user['id'])->update(['is_investissor'=>true]);
            } 
            return $this->successResponse("Mise à jour des informations de l'utilisateur effective");
        } catch (Exception $e) {
            Log::info($e);
            return $this->errorResponse("Une erreuse esr survenue au cours du processus.");
        }
    }
    function checkUserIsInvestissor(Request $request){
            $data=$request->all();
            $user = User::where('email',$data['email'])->first();
          return  isset($user['is_investissor']) && $user['is_investissor'] ? 1 : 0;
    }

    function register(Request $request)
    {
        try {

            $validator = \Illuminate\Support\Facades\Validator::make($request->all(), [
                'country_id' => 'required',
                'username' => 'required|string|unique:users',
                'first_name' => 'required|string',
                'last_name' => 'required|string',
                'telephone' => 'required|string',
                'email' => 'required|email|unique:users',
                'password' => 'required|string',
            ]);
            if ($validator->fails()) {
                return $this->errorResponse($validator->errors()->all()[0]);
            }
            $user = User::whereEmail($request->email)->first();
            if ($user == null) {
                $data = $request->all();
                $country = DB::table('countries')->where('id', $data['country_id'])->first();
                $data["slug"] = "user".Annonce::generate_slug_for_table("users");
                $data["code"] = Annonce::generate_slug_for_table("users");
                $data["country"] = $country->name;
                $data["type"] = "user";
                $data["password"] = Hash::make($request->password);
               
                $data["password"] = Hash::make($request->password);
                $user = User::create($data);
                Portefeuille::create([
                    "user_slug"=>$user->slug,
                    "montant"=>0,
                    "devise"=>"XOF",
                    "active"=>true
                ]);
                if(isset($data['reference'])){
                    $udata=['user_id'=>$user->id,'price'=>10000,'reference'=>$data['reference'],'year'=>date('Y')];
                    UserInvestissementRegisterPaymentLogs::create($udata);
                    $user = DB::table('users')->where('id',$user->id)->update(['is_investissor'=>true]);
                }
                try{
                    MailController::html_email($request->username, $request->email, "Inscription sur Sungrocery Investissement", $data["code"]);
                }catch(Exception $e){
                    return $this->errorResponse("Le mail n'a pas pu être transmus via l'adresse fournis.");
                }
                return $this->successResponse($user);
                //Votre insciption a été effectué. Veuillez le confirmer dans votre boite mail
            } else {
                return $this->errorResponse("Ce compte existe déjà.");
            }
        } catch (Exception $e) {
            return $this->errorResponse("Inscription échouée. Veuillez rééssayer");
        }
    }

    function confirmation(Request $request)
    {
        try {
            $user = User::whereCode($request->confirmation)->first();
            if ($user != null) {
                if ($user->validated_at !=null) {
                    return $this->errorResponse("Confirmation échouée. Ce compte a été déjà confirmé");
                } else {
                    DB::table("users")->
                    where('id', $user->id)->
                    update([
                        "validated_at" => now(),
                        'updated_at' => now(),
                    ]);
                    MailController::html_email_confirmation($user->uqername,
                        $user->email, "Confirmation de compte sur SunGrocey Inv");
                    return $this->successResponse($user);
                }
            } else {
                return $this->errorResponse("Confirmation échouée. Ce compte n'existe pas");
            }
        } catch (Exception $e) {
            return $this->errorResponse("Confirmation échouée. Veuillez rééssayer");
        }
    }


    function login(Request $request)
    {
        try {
            $validator = Validator::make($request->all(), [
                'email' => 'required|email',
                'password' => 'required|string|min:6',
            ]);
            if ($validator->fails()) {
                return $this->errorResponse($validator->errors()->all()[0]);
            }

            $user = User::with("portefeuille_inv")->whereEmail($request->email)->first();
            if ($user != null) {

                    if (Hash::check($request->password, $user->password)) {
                        $user->token = Annonce::generate_slug_for_table("users",90,"token");
                        $user->save();
                        return $this->successResponse(["user"=>$user,"token"=>$user->token]);
                    } else {
                        return $this->errorResponse("Mot de passe incorrect");
                    }

            } else {
                return $this->errorResponse("Ce compte compte est introuvable, Veuillez créer un compte.");
            }
        } catch (Exception $e) {
            return $this->errorResponse("Échec de connexion. Veuillez rééssayer");
        }
    }

    public function get_user(Request $request){
        try {
            Log::info($request->header());
            $validator = Validator::make($request->all(), [
                'token' => 'required|string'
            ]);
            if ($validator->fails()) {
                return $this->errorResponse($validator->errors()->all()[0]);
            }
            Log::info($header);
            $user = User::with("portefeuille_inv")->whereToken($request->token)->first();
            if ($user != null) {
                return $this->successResponse($user);
            } else {
                return $this->errorResponse("Vous n'êtes pas connecté");
            }
        } catch (Exception $e) {
            return $this->errorResponse("Échec de connexion. Veuillez rééssayer");
        }
    }

 public function get_user_data(Request $request){
        try {
            Log::info($request->header());
            $header = $request->header('Token');
            //Log::info($header);
            if (!isset($header)) {
                return $this->errorResponse(["status"=>false,"message"=>"Vous n'êtes pas connecté."]);
            }
            $user = User::with("portefeuille_inv")->whereToken($header)->first();
            if ($user != null) {
                return $this->successResponse(["status"=>true,"user"=>$user]);
            } else {
                return $this->errorResponse(["status"=>false,"message"=>"Nous ne parvenons pas à retrouver l'utilisateur."]);
            }
        } catch (Exception $e) {
            return $this->errorResponse(["status"=>false,"message"=>"Échec de connexion. Veuillez rééssayer"]);
        }
    }
    
     public function get_user_data_with_user_token(Request $request){
        try {
            Log::info($request->header());
            $header = $request->header('Token');
            Log::info($header);
            if (!isset($header)) {
                return $this->errorResponse(["status"=>false,"message"=>"Vous n'êtes pas connecté."]);
            }
            $user = User::with("portefeuille_inv")->whereToken($header)->first();
            if ($user != null) {
                return $this->successResponse(["status"=>true,"user"=>$user]);
            } else {
                return $this->errorResponse(["status"=>false,"message"=>"Nous ne parvenons pas à retrouver l'utilisateur."]);
            }
        } catch (Exception $e) {
            return $this->errorResponse(["status"=>false,"message"=>"Échec de connexion. Veuillez rééssayer"]);
        }
    }
}
