<?php

namespace App\Http\Controllers\SGI;

use App\Annonce;
use App\Http\Traits\ProjectTrait;
use App\InvestmentProject;
use App\InvestmentProjetContribution;
use App\InvestmentPaymentLogs;
use App\investissementRemboursement;
use App\InvestissementNews;
use App\ParametrageInvestissement;
use App\Commandes;
use App\Retrait;
use App\Portefeuille;
use App\SgiUser;
use App\User;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Http\Controllers\MailController;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;
use Illuminate\Support\Facades\Validator;
use Carbon\Carbon;
use Mockery\Exception;
use Symfony\Polyfill\Intl\Idn\Info;

class ProjectController extends ApiController
{
    use ProjectTrait;

    public function list()
    {
        $projects = InvestmentProject::with($this->projectRelation())
            ->where("visibility", true)
            ->orderByDesc("id")
            ->paginate(9);
      /*   $projects = InvestmentProject::with($this->projectRelation())
            ->where("date_debut_participation", "<=", date("Y-m-d", strtotime(now())))
            ->where("date_fin_participation", ">=", date("Y-m-d", strtotime(now())))
            ->where("visibility", true)
            ->orderByDesc("id")
            ->paginate(9);
       */  
      return $this->successResponse($projects);
    }

    public function detail($slug)
    {
        $project = InvestmentProject::with($this->projectRelation())->whereSlug($slug)->first();
        return $this->successResponse($project);
    }
    public function payment_logs(Request $request)
        {
            try{
                $investissements=DB::table('investment_payment_logs')->where('contribution_id',$request->contribution_id)->orderBy('id','DESC')->get();
                return $this->successResponse($investissements);
            }catch(Exception $e){
                return $this->errorResponse("Une erreure est survenue au cours du processus. Veuillez rééssayer");
            }
        }

    public function addContribution(Request $request)
    {
        try {
            $validator = Validator::make($request->all(), [
                'montant' => 'required|integer',
                'reference' => 'required|string',
                'investment_project_id' => 'required',
            ]);
            if ($validator->fails()) {
                return $this->errorResponse($validator->errors()->all()[0]);
            }
            $token = $request->header('token');   
            $user = User::whereToken($token)->first();
            if ($user != null) {
               $checkHasInvest=InvestmentProjetContribution::where('sgi_user_id',$user['id'])->where('investment_project_id',$request->investment_project_id)->count();
               if($checkHasInvest > 0){
                return $this->errorResponse("Vous ne pouvez pas investir deux fois sur le même projet.");
               }
                if($request->type_payment=="virement"){
                    $project = InvestmentProject::with($this->projectRelation())->find($request->investment_project_id);
                    $invest= InvestmentProjetContribution::create(
                    [
                        "slug" => "contribution_" . Annonce::generate_slug_for_table("investment_projet_contributions"),
                        "reference" => 'virement',
                        "sgi_user_id" => $user['id'],
                        "investment_project_id" => $request->investment_project_id,
                        "part" => $request->action_part,
                        "number_month_paid" => 0,
                        "active" =>  0,
                        "receipt" => "",
                        "type_payment" => $request->type_payment,
                        "payment_status" => 0,
                        "investissement_payment_status" => 0,
                        "montant" => $request->montant,
                    ]
                    );
                }else{

                $public_key= env('INTRAM_PUBLIC');
                $secret= env('INTRAM_SECRET');
                $private_key= env('INTRAM_PRIVATE');
                $intram = new \Intram\Intram($public_key, $private_key, $secret, env('INTRAM_SANDBOX') =='1');
                $tx = $intram->getTransactionStatus($request->reference);
                if ($tx->status == "SUCCESS") {
                    $project = InvestmentProject::with($this->projectRelation())->find($request->investment_project_id);
                    Portefeuille::createPortefeuilles(
                        $project->user->slug,
                        $request->montant,
                        'Investissement sur le projet '.$project->titre,
                        'Vous avez un nouvelle investissement sur le projet '.$project->titre,
                        'XOF',
                        $project->user->slug);
                        $investissement_payment_status=0;
                        $total_price=intVal($request->action_part)*intVal($project->action_prix);
                        if($total_price <= $request->montant ){
                                $investissement_payment_status=1;
                        }
                        $invest= InvestmentProjetContribution::create(
                        [
                            "slug" => "contribution_" . Annonce::generate_slug_for_table("investment_projet_contributions"),
                            "reference" => $request->reference,
                            "sgi_user_id" => $user['id'],
                            "investment_project_id" => $request->investment_project_id,
                            "part" => $request->action_part,
                            "number_month_paid" => isset($request->number_month_paid) ? $request->number_month_paid : 0,
                            "active" => isset($request->active) && $request->active ? 1 : 0,
                            "receipt" => isset($request->receipt) ? $request->receipt : "",
                            "type_payment" => $request->type_payment,
                            "payment_status" => isset($request->payment_status) && $request->payment_status ? 1 : 0,
                            "investissement_payment_status" => $investissement_payment_status,
                            "montant" => $request->montant,
                        ]
                    );
                    // If paid first contribution, create payment logs
                    DB::table('investment_payment_logs')->insert([
                        "contribution_id" => $invest->id,
                        "montant" => $request->montant,
                        "reference" => $request->reference,
                        "number_month_paid"=>isset($request->number_month_paid) ? $request->number_month_paid : 0,
                        'created_at'=>Carbon::now()
                    ]);

                    // Create remboursement planning ***************
                    $remboursement= [];
                    $interval=$project->date_gain;
                    $gain_price=intVal((($project->action_prix * $request->action_part)*($project->pourcentage_gain/100)) );
                    for($i=0;$i<$interval;$i++){
                            array_push($remboursement,[
                                "contribution_id" => $invest->id,
                                "montant" => ($gain_price),
                                "year" => (intval($project->start_remboursment)+$i),
                                "type"=>'gain',
                                "number"=>$interval,
                            ]);
                    }
                    if(isset($project->retour_capital)){
                        array_push($remboursement,[
                            "contribution_id" => $invest->id,
                            "montant" => (intval($project->action_prix * $request->action_part)),
                            "year" => ($project->retour_capital),
                            "type"=>'retour capital',
                            "number"=>$interval,
                        ]);
                    }
                    investissementRemboursement::insert($remboursement);
                }else {
                    return $this->errorResponse("Le paiement a échoué, veuillez réessayer");
                }
                    return $this->successResponse($project);
                } 
            } else {
                return $this->errorResponse("Vous n'êtes pas connecté");
            }
        } catch (Exception $e) {
            return $this->errorResponse("Échec de connexion. Veuillez rééssayer");
        }
    }
    
    public function updateContribution(Request $request)
    {
        try {
            $validator = Validator::make($request->all(), [
                'montant' => 'required|integer',
                'reference' => 'required|string',
            ]);
            if ($validator->fails()) {
                return $this->errorResponse($validator->errors()->all()[0]);
            }
            $token = $request->header('token');   
            $user = User::whereToken($token)->first();
            if ($user != null) {
              
                $public_key= env('INTRAM_PUBLIC');
                $secret= env('INTRAM_SECRET');
                $private_key= env('INTRAM_PRIVATE');
                $intram = new \Intram\Intram($public_key, $private_key, $secret, env('INTRAM_SANDBOX') =='1');
                $tx = $intram->getTransactionStatus($request->reference);
                if ($tx->status == "SUCCESS") {
                    $project = InvestmentProject::with($this->projectRelation())->find($request->investment_project_id);
                    Portefeuille::createPortefeuilles(
                        $project->user->slug,
                        $request->montant,
                        'Cumule investissement mensuel sur le projet '.$project->titre,
                        'Vous avez un cumule sur l\'investissement du projet '.$project->titre,
                        'XOF',
                        $project->user->slug);
                        $invest_data=InvestmentProjetContribution::findOrFail($request->contribution_id);
                      //  Log::info($invest_data);
                        $number_month=($invest_data->number_month_paid + $request->number_month_paid);
                        $investissement_payment_status=0;
                        $montant=intVal($invest_data->montant) + intVal($request->montant);
                        $total_price=intVal($invest_data->action_part)*intVal($project->action_prix);
                        if($total_price <= $montant ){
                            $investissement_payment_status=1;
                        }
                        $contr_data=[
                            'montant'=>intVal($invest_data->montant) + intVal($request->montant),
                            'number_month_paid'=>$number_month,
                            "investissement_payment_status" => $investissement_payment_status
                        ];
                        if($number_month>=$project->nbre_obligation_mensuelle_investisseur){
                            $contr_data['payment_status']=1;
                        }
                        DB::table('investment_projet_contributions')->where('id',$request->contribution_id)->update($contr_data);
                        DB::table('investment_payment_logs')->insert([
                            "contribution_id" => $request->contribution_id,
                            "montant" => $request->montant,
                            "reference" => $request->reference,
                            "number_month_paid"=>isset($request->number_month_paid) ? $request->number_month_paid : 0,
                            'created_at'=>Carbon::now()
                        ]);

                    return $this->successResponse($project);
                } 
            } else {
                return $this->errorResponse("Vous n'êtes pas connecté");
            }
        } catch (Exception $e) {
            return $this->errorResponse("Échec de connexion. Veuillez rééssayer");
        }
    }
    public function validateVirementContribution($contribution_id)
    {
        try {
        
                    $invest_data=InvestmentProjetContribution::whereSlug($contribution_id)->first();
                    $project = InvestmentProject::with($this->projectRelation())->find($invest_data->investment_project_id);
                        $number_month=0;
                        $contr_data=[
                            'payment_status'=>1,
                            "investissement_payment_status" => 1,
                            'montant' => $invest_data->montant,
                        ];
                        if($number_month>=$project->nbre_obligation_mensuelle_investisseur){
                            $contr_data['payment_status']=1;
                        }
                        DB::table('investment_projet_contributions')->where('id',$invest_data['id'])->update($contr_data);
                        DB::table('investment_payment_logs')->insert([
                            "contribution_id" => $invest_data['id'],
                            "montant" => $invest_data->montant,
                            "reference" => 'virement',
                            "number_month_paid"=> 0,
                            'created_at'=>Carbon::now()
                        ]);
                         // Create remboursement planning ***************
                        $remboursement= [];
                        $interval=$project->date_gain;
                        $gain_price=(intVal((($project->action_prix * $invest_data['action_part'])*($project->pourcentage_gain/100)) ));
                        for($i=0;$i<$interval;$i++){
                                array_push($remboursement,[
                                    "contribution_id" => $invest_data['id'],
                                    "montant" => ($gain_price),
                                    "year" => (intval($project->start_remboursment)+$i),
                                    "type"=>'gain',
                                    "number"=>$interval,
                                ]);
                        }
                        if(isset($project->retour_capital)){
                            array_push($remboursement,[
                                "contribution_id" => $invest_data['id'],
                                "montant" => (intval($project->action_prix * $invest_data['action_part'])),
                                "year" => ($project->retour_capital),
                                "type"=>'retour capital',
                                "number"=>$interval,
                            ]);
                        }
                        //dd($remboursement);
                        investissementRemboursement::insert($remboursement);
                    return back()->with('success','Investissement validé avec succès');
        
        } catch (Exception $e) {
            return back()->with('error',"Échec de connexion. Veuillez rééssayer ".$e->getMessage());
        }
    }
    public function receiptUpload(Request $request){
        try{
            $data=$request->all();
            $project = InvestmentProject::with($this->projectRelation())->find($request->investment_project_id);
            $invest_data=InvestmentProjetContribution::findOrFail($request->contribution_id);
            if ($request->file('receipt')) {
                $cni = $request->file('receipt');
                $path = public_path('uploads/investment-projects/receipt');
                $ifFilename = time().'.'. $cni->getClientOriginalExtension();
                $cni->move($path, $ifFilename);
                $data['receipt']= asset('uploads/investment-projects/receipt/' . $ifFilename);
                DB::table('investment_projet_contributions')->where('id',$request->contribution_id)->update(['receipt'=>$data['receipt']]);
                return $this->successResponse($project);
            }else{
                return $this->errorResponse("Aucun fichier trouvé.");
            }
        } catch (Exception $e) {
            return $this->errorResponse("Une erreure est survenue au cours du processus. Veuillez rééssayer");
        }
    }

    public function retraits(Request $request){
        try{
            $token = $request->header('token');   
            $user = User::whereToken($token)->first();
            Log::info($user);
            if ($user != null) {
                $retraits = Retrait::where('user_slug', $user['slug'])->orderBy('id','DESC')->get();
                Log::info($retraits);
                return $this->successResponse($retraits);
            }
        }catch(Exception $e){
            return $this->errorResponse("Une erreure est survenue au cours du processus. Veuillez rééssayer");
        }
    }

    public function makedemande_retrait(Request $request)
    {
        $data = $request->all();
        $rules = array(
            'montant' => 'required|integer',
            'password' => 'required|string',
        );
        $validator = \Illuminate\Support\Facades\Validator::make($request->all(), $rules);
        if ($validator->fails()) {
            return $this->errorResponse($validator->getMessageBag()->first());
        }
    
        $token = $request->header('token');   
        $user = User::whereToken($token)->first();
        if(Hash::check($data['password'],$user->password)) {
            // si l'utilisateur à choisis un retrait par mobile
            if(isset($data['numero']) && $data['numero']!= null && $data['numero']!='' && $data['moyen_paiement']=='mobile_money') {
                $data['compte_bancaire'] = null;
                $numero=$data['numero'];
                $compte='mobile money';
            }
                //si l'utilisateur à choisis un compte bancaire
            if($data['moyen_paiement']=='compte_bancaire'){
                    $numero=$data['numero'];
                    $data['numero'] = '';
                    $compte='compte bancaire';
            }
            //si l'utilisateur à choisis un compte paypal
            if($data['moyen_paiement']=='paypal'){
                $numero=$data['numero'];
                $data['numero'] = '';
                $compte='paypal';
            }
            $data['compte_bancaire']=$numero;
            $data['devise'] = 'xof';
            $data['moyen_paiement']=$compte;
            $data['slug'] = Str::slug(time() . 'retrait' . time());
            $data['user_slug'] = $user->slug;
            $data['status_demande'] = false;
            $data['status_retrait'] = false;
            Retrait::create($data);
            try {
                //Envoyer un email au client pour la demande de retrait
                $subject = 'Demande de retrait en cours d\'évaluation';
                $messages = ['first_name' => $user->first_name, 'last_name' => $user->last_name, 'numero' => $numero, 'compte' => $compte, 'montant' => $data['montant']];
                MailController::SendGeneralUniqueMail('Mail.retrait_demand', $subject, $messages, $user->email, env('MAIL_USERNAME'));

                $subject = 'Demande de retrait ';
                $messages = 'Une demande de retrait à été envoyé';
                MailController::SendGeneralUniqueMail('generale_blade', $subject, $messages, env('MAIL_USERNAME'), env('MAIL_USERNAME'));
            }catch (\Exception $e){

            }
            return $this->successResponse('Demande éffectuée avec succès. Un email de confirmation vous sera envoyé.');
        }else{
            return $this->errorResponse("Mot de passe incorrecte. Veuillez rééssayer");
        }
    }
  
    public function remboursements(Request $request)
        {
            $token = $request->header('token');   
            $user = User::whereToken($token)->first();
            $contributions=InvestmentProjetContribution::where('sgi_user_id',$user['id'])->pluck('id')->toArray();
            $investissements=investissementRemboursement::with('contribution','contribution.investment')->whereIn('contribution_id',$contributions)->get();
            return $this->successResponse($investissements);
        }

        public function actualites($slug,$type)
        {
            try{
            $project = InvestmentProject::where('slug',$slug)->first();
            $actualites = InvestissementNews::where("project_id", $project['id'])->where("public", $type)->get();
            return $this->successResponse($actualites);
            }catch(Exception $e){
                return $this->errorResponse("Une erreure est survenue au cours du processus. Veuillez rééssayer");
            }
        }
        public function actualite($slug,Request $request)
        {
            try{
            $actualite = InvestissementNews::with(['project','project.contributions'])->where("slug", $slug)->first();
            $response=[];
            if($actualite['public']==='private'){
                $token = $request->header('token');   
                $user = User::whereToken($token)->first();
                $contributions=InvestmentProjetContribution::where('sgi_user_id',$user['id'])->pluck('id')->toArray();
                if(count($contributions) <= 0){
                    $response=['message'=>"Vous n'avez pas accès a cette page"];
                }else{
                    $response=['actualite'=>$actualite];
                }
            }else{
                    $response=['actualite'=>$actualite];
            }
            return $this->successResponse($response);
            }catch(Exception $e){
                return $this->errorResponse("Une erreure est survenue au cours du processus. Veuillez rééssayer");
            }
        }
        public function all_actualites(Request $request)
        {
            try{
            $contributions=[];
            $token = $request->header('token');   
            if(isset($token) || $token!=''){
                $user = User::whereToken($token)->first();
                $contributions=InvestmentProjetContribution::where('sgi_user_id',$user['id'])->pluck('investment_project_id')->toArray();
            }
            $actualites = InvestissementNews::with(['project','project.contributions'])->where("public", 'public')->orWhereIn("project_id", $contributions)->orderBy('id','DESC')->paginate();
            return $this->successResponse($actualites);
            }catch(Exception $e){
                return $this->errorResponse("Une erreure est survenue au cours du processus. Veuillez rééssayer");
            }
        }

        public function setInvestissementParams(Request $request){
            try{
                $data=$request->all();
                unset($data['_token']);
                foreach ($data as $key =>$value) {
                    $params=ParametrageInvestissement::where('key',$key)->first();
                    if(isset($params) && $params!=null){
                        DB::table('parametrage_investissements')
                            ->where('key',$key)
                            ->update(['value'=>$value]);
                    }else{
                        ParametrageInvestissement::create([
                            'key'=>$key,'value'=>$value
                        ]);
                    }
                }
                return back()->with('success','Paramètre mise à jour avec succès');
            }catch (\Exception $e){
                return back()->with('error','Une erreur s\'est produite. '.$e->getMessage());
            }
        }
        public function getInvestissementParams($key){
                try{
                    $params=new \App\ParametrageInvestissement();
                    $value=$params->getParametersByKeys($key);
                    return $this->successResponse($value);
                }catch (\Exception $e){
                    return $this->errorResponse("Une erreure est survenue au cours du processus. Veuillez rééssayer");
                }
            }
        public function contact(Request $request){
                try{
                    $data=$request->all();
                    try {
                        //Envoyer un email au client pour la demande de retrait
                        $subject = 'Vous avez reçu un message de '.$data['name'];
                        $messages = $data['message']." Email : ".$data['email'];
                        MailController::SendGeneralUniqueMail('generale_blade', $subject, $messages, env('MAIL_USERNAME'), env('MAIL_USERNAME'));
                    }catch (\Exception $e){
        
                    }
                    return back()->with('success','Paramètre mise à jour avec succès');
                }catch (\Exception $e){
                    return back()->with('error','Une erreur s\'est produite. '.$e->getMessage());
                }
            }

}
