<?php

namespace App\Http\Controllers;

use App\AbonnementPaiment;
use App\Boutique;
use App\BoutiqueAbonnement;
use App\BoutiqueMeta;
use App\CatalogueArticles;
use App\CategorieCaracteristique;
use App\CategorieCatalogue;
use App\check_boutiques;
use App\check_products;
use App\CommandArticle;
use App\Commandes;
use App\Converter;
use App\EtatAbonnement;
use App\helpers\helper;
use App\Images;
use App\Metier;
use App\NewslettersAbonnementUser;
use App\NewslettersOptionAbonnement;
use App\Portefeuille;
use App\Privilege_access;
use App\SelectArticle;
use App\SelectedCategorie;
use App\MarketSetting;
use App\User;
use Illuminate\Support\Facades\Log;
use App\visite_boutique;
use App\wishlist_article;
use App\Recettes;
use App\wishlist_boutique;
use Cartalyst\Sentinel\Laravel\Facades\Activation;
use Cartalyst\Sentinel\Laravel\Facades\Sentinel;
use Illuminate\Http\Request;
use Illuminate\Support\Carbon;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Config;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Input;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Str;
use Intervention\Image\Facades\Image;
use Kkiapay\Kkiapay;
use PayPal\Api\Amount;
use PayPal\Api\Item;
use PayPal\Api\ItemList;
use PayPal\Api\Payer;
use PayPal\Api\Payment;
use PayPal\Api\PaymentExecution;
use PayPal\Api\RedirectUrls;
use PayPal\Api\Transaction;
use PayPal\Auth\OAuthTokenCredential;
use PayPal\Rest\ApiContext;


class apiController extends Controller
{

    public function __construct(helper $helper)
    {
        $this->helpers=$helper;
        /** PayPal api context **/
        $paypal_conf = Config::get('paypal');
        $this->_api_context = new ApiContext(new OAuthTokenCredential(
                $paypal_conf['client_id'],
                $paypal_conf['secret'])
        );
        $this->_api_context->setConfig($paypal_conf['settings']);
    }

    public function getSetting($key){
       
        try {
            $params=MarketSetting::where('key',$key)->first();
            return json_encode($params);
        }catch (\Exception $e){
            return json_encode($e);
        }
    }

    public function home_data(Request $request){
        $params=MarketSetting::all();
        $recettes =  Recettes::orderBy("id",'DESC')->inRandomOrder()->take(10)->get();
        $get_most_visite_boutiques=$this->most_visite_shop($request);
        $get_most_like_boutiques=$this->most_like_shop($request);
        $get_visite_products=$this->get_most_visit_product($request,8);
        $get_most_sell_products=$this->get_most_buy_product($request,8);
        $get_most_like_product=$this->get_most_like_product($request);
        $get_products_on_promo=$this->get_products_promotion($request);
        $get_some_panier=$this->get_some_panier($request,10);
        return json_encode(['params'=>$params,
            'recettes'=>$recettes,
            'get_most_visite_boutiques'=>json_decode($get_most_visite_boutiques),
            'get_most_like_boutiques'=>json_decode($get_most_like_boutiques),
            'get_visite_products'=>json_decode($get_visite_products),
            'get_most_sell_products'=>json_decode($get_most_sell_products),
            'get_products_on_promo'=>json_decode($get_products_on_promo),
            'get_some_panier'=>json_decode($get_some_panier)
            ]);
    }

    public function settings(){
        
            try {
                $params=MarketSetting::all();
                return json_encode($params);
            }catch (\Exception $e){
                return json_encode($e);
            }
        }

    public function convertCurrency(Request $request){
        $data=$request->all();
        $from_Currency=$data['from'];
        $to_Currency=$data['to'];
        $amount=$data['amount'];
        $query =  $to_Currency.$from_Currency;
        $rate=Converter::where('code',$query)->first();
       if($rate!=null) {
            $total =  $amount / $rate['rate'];
            $formatValue = number_format($total, 2, '.', '');
            $data = $formatValue;
        }else{
               $query = 'USD' . $from_Currency;
               $rate = Converter::where('code', $query)->first();
               $total = $amount / $rate['rate'];
               $formatValue = number_format($total, 2, '.', '');
               $data = $formatValue;
               //second method
               $query = 'USD' . $to_Currency;
               $rate = Converter::where('code', $query)->first();
               $total = (double) $data * $rate['rate'];
               $formatValue = number_format($total, 2, '.', '');
               $data = $formatValue;
        }
        return (double) $data;
    }

    public function iso(Request $request){
        $country=$request->header('country');
        try {
            $countries = DB::table('countries')->where('name',$country)->first();
            return json_encode($countries->iso2);
        }catch (\Exception $e){
            return json_encode($e);
        }
    }

 public function countries(){
        try {
            $countries = DB::table('countries')->get();
            return json_encode($countries);
        }catch (\Exception $e){
            return json_encode($e);
        }
    }

    public function get_user_continent($countries){
       $country= DB::table('countries')->where('name',$countries)->first();
      $continent= DB::table('continent')->where('Two_Letter_Country_Code',$country->iso2)->first();
      return json_encode($continent);
    }

    public function cities(){
        try {
            $cities = DB::table('cities')->get();
            return json_encode($cities);
        }catch (\Exception $e){
            return json_encode($e);
        }
    }
    
    public function searchCities($name,$value){
        try {
            $cities = DB::table('cities')->where($name,$value)->get();
            return json_encode($cities);
        }catch (\Exception $e){
            return json_encode($e);
        }
    }


    public function regions(){
        try {
            $states = DB::table('states')->get();
            return json_encode($states);
        }catch (\Exception $e){
            return json_encode($e);
        }
    }

    public function searchRegions($name,$value){
            try {
                $states = DB::table('states')->where($name,$value)->get();
                return json_encode($states);
            }catch (\Exception $e){
                return json_encode($e);
            }
        }

    public function all_user_favorite_product($slug){
        $wh = wishlist_article::where('user_slug', $slug)->pluck('catalogue_article_slug')->toArray();
        return json_encode($wh);
    }
    public function add_to_whishlist(Request $request)
    {
        $data = $request->all();
try {
    $wh = wishlist_article::where('boutique_slug', $data['boutique_slug'])->where('user_slug', $data['user_slug'])->where('catalogue_article_slug', $data['catalogue_article_slug'])->count();
    if ($wh > 0) {
        $wh = wishlist_article::where('boutique_slug', $data['boutique_slug'])->where('user_slug', $data['user_slug'])->where('catalogue_article_slug', $data['catalogue_article_slug'])->first();
        wishlist_article::findOrFail($wh['id'])->delete();
        $create = 0;
    } else {
        wishlist_article::create($data);
        $create = 1;
    }
    $wh = wishlist_article::where('user_slug', $data['user_slug'])->pluck('catalogue_article_slug')->toArray();

    return json_encode(['error'=>false,'statut'=>$create,'favorites'=>$wh]);
}catch (\Exception $e){
    return json_encode(['error'=>true,'message'=>$e->getMessage()]);
}
    }

   public function list_secteur_activity(Request $request, $limit){
        $country=$request->header('country');
       $boutiques=  Boutique::with('meta')->whereHas('meta',function($q) use ($country){
           $q->where('internationalize',1)->where('pay_internationalize',1)->orwhere('country','like','%'.$country.'%')->whereNotNull('country');
       })->where('expired',false)->where('maintenance',false)->where('corbeil',false)->where('installer',true)->pluck('metier_slug')->toArray();
      $metiers=   Metier::whereIn('slug',$boutiques)->orderBy('id','DESC')->limit($limit)->get();
        return json_encode($metiers);
   }
   
   public function category_by_secteur_activity_slug(Request $request){
       $data=$request->all();
       try {
           $metiers=   Metier::where('intitule_metier',$data['slug'])->orWhere('slug',$data['slug'])->pluck('slug')->toArray();
               $categories = \App\CategorieCatalogue::whereIn('secteur_activite', $metiers)->get();
           return json_encode($categories);
       }catch (\Exception $e){
          return json_encode($e->getMessage());
       }
   }

  public function category_by_secteur_activity(Request $request){
       $data=$request->all();
       $data['secteur']= explode(',',$data['secteur'][0]);
       try {
           $categories = \App\CategorieCatalogue::pluck('slug')->toArray();

           if(isset($data['secteur']) &&  $data['secteur'][0]!="") {
               $metiers = Metier::whereIn('intitule_metier', $data['secteur'])->pluck('slug')->toArray();
               $categories = \App\CategorieCatalogue::whereIn('secteur_activite', $metiers)->pluck('slug')->toArray();
           }
           if (isset($data['name']) && $data['name'] != null) {
               $categories = \App\CategorieCatalogue::whereIn('slug', $categories)->where('intitule','like','%'. $data['name'] .'%')->pluck('slug')->toArray();
           }
           $country=$request->header('country');
           $boutiques=  Boutique::with('meta')->whereHas('meta',function($q) use ($country){
               $q->where('internationalize',1)->where('pay_internationalize',1)->orwhere('country','like','%'.$country.'%')->whereNotNull('country');
           })->where('expired',false)->where('maintenance',false)->where('corbeil',false)->where('installer',true)->pluck('slug')->toArray();
           $categories = \App\CategorieCatalogue::whereIn('slug', $categories)->whereIn('boutique_slug',$boutiques)->orwhere('boutique_slug','all')->get();
           return json_encode($categories);
       }catch (\Exception $e){
          return json_encode($e->getMessage());
       }
   }


    public function get_product_secteur_activity($slug){
        $categories=  \App\CategorieCatalogue::where('secteur_activite',$slug)->where('corbeil',false)->pluck('slug')->toArray();
        $selected_articles=SelectArticle::where('corbeil',false)->pluck('article_slug')->toArray();
        $produits = CatalogueArticles::has('images')->with(['boutique','boutique.meta','boutique.publicites','images','article_meta','categorie','categorie.caracteristique','categorie.caracteristique.article_meta'])->where('type_user','<>' ,'administrateur')->where('active', 1)->whereIn('categorie_slug',$categories)->where('corbeil',false)->inRandomOrder()->paginate(100);
        return json_encode($produits);
    }

    public function get_product_secteur_activity_global($slug){
        $categories=  \App\CategorieCatalogue::where('secteur_activite',$slug)->where('corbeil',false)->pluck('slug')->toArray();
        $produits = CatalogueArticles::has('images')->with('images')->where('type_user','<>' ,'administrateur')->where('active', 1)->whereIn('categorie_slug',$categories)->where('corbeil',false)->inRandomOrder()->get();
        return json_encode($produits);
    }
 public function filter_secteur_activity(Request $request){
       $data=$request->all();
       try{

         $metiers= Metier::pluck('slug')->toArray();
          if($metiers)
              $metiers= Metier::whereIn('slug',$metiers)->where('intitule_metier','like','%'.$data['name'].'%')->pluck('slug')->toArray();

           $country=$request->header('country');
           $domaines=  Boutique::with('meta')->whereHas('meta',function($q) use ($country){
           $q->where('internationalize',1)->where('pay_internationalize',1)->orwhere('country','like','%'.$country.'%')->whereNotNull('country');
       })->where('expired',false)->where('maintenance',false)->where('corbeil',false)->where('installer',true)->pluck('metier_slug')->toArray();

           $metiers=Metier::whereIn('slug',$metiers)->whereIn('slug',$domaines)->get();
           return json_encode($metiers);
       }catch (\Exception $e){
           return json_encode($e->getMessage());
       }
    }

   public function all_category(Request $request,$limit){
       $country=$request->header('country');
        $boutiques=  Boutique::with('meta')->whereHas('meta',function($q) use ($country){
           $q->where('internationalize',1)->where('pay_internationalize',1)->orwhere('country','like','%'.$country.'%')->whereNotNull('country');
       })->where('expired',false)->where('maintenance',false)->where('corbeil',false)->where('installer',true)->pluck('slug')->toArray();

  $categorie= SelectedCategorie::whereIn('boutique_slug',$boutiques)->pluck('categorie_slug')->toArray();
    $categories=\App\CategorieCatalogue::whereIn('boutique_slug',$boutiques)->orWhereIn('slug',$categorie)->where('corbeil',false)->limit($limit)->get();
    return json_encode($categories);
   }

   public function all_products(Request $request){
       $country=$request->header('country');
        $boutiques=  Boutique::with('meta')->whereHas('meta',function($q) use ($country){
           $q->where('internationalize',1)->where('pay_internationalize',1)->orwhere('country','like','%'.$country.'%')->whereNotNull('country');
       })->where('expired',false)->where('maintenance',false)->where('corbeil',false)->where('installer',true)->pluck('slug')->toArray();
       $selected_articles=SelectArticle::whereIn('boutique_slug',$boutiques)->where('corbeil',false)->pluck('article_slug')->toArray();
       $articles = CatalogueArticles::has('images')->with(['boutique','boutique.meta','boutique.publicites','images','article_meta','categorie','categorie.caracteristique','categorie.caracteristique.article_meta'])->where('type_user','<>' ,'administrateur')->whereIn('boutique_slug',$boutiques)->orwhereIn('slug',$selected_articles)->where('corbeil',false)->where('active', 1)->inRandomOrder()->paginate(10);
return json_encode($articles);
   }

   public function get_product_by_category($slug){
         $produits = CatalogueArticles::has('images')->with(['boutique','boutique.meta','boutique.publicites','images','article_meta','categorie','categorie.caracteristique','categorie.caracteristique.article_meta'])->where('type_user','<>' ,'administrateur')->where('corbeil',false)->where('active', 1)->where('categorie_slug',$slug)->inRandomOrder()->get();
       return json_encode($produits);
   }

   public function get_products_promotion(Request $request){
       $country=$request->header('country');
        $boutiques=  Boutique::with('meta')->whereHas('meta',function($q) use ($country){
           $q->where('internationalize',1)->where('pay_internationalize',1)->orwhere('country','like','%'.$country.'%')->whereNotNull('country');
       })->where('expired',false)->where('maintenance',false)->where('corbeil',false)->where('installer',true)->pluck('slug')->toArray();
       $promos = CatalogueArticles::has('images')
            ->with(['boutique','boutique.meta','boutique.publicites','images','article_meta','categorie','categorie.caracteristique','categorie.caracteristique.article_meta','article_meta'=>function($q){
                $q->where('key','show_price');
       }])->whereIn('boutique_slug',$boutiques)->where('active', 1)->where('on_sale', 1)->where('corbeil',false)->limit(8)->get();
        return json_encode($promos);
   }

   public function get_some_panier(Request $request, $limit){
        $country=$request->header('country');
        $boutiques=  Boutique::with('meta')->whereHas('meta',function($q) use ($country){
           $q->where('internationalize',1)->where('pay_internationalize',1)->orwhere('country','like','%'.$country.'%')->whereNotNull('country');
       })->where('expired',false)->where('maintenance',false)->where('corbeil',false)->where('installer',true)->pluck('slug')->toArray();
       $produits= CatalogueArticles::has('images')
            ->with(['boutique','boutique.meta','boutique.publicites','images','article_meta','categorie','categorie.caracteristique','categorie.caracteristique.article_meta'])
            ->whereIn('boutique_slug',$boutiques)
            ->where('active', 1)
            ->where('corbeil',false)
            ->where('is_panier',1)->limit($limit)->get();
       return json_encode($produits);
   }

    public function get_most_visit_product(Request $request, $limit){
        $visite= check_products::pluck('catalogue_article_slug')->toArray();
        $newCheck=array_count_values($visite);
        arsort($newCheck);
        $newCheck=array_keys($newCheck);
        $country=$request->header('country');
            $boutiques=  Boutique::with('meta')->whereHas('meta',function($q) use ($country){
            $q->where('internationalize',1)->where('pay_internationalize',1)->orwhere('country','like','%'.$country.'%')->whereNotNull('country');
        })->where('expired',false)->where('maintenance',false)->where('corbeil',false)->where('installer',true)->pluck('slug')->toArray();
        $produits= CatalogueArticles::has('images')->with(['boutique','boutique.meta','boutique.publicites','images','article_meta','categorie','categorie.caracteristique','categorie.caracteristique.article_meta'])->whereIn('boutique_slug',$boutiques)->where('active', 1)->whereIn('slug',$newCheck)->where('corbeil',false)->limit($limit)->get();
        return json_encode($produits);
    }

 public function get_most_buy_product(Request $request, $limit){
   $command= CommandArticle::pluck('article_slug')->toArray();
     $newCheck=array_count_values($command);
     arsort($newCheck);
     $newCheck=array_keys($newCheck);
     $country=$request->header('country');
      $boutiques=  Boutique::with('meta')->whereHas('meta',function($q) use ($country){
           $q->where('internationalize',1)->where('pay_internationalize',1)->orwhere('country','like','%'.$country.'%')->whereNotNull('country');
       })->where('expired',false)->where('maintenance',false)->where('corbeil',false)->where('installer',true)->pluck('slug')->toArray();
     $produits= CatalogueArticles::has('images')->with(['boutique','boutique.meta','boutique.publicites','images','article_meta','categorie','categorie.caracteristique','categorie.caracteristique.article_meta'])->whereIn('slug',$newCheck)->whereIn('boutique_slug',$boutiques)->where('active', 1)->where('corbeil',false)->limit($limit)->get();
     return json_encode($produits);
 }

 public function get_most_like_product(Request $request){
    $favoris=wishlist_article::pluck('catalogue_article_slug')->toArray();
     $newCheck=array_count_values($favoris);
     arsort($newCheck);
     $newCheck=array_keys($newCheck);
     $country=$request->header('country');
      $boutiques=  Boutique::with('meta')->whereHas('meta',function($q) use ($country){
           $q->where('internationalize',1)->where('pay_internationalize',1)->orwhere('country','like','%'.$country.'%')->whereNotNull('country');
       })->where('expired',false)->where('maintenance',false)->where('corbeil',false)->where('installer',true)->pluck('slug')->toArray();
     $produits= CatalogueArticles::has('images')->with(['boutique','boutique.meta','boutique.publicites','images','article_meta','categorie','categorie.caracteristique','categorie.caracteristique.article_meta'])->whereIn('slug',$newCheck)->whereIn('boutique_slug',$boutiques)->where('active', 1)->where('corbeil',false)->limit(8)->get();
     return json_encode($produits);
   }

   public function product_details($slug){
   $produit= CatalogueArticles::with(['boutique','boutique.meta','boutique.publicites','images','article_meta','categorie','categorie.caracteristique','categorie.caracteristique.article_meta'=>function($q) use($slug){
       $q->where('article_slug',$slug);
   }])->where('slug',$slug)->first();
   Log::info($produit);
   Log::info($slug);
       $data['user_slug'] = request()->ip();
       $data['boutique_slug']=$produit['boutique']['slug'];
       $data['nclick'] = 1;
       $data['catalogue_article_slug']=$produit['slug'];
       check_products::create($data);
  return json_encode($produit);
   }

   public function category_by_boutique(Request $request){
       $data=$request->all();
      try {
          if ($data['slug'] == 'all') {
              $data['slug'] = Boutique::pluck('slug')->toArray();
              $categoriesSelected = SelectedCategorie::pluck('categorie_slug')->where('corbeil',false)->toArray();
              $categories = \App\CategorieCatalogue::whereIn('boutique_slug', $data['slug'])->where('corbeil',false)->orwhereIn('slug', $categoriesSelected)->get();
          } else {
              $data['slug'] = Boutique::whereIn('nom_boutique', $data['slug'])->pluck('slug')->toArray();
              $categoriesSelected = SelectedCategorie::whereIn('boutique_slug', $data['slug'])->pluck('categorie_slug')->where('corbeil',false)->toArray();
              $categories = \App\CategorieCatalogue::whereIn('boutique_slug', $data['slug'])->orwhereIn('slug', $categoriesSelected)->where('corbeil',false)->get();
          }
          return json_encode($categories);
      }catch (\Exception $e){
          return json_encode($e);
      }
   }

   public function all_products_filter_by_category(Request $request){
       $data=$request->all();
       $min=0;
       $max=999999999999999;
        if(isset($data['min']) && $data['min']!=null)
           $min=intval($data['min']);
       if(isset($data['max']) && $data['max']!=null)
            $max=intval($data['max']);
try{
              $categories = \App\CategorieCatalogue::where('intitule', $data['categories'])->pluck('slug')->toArray();
               $articles = CatalogueArticles::whereIn('categorie_slug', $categories)->pluck('slug')->toArray();

    if (isset($data['name']) && $data['name'] != null) {
        $articles = CatalogueArticles::where('name','like','%'. $data['name'].'%')->whereIn('slug',$articles)->pluck('slug')->toArray();
    }


if(isset($data['star']) && $data['star']!='false' && $data['star']!='undefined'){
    $visites= check_products::pluck('catalogue_article_slug')->toArray();
    $newCheck=array_count_values($visites);
    arsort($newCheck);
    $newCheck=array_keys($newCheck);
$articles=array_intersect($articles,$newCheck);
}

if(isset($data['most_sell']) && $data['most_sell']!='false' && $data['most_sell']!='undefined'){
    $command= CommandArticle::pluck('article_slug')->toArray();
    $newCheck=array_count_values($command);
    arsort($newCheck);
    $newCheck=array_keys($newCheck);
    $articles=array_intersect($articles,$newCheck);
}
    if (isset($data['promotion']) && $data['promotion']!='false' && $data['promotion']!='undefined') {
        $data['promotion']=='true' ? $data['promotion']=1 : $data['promotion']=1;
        $articles = CatalogueArticles::whereIn('slug',$articles)->where('on_sale',$data['promotion'] )->pluck('slug')->toArray();
    }
        if(count($articles)>0) {
            $country=$request->header('country');
             $boutiques=  Boutique::with('meta')->whereHas('meta',function($q) use ($country){
                   $q->where('internationalize',1)->where('pay_internationalize',1)->orwhere('country','like','%'.$country.'%')->whereNotNull('country');
               })->where('expired',false)->where('maintenance',false)->where('corbeil',false)->where('installer',true)->pluck('slug')->toArray();
            $articles = CatalogueArticles::has('images')->with(['boutique','boutique.meta','boutique.publicites','images','article_meta','categorie','categorie.caracteristique','categorie.caracteristique.article_meta'])->whereIn('slug', $articles)->whereIn('boutique_slug',$boutiques)->where('price', '<=', $max)->where('price', '>=', $min)->where('corbeil', false)->where('active', 1)->inRandomOrder()->simplePaginate(20);
        }else{
            $articles = [];
}
     return json_encode($articles);
       }catch (\Exception $e){
           return json_encode($e);
       }
   }

   public function all_products_filter(Request $request){
       $data=$request->all();
       $categories=[];
       $min=0;
       $max=9999999999;
       if(isset($data['categories']))
       $data['categories']=explode(',',$data['categories'][0]);
       if(isset($data['min']) && $data['min']!=null)
           $min=intval($data['min']);
       if(isset($data['max']) && $data['max']!=null)
            $max=intval($data['max']);
try{
    $articles = CatalogueArticles::where('corbeil', false)->where('active', 1)->pluck('slug')->toArray();


    if (isset($data['categories']) && $data['categories'][0]!="") {
               $categories = \App\CategorieCatalogue::whereIn('intitule', $data['categories'])->pluck('slug')->toArray();
               $articles = CatalogueArticles::whereIn('categorie_slug', $categories)->pluck('slug')->toArray();
           }


    if (isset($data['name']) && $data['name'] != null) {
        $articles = CatalogueArticles::where('name','like','%'. $data['name'].'%')->whereIn('slug',$articles)->pluck('slug')->toArray();
    }


if(isset($data['star']) && $data['star']!='false' && $data['star']!='undefined'){
    $visites= check_products::pluck('catalogue_article_slug')->toArray();
    $newCheck=array_count_values($visites);
    arsort($newCheck);
    $newCheck=array_keys($newCheck);
$articles=array_intersect($articles,$newCheck);
}

if(isset($data['most_sell']) && $data['most_sell']!='false' && $data['most_sell']!='undefined'){
    $command= CommandArticle::pluck('article_slug')->toArray();
    $newCheck=array_count_values($command);
    arsort($newCheck);
    $newCheck=array_keys($newCheck);
    $articles=array_intersect($articles,$newCheck);
}
    if (isset($data['promotion']) && $data['promotion']!='false' && $data['promotion']!='undefined') {
        $data['promotion']=='true' ? $data['promotion']=1 : $data['promotion']=1;
        $articles = CatalogueArticles::whereIn('slug',$articles)->where('on_sale',$data['promotion'] )->pluck('slug')->toArray();
    }

    if(isset($data['search']) && $data['search']!=''){
       $articles_= $this->filter_search($data['search']);
        $articles = CatalogueArticles::whereIn('slug',$articles)->whereIn('slug',$articles_)->pluck('slug')->toArray();
    }

if(count($articles)>0) {
    $country=$request->header('country');
     $boutiques=  Boutique::with('meta')->whereHas('meta',function($q) use ($country){
           $q->where('internationalize',1)->where('pay_internationalize',1)->orwhere('country','like','%'.$country.'%')->whereNotNull('country');
       })->where('expired',false)->where('maintenance',false)->where('corbeil',false)->where('installer',true)->pluck('slug')->toArray();
    $articles = CatalogueArticles::has('images')->with(['boutique','boutique.meta','boutique.publicites','images','article_meta','categorie','categorie.caracteristique','categorie.caracteristique.article_meta'])->whereIn('slug', $articles)->whereIn('boutique_slug',$boutiques)->where('price', '<=', $max)->where('price', '>=', $min)->where('corbeil', false)->where('active', 1)->inRandomOrder()->simplePaginate(10);
}else{
    $articles = [];
}
           return json_encode($articles);
       }catch (\Exception $e){
           return json_encode($e);
       }
   }



   public function all_panier_filter(Request $request){
    $data=$request->all();
    $categories=[];
    $min=0;
    $max=9999999999;
    if(isset($data['categories']))
    $data['categories']=explode(',',$data['categories'][0]);
    if(isset($data['min']) && $data['min']!=null)
        $min=intval($data['min']);
    if(isset($data['max']) && $data['max']!=null)
         $max=intval($data['max']);
try{
 $articles = CatalogueArticles::where('corbeil', false)->where('active', 1)->pluck('slug')->toArray();


 if (isset($data['categories']) && $data['categories'][0]!="") {
            $categories = \App\CategorieCatalogue::whereIn('intitule', $data['categories'])->pluck('slug')->toArray();
            $articles = CatalogueArticles::whereIn('categorie_slug', $categories)->pluck('slug')->toArray();
        }


 if (isset($data['name']) && $data['name'] != null) {
     $articles = CatalogueArticles::where('name','like','%'. $data['name'].'%')->whereIn('slug',$articles)->pluck('slug')->toArray();
 }


if(isset($data['star']) && $data['star']!='false' && $data['star']!='undefined'){
 $visites= check_products::pluck('catalogue_article_slug')->toArray();
 $newCheck=array_count_values($visites);
 arsort($newCheck);
 $newCheck=array_keys($newCheck);
$articles=array_intersect($articles,$newCheck);
}

if(isset($data['most_sell']) && $data['most_sell']!='false' && $data['most_sell']!='undefined'){
 $command= CommandArticle::pluck('article_slug')->toArray();
 $newCheck=array_count_values($command);
 arsort($newCheck);
 $newCheck=array_keys($newCheck);
 $articles=array_intersect($articles,$newCheck);
}
 if (isset($data['promotion']) && $data['promotion']!='false' && $data['promotion']!='undefined') {
     $data['promotion']=='true' ? $data['promotion']=1 : $data['promotion']=1;
     $articles = CatalogueArticles::whereIn('slug',$articles)->where('on_sale',$data['promotion'] )->pluck('slug')->toArray();
 }

 if(isset($data['search']) && $data['search']!=''){
    $articles_= $this->filter_search($data['search']);
     $articles = CatalogueArticles::whereIn('slug',$articles)->whereIn('slug',$articles_)->pluck('slug')->toArray();
 }

if(count($articles)>0) {
 $country=$request->header('country');
  $boutiques=  Boutique::with('meta')->whereHas('meta',function($q) use ($country){
        $q->where('internationalize',1)->where('pay_internationalize',1)->orwhere('country','like','%'.$country.'%')->whereNotNull('country');
    })->where('expired',false)->where('maintenance',false)->where('corbeil',false)->where('installer',true)->pluck('slug')->toArray();
 $articles = CatalogueArticles::has('images')->with(['boutique','boutique.meta','boutique.publicites','images','article_meta','categorie','categorie.caracteristique','categorie.caracteristique.article_meta'])->where('is_panier', 1)->whereIn('slug', $articles)->whereIn('boutique_slug',$boutiques)->where('price', '<=', $max)->where('price', '>=', $min)->where('corbeil', false)->where('active', 1)->inRandomOrder()->simplePaginate(10);
}else{
 $articles = [];
}
        return json_encode($articles);
    }catch (\Exception $e){
        return json_encode($e);
    }
}


   public function all_products_filter_by_secteur(Request $request){
       $data=$request->all();
       $min=0;
       $max=99999999999;
       if(isset($data['categories']))
       $data['categories']=explode(',',$data['categories'][0]);
       if(isset($data['boutiques']))
           $data['boutiques']=explode(',',$data['boutiques'][0]);
       if(isset($data['min']) && $data['min']!=null)
           $min=intval($data['min']);
       if(isset($data['max']) && $data['max']!=null)
            $max=intval($data['max']);
try{
    $articles = CatalogueArticles::where('corbeil', false)->where('active', 1)->pluck('slug')->toArray();

    if (isset($data['boutiques']) && $data['boutiques'][0]!="") {
        $mesBoutique=[];
        for($i=0;$i<count($data['boutiques']);$i++){
            array_push($mesBoutique, str_replace(' ','_',strtolower($data['boutiques'][$i])));
        }

      $boutiques=  Boutique::whereIn('nom_boutique',$mesBoutique)->pluck('slug')->toArray();
        $articles = CatalogueArticles::whereIn('boutique_slug', $boutiques)->pluck('slug')->toArray();
           }
  if (isset($data['categories']) && $data['categories'][0]!="") {
               $categories = \App\CategorieCatalogue::whereIn('intitule',$data['categories'])->pluck('slug')->toArray();
               $articles = CatalogueArticles::whereIn('slug',$articles)->whereIn('categorie_slug', $categories)->pluck('slug')->toArray();
           }


    if (isset($data['name']) && $data['name'] != null) {
        $articles = CatalogueArticles::where('name','like','%'. $data['name'].'%')->whereIn('slug',$articles)->pluck('slug')->toArray();
    }


if(isset($data['star']) && $data['star']!='false' && $data['star']!='undefined'){
    $visites= check_products::pluck('catalogue_article_slug')->toArray();
    $newCheck=array_count_values($visites);
    arsort($newCheck);
    $newCheck=array_keys($newCheck);
$articles=array_intersect($articles,$newCheck);
}

if(isset($data['most_sell']) && $data['most_sell']!='false' && $data['most_sell']!='undefined'){
    $command= CommandArticle::pluck('article_slug')->toArray();
    $newCheck=array_count_values($command);
    arsort($newCheck);
    $newCheck=array_keys($newCheck);
    $articles=array_intersect($articles,$newCheck);
}
    if (isset($data['promotion']) && $data['promotion']!='false' && $data['promotion']!='undefined') {
        $data['promotion']=='true' ? $data['promotion']=1 : $data['promotion']=1;
        $articles = CatalogueArticles::whereIn('slug',$articles)->where('on_sale',$data['promotion'] )->pluck('slug')->toArray();
    }

if(count($articles)>0) {
    $country=$request->header('country');
    $boutiques=  Boutique::with('meta')->whereHas('meta',function($q) use ($country){
        $q->where('internationalize',1)->where('pay_internationalize',1)->orwhere('country','like','%'.$country.'%')->whereNotNull('country');
    })->where('expired',false)->where('maintenance',false)->where('corbeil',false)->where('installer',true)->where('metier_slug',$data['secteur'])->pluck('slug')->toArray();
    $articles = CatalogueArticles::has('images')->with(['boutique','boutique.meta','boutique.publicites','images','article_meta','categorie','categorie.caracteristique','categorie.caracteristique.article_meta'])->whereIn('slug', $articles)->whereIn('boutique_slug',$boutiques)->where('price', '<=', $max)->where('price', '>=', $min)->where('corbeil', false)->where('active', 1)->inRandomOrder()->simplePaginate(10);
}else{
    $articles = [];
}
           return json_encode($articles);
       }catch (\Exception $e){
           return json_encode($e);
       }
   }

   public function all_products_filter_promo(Request $request){
        $data=$request->all();
        $min=0;
        $max=9999999999;
        if(isset($data['categories'])) $data['categories']=explode(',',$data['categories'][0]);
        if(isset($data['min']) && $data['min']!=null) $min=intval($data['min']);
        if(isset($data['max']) && $data['max']!=null) $max=intval($data['max']);
        try{
            $articles = CatalogueArticles::where('corbeil', false)->where('active', 1)->pluck('slug')->toArray();
            if (isset($data['categories']) && $data['categories'][0]!="") {
               $categories = \App\CategorieCatalogue::whereIn('intitule', $data['categories'])->pluck('slug')->toArray();
               $articles = CatalogueArticles::whereIn('categorie_slug', $categories)->pluck('slug')->toArray();
            }
            if (isset($data['name']) && $data['name'] != null) {
                $articles = CatalogueArticles::where('name','like','%'. $data['name'].'%')->orwhere('description','like','%'. $data['name'].'%')->whereIn('slug',$articles)->pluck('slug')->toArray();
            }
            if(isset($data['star']) || $data['star']!='false' || $data['star']!=false || $data['star']!='undefined'){
                $visites= check_products::pluck('catalogue_article_slug')->toArray();
                $newCheck=array_count_values($visites);
                arsort($newCheck);
                $newCheck=array_keys($newCheck);
                $articles=array_intersect($articles,$newCheck);
            }
            if(isset($data['most_sell']) || $data['most_sell']!='false' ||$data['most_sell']!=false || $data['most_sell']!='undefined' || $data['most_sell']!=null){
                $command= CommandArticle::pluck('article_slug')->toArray();
                $newCheck=array_count_values($command);
                arsort($newCheck);
                $newCheck=array_keys($newCheck);
                $articles=array_intersect($articles,$newCheck);
            } 
            Log::info($min);
            Log::info($max);
            if(count($articles)>0) {
                $country=$request->header('country');
                $boutiques =  Boutique::with('meta')
                    ->whereHas('meta',function($q) use ($country){
                        $q->where('internationalize',1)
                        ->where('pay_internationalize',1)
                        ->orwhere('country','like','%'.$country.'%')
                        ->whereNotNull('country');
                })->where('expired',false)
                    ->where('maintenance',false)
                    ->where('corbeil',false)
                    ->where('installer',true)
                    ->pluck('slug')->toArray();

                $articles = CatalogueArticles::has('images')
                    ->with(['boutique','boutique.meta','boutique.publicites','images','article_meta','categorie','categorie.caracteristique','categorie.caracteristique.article_meta'])
                    ->whereIn('slug', $articles)
                    ->whereIn('boutique_slug',$boutiques)
                    ->where('price', '>=', $min)
                    ->where('price', '<=', $max)
                    ->where('on_sale',1)
                    ->where('active',1)
                    ->inRandomOrder()
                    ->simplePaginate(10);
            }else{
                $articles = [];
            }
            return json_encode($articles);
        }catch (\Exception $e){
            return json_encode($e);
        }
   }


   public function all_products_filter_favorite(Request $request){
       $data=$request->all();
       $categories=[];
       $min=0;
       $max=9999999999999;
       if(isset($data['categories']))
       $data['categories']=explode(',',$data['categories'][0]);
       if(isset($data['min']) && $data['min']!=null)
           $min=intval($data['min']);
       if(isset($data['max']) && $data['max']!=null)
            $max=intval($data['max']);
try{
    $articles = CatalogueArticles::where('corbeil', false)->where('active', 1)->pluck('slug')->toArray();


    if (isset($data['categories']) && $data['categories'][0]!="") {
               $categories = \App\CategorieCatalogue::whereIn('intitule', $data['categories'])->pluck('slug')->toArray();
               $articles = CatalogueArticles::whereIn('categorie_slug', $categories)->pluck('slug')->toArray();
           }


    if (isset($data['name']) && $data['name'] != null) {
        $articles = CatalogueArticles::where('name','like','%'. $data['name'].'%')->whereIn('slug',$articles)->pluck('slug')->toArray();
    }


if(isset($data['star']) && $data['star']!='false' && $data['star']!='undefined'){
    $visites= check_products::pluck('catalogue_article_slug')->toArray();
    $newCheck=array_count_values($visites);
    arsort($newCheck);
    $newCheck=array_keys($newCheck);
$articles=array_intersect($articles,$newCheck);
}

if(isset($data['most_sell']) && $data['most_sell']!='false' && $data['most_sell']!='undefined'){
    $command= CommandArticle::pluck('article_slug')->toArray();
    $newCheck=array_count_values($command);
    arsort($newCheck);
    $newCheck=array_keys($newCheck);
    $articles=array_intersect($articles,$newCheck);
}


    if (isset($data['promotion']) && $data['promotion']!='false' && $data['promotion']!='undefined') {
        $data['promotion']=='true' ? $data['promotion']=1 : $data['promotion']=1;
        $articles = CatalogueArticles::whereIn('slug',$articles)->where('on_sale',$data['promotion'] )->pluck('slug')->toArray();
    }

    $favoris=wishlist_article::where('user_slug',$data['user'])->pluck('catalogue_article_slug')->toArray();
    $newCheck=array_count_values($favoris);
    arsort($newCheck);
    $newCheck=array_keys($newCheck);
    $articles=array_intersect($articles,$newCheck);


    if(count($articles)>0) {
        $country=$request->header('country');
         $boutiques=  Boutique::with('meta')->whereHas('meta',function($q) use ($country){
           $q->where('internationalize',1)->where('pay_internationalize',1)->orwhere('country','like','%'.$country.'%')->whereNotNull('country');
       })->where('expired',false)->where('maintenance',false)->where('corbeil',false)->where('installer',true)->pluck('slug')->toArray();
        $articles = CatalogueArticles::has('images')->with(['boutique','boutique.meta','boutique.publicites','images','article_meta','categorie','categorie.caracteristique','categorie.caracteristique.article_meta'])->whereIn('slug', $articles)->whereIn('boutique_slug',$boutiques)->where('price', '<=', $max)->where('price', '>=', $min)->where('corbeil', false)->where('active', 1)->inRandomOrder()->get();
}else{
    $articles = [];
}
           return json_encode($articles);
       }catch (\Exception $e){
           return json_encode($e);
       }
   }

   public function get_shop_by_secteur_activity(Request $request){
       $data=$request->all();
       $country = $request->header('country');
       $boutiques=  Boutique::with('meta')->whereHas('meta',function($q) use ($country){
           $q->where('internationalize',1)->where('pay_internationalize',1)->orwhere('country','like','%'.$country.'%')->whereNotNull('country');
       })->where('expired',false)->where('maintenance',false)->where('corbeil',false)->where('installer',true)->pluck('slug')->toArray();

       if($data['slug']=='all') {
           $boutiques = Boutique::where('corbeil',false)->whereIn('slug',$boutiques)->get();
       }else {
           $metier=  Metier::whereIn('intitule_metier',$data['slug'])->pluck('slug')->toArray();
           $boutiques = Boutique::whereIn('metier_slug', $metier)->whereIn('slug',$boutiques)->where('corbeil',false)->get();
       }
       return json_encode($boutiques);
   }

   public function get_shop_by_secteur_activity_slug(Request $request){
       $data=$request->all();
    try {
        $country = $request->header('country');
        $metier=  Metier::where('intitule_metier',$data['slug'])->orWhere('slug',$data['slug'])->pluck('slug')->toArray();
        $boutiques=  Boutique::with('meta')->whereHas('meta',function($q) use ($country){
            $q->where('internationalize',1)->where('pay_internationalize',1)->orwhere('country','like','%'.$country.'%')->whereNotNull('country');
        })->where('expired',false)->where('maintenance',false)->where('corbeil',false)->where('installer',true)->pluck('slug')->toArray();
        $boutiques = Boutique::with('meta')->whereIn('slug',$boutiques)->where('expired', false)->where('maintenance', false)->where('corbeil', false)->where('installer', true)->whereIn('metier_slug', $metier)->get();
        return json_encode($boutiques);
    }catch (\Exception $e){
        return json_encode($e);
    }
   }

   public function get_all_shop(Request $request){
       $country=$request->header('country');
       $boutiques=  Boutique::with('meta')->whereHas('meta',function($q) use ($country){
           $q->where('internationalize',1)->where('pay_internationalize',1)->orwhere('country','like','%'.$country.'%')->whereNotNull('country');
       })->where('expired',false)->where('maintenance',false)->where('corbeil',false)->where('installer',true)->get();
       return json_encode($boutiques);
   }

    public function most_visite_shop(Request $request){
      try{
       $visite= check_boutiques::pluck('boutique_slug')->toArray();
       $newCheck=array_count_values($visite);
       arsort($newCheck);
       $newCheck=array_keys($newCheck);
        $country=$request->header('country');
        $boutiques=  Boutique::with('meta')->whereHas('meta',function($q) use ($country){
            $q->where('internationalize',1)->where('pay_internationalize',1)->orwhere('country','like','%'.$country.'%')->whereNotNull('country');
        })->where('expired',false)->where('maintenance',false)->where('corbeil',false)->where('installer',true)->pluck('slug')->toArray();
        $boutiques=  Boutique::with('meta','publicites','metier')->whereIn('slug',$newCheck)->whereIn('slug',$boutiques)->where('expired',false)->where('maintenance',false)->where('corbeil',false)->where('installer',true)->limit(3)->get();
        return json_encode($boutiques);
    }catch(\Exception $e){
return json_encode($e->getMessage());
}
    }

    public function most_like_shop(Request $request){
        try {
            $favoris = check_boutiques::pluck('boutique_slug')->toArray();
            $newCheck = array_count_values($favoris);
            arsort($newCheck);
            $newCheck = array_keys($newCheck);
            $country = $request->header('country');
            $boutiques = Boutique::with('meta')->whereHas('meta', function ($q) use ($country) {
                $q->where('internationalize', 1)->where('pay_internationalize', 1)->orwhere('country', 'like', '%' . $country . '%')->whereNotNull('country');
            })->where('expired', false)->where('maintenance', false)->where('corbeil', false)->where('installer', true)->pluck('slug')->toArray();
            $boutiques = Boutique::with('meta', 'publicites', 'metier')->whereIn('slug', $newCheck)->whereIn('slug', $boutiques)->where('expired', false)->where('maintenance', false)->where('corbeil', false)->where('installer', true)->limit(10)->get();
            return json_encode($boutiques);
        }catch(\Exception $e){
            return json_encode($e->getMessage());
        }
    }


    public function AjouterCommande(Request $request){
        $data=$request->all();
        try {
            $dataCaracteristiques = json_decode($data['caracteristiques'],true);
            $specifications = json_decode($data['specifications'],true) !==null  ? json_decode($data['specifications'],true)  : $specifications=[];
            $cart = json_decode($data['cart'], true);
            $globalCart = [];
            $globalBoutique = [];
            $allCommande = [];
            $allTotal = 0;
            for ($i = 0; $i < count($cart); $i++) {
                if (!array_key_exists($cart[$i]['product']['boutique_slug'],$globalBoutique))
                    $globalBoutique[$cart[$i]['product']['boutique_slug']] = [];
                array_push($globalBoutique[$cart[$i]['product']['boutique_slug']], $cart[$i]);
            }
            $data['statut_paiement'] = false;
            $data['statut_shipping'] = false;
            $data['total_price'] = 0;
            $data['reference'] = 'attente paiement';
            if ($data['command_type'] == 1) {
                $data['shipping'] = true;
                $data['paiement_type'] = 'paid_now';
            } else {
                $data['shipping'] = false;
                $data['paiement_type'] = 'paid_after';
            }
            if (isset($data['user_slug']) && $data['user_slug']!==null) {
                $data['have_account'] = true;
            } else {
                $data['have_account'] = false;
            }
            $data['is_global']=true;
            $data['reference_global']='cmd-gl-'.str_random(6);
            if(isset($data['code_promo']) && $data['code_promo']!=null){
                $codePromos = DB::table('global_promos')->where('code',$data['code_promo'])->first();
                if($codePromos!=null){
                    $data['montant_global_code_promo']=$codePromos->percentage;
                    $data['global_code_promo']=$codePromos->code;
                }
            }
            foreach ($globalBoutique as $key => $value) {
                $boutique_slug = $key;
                $data['slug'] = 'cmd-'.str_random(6);
                $data['boutique_slug'] = $boutique_slug;
                $commande_id = Commandes::create($data)->id;
                Session::put('command_id_new', $commande_id);
                $total = 0;
                $choice = [];
                for ($i = 0; $i < count($globalBoutique[$key]); $i++) {
                    $articles = CatalogueArticles::where('slug', $globalBoutique[$key][$i]['product']['slug'])->first();
                    $categorie_id = \App\CategorieCatalogue::where('slug', $globalBoutique[$key][$i]['product']['categorie_slug'])->first()['id'];
                   if(isset($dataCaracteristiques) && count($dataCaracteristiques)>0) {
                           foreach ($dataCaracteristiques as $key2 => $value2) {
                               if (strpos($key2, $globalBoutique[$key][$i]['product']['slug']) !==false) {
                                    $newTab = explode('sungrocery', $key2);
                                       $choice[$newTab[1]] = implode(',', $value2);
                                }
                            }
                    }
                    $helpers = new HelperController();
                    $prix = $helpers->get_article_price_by_boutique($globalBoutique[$key][$i]['product']['slug'], $boutique_slug);
                    $prix_vente = $prix * $globalBoutique[$key][$i]['quantiy'];
                    $total += $prix_vente;
                    $slug = Str::slug('article' . time() . 'slug' . time() . 'command');
                    $specification=array_key_exists($globalBoutique[$key][$i]['product']['slug'],$specifications) ? $specifications[$globalBoutique[$key][$i]['product']['slug']] : '';
                    CommandArticle::create(['slug' => $slug, 'command_slug' => $data['slug'], 'article_slug' => $globalBoutique[$key][$i]['product']['slug'], 'price' => $prix, 'quantity' => $globalBoutique[$key][$i]['quantiy'], 'total_price' => $prix_vente, 'specificity' => $specification, 'choice' => json_encode($choice)]);
                }
                array_push($allCommande, $commande_id);
               /*  $cmd = Commandes::findOrFail($commande_id);
                $cmd->total_price = $total;
                $cmd->save(); */
                $cmd= Commandes::findOrFail($commande_id);
                $cmd->total_price=$total;
                $cmd->total_wr=$total;
                if(isset($data['montant_global_code_promo'])){
                    $new_price=$total-(($total*$data['montant_global_code_promo'])/100);
                    $cmd->total_price=$new_price;
                    $cmd->total_wr=$new_price;
                    $total=$new_price;
                }
                $allTotal += $total;
                $cmd->save();
                if(isset($data['echellonPaiement'])){
                    $paiement_echelonner=PaiementEchelonner::where('boutique_slug',$boutique_slug)->first();
                    if(isset($paiement_echelonner)) if($paiement_echelonner->max>0) $total=(doubleval($total)/intval($paiement_echelonner->max))+1;
                }
                // envoyer un email au gerant de la boutique
               /*  $boutique=Boutique::with('user')->where('slug',$boutique_slug)->first();
                $subject = 'Nouvelle commande enregistré sur la boutique '.$boutique->nom_boutique;
                $messages = ['first_name'=>$data['first_name'],'last_name'=>$data['last_name'],'montant'=>$total,'boutique'=>$boutique->nom_boutique];
                MailController::SendGeneralUniqueMail('Mail.commande_seller',$subject, $messages, $boutique->user->email,env('MAIL_USERNAME'));

                // Envoyer un email au cleint
                $subject = 'commande enregistré pour '.$data['last_name'].' '.$data['first_name'].' sur la boutique '.$boutique->nom_boutique;
                $messages = ['first_name'=>$data['first_name'],'last_name'=>$data['last_name'],'montant'=>$total,'boutique'=>$boutique->nom_boutique,'have_account'=>$data['have_account']];
                MailController::SendGeneralUniqueMail('Mail.commande_client',$subject, $messages, $data['email'],env('MAIL_USERNAME'));
            */ }
            $message='Commande validée avec succès ! Votre commande à été transmis au gestionnaire de la boutique cible. Vous serai contacter pour les formalitées de livraison. Accédé à la liste des commandes pour vérifier vos transactions.';
            return json_encode(['error'=>false,'message'=>$message,'commandes' => $allCommande, 'total' => $allTotal]);
        }catch (\Exception $e){
            return json_encode(['error'=>true,'message'=>$e->getMessage()]);
        }
    }


    public function checkpaiement(Request $request)
    {
        $data = $request->all();
        try {
            $total = $data['total'];
            $comandes = $data['command'];
            $public_key = env('INTRAM_PUBLIC');
            $secret = env('INTRAM_SECRET');
            $private_key = env('INTRAM_PRIVATE');
            $intram = new \Intram\Intram($public_key, $private_key, $secret, false); 
            $transaction_id = $data['transaction_id'];
            $verify = $intram->getTransactionStatus($transaction_id);
            $status = $verify->status;
            if ($total != $verify->amount) {
                return ['error' => true, 'message' => 'Paiement non valide. Vous n\'avez pas payé le montant dû de la transaction'];
            }
            for ($i = 0; $i < count($comandes); $i++) {
                $cmd = Commandes::findOrFail($comandes[$i]);
                if ($status == 'SUCCESS') {
                    $cmd->paiement_type = 'paid_now';
                    $cmd->source = $verify->source;
                    $cmd->source_name = "intram";
                    $reference = $transaction_id;
                    $cmdt = CommandArticle::where('command_slug', $cmd->slug)->get();
                    foreach ($cmdt as $commandearticle) {
                        $article = CatalogueArticles::where('slug', $commandearticle->article_slug)->first();
                        if ($article['boutique_slug'] == $cmd['boutique_slug']) {
                            $modart = CatalogueArticles::findOrFail($article['id']);
                            $modart->quantity = (intval($modart->quantity) - intval($commandearticle->quantity));
                            $modart->save();
                        } else {
                            $helpers = new HelperController();
                            $stock = $helpers->get_meta_article('stock', $commandearticle->article_slug, $cmd['boutique_slug']);
                            $stock = (intval($stock) - intval($commandearticle->quantity));
                            $helpers->update_meta_article('stock', $commandearticle->article_slug, $stock, $cmd['boutique_slug']);
                        }
                    }
                    $boutique = Boutique::with('user')->where('slug', $cmd['boutique_slug'])->first();
                    $cmd_pricing = $cmd->total_price;
                    if($cmd->is_global){
                        $cmd_pricing = $cmd_pricing - (($cmd_pricing * 5) / 100);
                        $cmd->admin_percentage=5;
                        $cmd->admin_gain=(($cmd_pricing * 5) / 100);
                    }else{
                        $cmd_pricing = $cmd_pricing - (($cmd_pricing * 10) / 100);
                        $cmd->admin_percentage=10;
                        $cmd->admin_gain=(($cmd_pricing * 5) / 100);
                    }
                    Portefeuille::incrementAdminPortefeuille(
                        $cmd->admin_gain
                        ,
                        'VENTE',
                        $cmd->admin_percentage.' de gain de vente'
                        ,'xof');
                   
                   } else {
                    $reference = 'echec paiement';
                    return ['error' => true, 'message' => 'Echec de paiement. Votre paiement n\'a pas été validé.'];
                }
                $cmd->reference = $reference;
                $cmd->statut_paiement = true;
                $cmd->save();
            }
            return ['error' => false, 'message' => 'Paiement effectué avec succès. Vous pouvez accédé à la liste des commandes pour consulter les commandes antérieures.'];

        }catch (\Exception $e){
            return ['error' => true, 'message' => 'Echec de paiement. Votre paiement n\'a pas été validé. '.$e->getMessage()];
          //  return json_encode($e->getMessage().' '.$e->getLine());
        }
         }


    public function cart(){

   }

   public function favoris(){

   }





   /* public function register_web(Request $request){

         try{

             $rules = array(
                 'first_name'=> 'required|string',
                 'last_name'=> 'required|string',
                 'email'=> 'required|email|unique:users|max:255',
                 'username'=> 'required|string|unique:users|max:255',
                 'password'=> 'required|string|min:6'

             );

             $validator = \Illuminate\Support\Facades\Validator::make(Input::all(),$rules);
            /* if ($validator->fails()) {
                 return back()
                     ->withErrors($validator)
                     ->withInput();
             }*/
    /* if ($validator->fails())
     {
         return \Illuminate\Support\Facades\Response::json(array('success'=>false,'errors'=>$validator->getMessageBag()->toArray()),400);
     }else{
         $response = $this->register($request);
         $get_array_response=json_decode($response,true);

         if($get_array_response['statut']){
             Session::flash('success',$get_array_response['message']);

         }else{
             Session::flash('error',$get_array_response['message']);

         }
     }

 }catch (\Exception $e){
     Session::flash('error',$e->getMessage());

 }


}*/

    public function confirm_account_web($id){
        $response = $this->confirm_account($id);
        $get_array_response=json_decode($response,true);

        if($get_array_response['statut']){
            Session::flash('success',$get_array_response['message']);

        }else{
            Session::flash('error',$get_array_response['message']);
        }
        return redirect('login');
    }

/*     public function checkIfAuthIsLog($user){
        if ($user = Sentinel::getUser())
        {
           return json_encode(['user'=>$user,'error'=>false]);
        }else{
            return json_encode(['user'=>null,'error'=>true]);
        }
    } */

    public function login(Request $request)
    {
        
        $message='';
        $statut=true;
        $data = $request->all();
        $users=[];
        $error=false;
        $message='';
        $url='';
        $user=[];
        try {
            $user=DB::table('users')->where('email',$data['email'])->orwhere('username',$data['email'])->first();
           $credentials = [
                'email' => $user->email,
                'password' => $data['password']
            ];
            if (Auth::attempt($credentials)){
               $user=Auth::user();
                if(isset($data['commandes'])){
                    $data['commandes']=json_decode($data['commandes'],true);
                    DB::table('commandes')->whereIn('id',$data['commandes'])->update(['user_slug'=>$user->slug]);
                }
               $user=User::with('meta')->where('id',$user->id)->first();
               $message = 'Connexion établie avec succès.';
            } else {
                $error = true;
                $message = 'Connexion refusée. Une erreure inconnu est survenue';
            }
        }catch (\Exception $e){
            $error = true;
            $message = 'Une erreur s\'est produite au cours de l\'authentification '.$e->getMessage();
        }
        return json_encode(['error'=>$error,'message'=>$message,'url'=>$url,'user'=>$user]);
    }

    public function client_register(Request $request){
        $data=$request->all();
        if($data['password'] != $data['cpassword']){
            return json_encode(['error'=>true,'message'=>"le mot de passe de confirmation n'est pas valide"]);
        }
        $response=$this->register($request);
        $response=json_decode($response,true);
        $error=false;
        $message='';
        if($response['statut']){
            $message='Inscription effectué avec succès veuillez vous connecter avec les informations précedemment saisis';
        }else{
            if(isset($response['input_error'])){
                $error_input='';
                for ($i = 0; $i < count($response['input_error']);$i++) {
                    foreach ($response['input_error'] as $key => $value){
                        $error_input .=' '.$value[0].' - ';
                    }
                }
                $error=true;
                $message=$error_input;
            }else{
                $error=true;
                $message=$response['message'];
            }

        }
        return json_encode(['error'=>$error,'message'=>$message]);
    }

    public function register(Request $request){

        $data=$request->all();
        $imagepath='logo_mini.jpg';
        if(!isset($data['type'])){
            $data['type']='admin';
        }
        try{
            $rules = array(
                'first_name'=> 'required|string',
                'telephone'=>'required|string',
                'sexe'=>'required|string',
                'last_name'=> 'required|string',
                'email'=> 'required|email|unique:users|max:255',
                'username'=> 'required|string|unique:users|max:255',
                'password'=> 'required|string|min:6'
            );
            $validator = \Illuminate\Support\Facades\Validator::make($data,$rules);
            if ($validator->fails())
            {
                $message= $validator->getMessageBag()->first();
                return json_encode(['statut'=>false,"message"=>$message]);
            }else {

                $data['slug'] = Str::slug('user' . time());
                $country = DB::table('countries')->where('name', $data['country'])->first();
                $region = DB::table('states')->where('name', $data['region'])->first();
                $city = DB::table('cities')->where('name', $data['city'])->first();
                $continent = DB::table('continents')->where('Two_Letter_Country_Code', $country->iso2)->first();
                $data['country'] = $country->name;
                $data['region'] = $region->name;
                $data['city'] = $city->name;
                $data['continent'] = $continent->Continent_Name;
                $data['password']=Hash::make($data['password']);
                $user = User::create($data);
                $user_model = new \App\Users_meta();
                $user_model->update_user_meta($user->id, 'profil_picture', $imagepath);
                if(isset($data['commandes'])){
                    $data['commandes']=json_decode($data['commandes'],true);
                    DB::table('commandes')->whereIn('id',$data['commandes'])->update(['user_slug'=>$data['slug']]);
                }
                $subject = 'Inscription à sungrocery réussit';
                $messages = ['first_name' => $data['first_name'], 'last_name' => $data['last_name']];
                MailController::SendRegisterMail($subject, $messages, $data['email']);
                if ($user) {
                    Privilege_access::create(['user_fk_user_controle' => $user['id'], 'privilege_slug' => 'utilisateur']);
                    return json_encode(['statut' => true, "message" => "Inscription effectuée avec succès"]);
                } else {
                    return json_encode(['statut' => false, "message" => "Une erreur s'est produite au cours du processus. Veuillez réactualiser la page et reéssayer ou contacter l'équipe si le problème persite"]);
                }
            }

        }catch (\Exception $e){
            $message=$e->getMessage();
            return json_encode(['statut'=>false,"message"=>"Une erreur s'est produite au cours du processus. Veuillez réactualiser la page et reéssayer ou contacter l'équipe si le problème persite. ".$message]);

        }

    }

    public function shipping_after_command_make(Request $request){
        $data=$request->all();
      try {
          $commandes = Commandes::where('slug', $data['slug'])->first();
          $cmd = Commandes::findOrFail($commandes['id']);
          $cmd->shipping_phone = $data['shipping_phone'];
          $cmd->shipping_adress = $data['shipping_adress'];
          $cmd->shipping = true;
          $cmd->save();
          return json_encode(true);
      }catch (\Exception $e){
          return json_encode($e->getMessage());
      }
    }

    public function list_commande(Request $request){
        $data=$request->all();
        try {
          $commandes= Boutique::has('commande')->with(['meta','publicites','commande'=>function($q) use ($data){
                $q->where('user_slug', $data['user_slug'])->where('statut_shipping',false)->where('corbeil', false)->orderByDesc('id');
            },'commande.commande_article', 'commande.commande_article.article_', 'commande.commande_article.article_.article_meta', 'commande.commande_article.article_.images'])->where('corbeil',false)->get();

         $commande_finish= Boutique::has('commande')->with(['meta','publicites','commande'=>function($q) use ($data){
                $q->where('user_slug', $data['user_slug'])->where('statut_shipping',true)->where('corbeil', false)->orderByDesc('id');
            },'commande.commande_article', 'commande.commande_article.article_', 'commande.commande_article.article_.article_meta', 'commande.commande_article.article_.images'])->where('corbeil',false)->get();

        return json_encode(['waiting'=>$commandes,'finish'=>$commande_finish]);
        }catch (\Exception $e){
            return json_encode($e);
        }
        }


    public function filter(Request $request){
     try {
         $metiers = Metier::where('intitule_metier', 'like', '%' . $request->search . '%')->where('description_metier', 'like', '%' . $request->search . '%')->pluck('slug')->toArray();
         if (isset($metiers) && count($metiers) > 0) {
             $categories = CategorieCatalogue::where('intitule', 'like', '%' . $request->search . '%')->where('description', 'like', '%' . $request->search . '%')->whereIn('secteur_activite', $metiers)->pluck('slug')->toArray();
         } else {
             $categories = CategorieCatalogue::where('intitule', 'like', '%' . $request->search . '%')->where('description', 'like', '%' . $request->search . '%')->pluck('slug')->toArray();
         }

         if (isset($categories) && count($categories) > 0) {
             $articles = CatalogueArticles::whereIn('slug', $categories)->pluck('slug')->toArray();
         } else {
             $articles = CatalogueArticles::where('name', 'like', '%' . $request->search . '%')
                 ->where('description', 'like', '%' . $request->search . '%')
                 ->where('active', 1)->where('corbeil', false)->pluck('slug')->toArray();
         }
         if (isset($articles) && count($articles)>0) {
             $articles = CatalogueArticles::has('images')->with(['boutique','boutique.meta','boutique.publicites','images','article_meta','categorie','categorie.caracteristique','categorie.caracteristique.article_meta'])->whereIn('slug', $articles)->get();
         } else {
             $articles = [];
         }
         return json_encode($articles);
     }catch (\Exception $e){
         return json_encode($e->getMessage());
     }
    }
    public function filter_search($search){
         $metiers = Metier::where('intitule_metier', 'like', '%' . $search . '%')->orwhere('description_metier', 'like', '%' . $search . '%')->pluck('slug')->toArray();
         if (isset($metiers) && count($metiers) > 0) {
             $categories = CategorieCatalogue::where('intitule', 'like', '%' . $search . '%')->orwhere('description', 'like', '%' . $search . '%')->whereIn('secteur_activite', $metiers)->pluck('slug')->toArray();
         } else {
             $categories = CategorieCatalogue::where('intitule', 'like', '%' . $search . '%')->orwhere('description', 'like', '%' . $search . '%')->pluck('slug')->toArray();
         }

         if (isset($categories) && count($categories) > 0) {
             $articles = CatalogueArticles::where('name', 'like', '%' . $search . '%')->orwhereIn('slug', $categories)->pluck('slug')->toArray();
         } else {
             $articles = CatalogueArticles::where('name', 'like', '%' . $search . '%')
                 ->orwhere('description', 'like', '%' . $search . '%')->pluck('slug')->toArray();
         }
         if (isset($articles) && count($articles)>0) {
             $articles = CatalogueArticles::whereIn('slug', $articles)->pluck('slug');
         } else {
             $articles = [];
         }
         return $articles;
    }

    public function update_user_password(Request $request){
        $data=$request->all();
        try {
            $user = User::findOrFail($data['user_id']);
            if ($data['password'] != $data['cpassword']) {
                $error = true;
                $message = 'Mot de passe de confirmation incorrect';
            } else {
                if (!Hash::check($data['oldpassword'], $user->password)) {
                    $error = true;
                    $message = 'Mot de passe non confimer.';
                } else {
                    $credentials = [
                        'password' => $data['password'],
                    ];
                   $user =DB::table('users')->where('id',$user->id)->update($credentials);
                    if (isset($user)) {
                        $error = false;
                        $message = 'Mot de passe mis à jour';
                    } else {
                        $error = true;
                        $message = 'Echec de modification de vos informations';
                    }
                }
            }
            $user= User::with('meta')->where('id',$user->id)->first();
            return json_encode(['error' => $error, 'message' => $message, 'user' => $user]);
        }catch (\Exception $e){
            return json_encode($e->getMessage());
        }
    }

    public function update_user(Request $request){

        try{
        $imagepath="logo_mini.jpg";
        $user_pic=1;
        $data=$request->all();
        $user = User::findOrFail($data['user_id']);
            $country=DB::table('countries')->where('name',$data['country'])->first();
            $continent= DB::table('continents')->where('Two_Letter_Country_Code',$country->iso2)->first();

            $credentials = [
            'email' => $data['email'],
            'username' => $data['username'],
            'first_name' => $data['first_name'],
            'last_name' => $data['last_name'],
            'telephone' => $data['telephone'],
            'sexe' => $data['sexe'],
            'country'=>$data['country'],
            'city'=>$data['city'],
            'region'=>$data['region'],
                'continent'=>$continent->Continent_Name
        ];

        $users =DB::table('users')->where('id',$user->id)->update($credentials);
        if (isset($users)) {
            if ($request->has('photo_profil')) {
                $user_model = new \App\Users_meta();
                if (!is_string(request()->photo_profil) and request()->photo_profil) {
                    $originalImage= $request->photo_profil;
                    $thumbnailImage = Image::make($originalImage);
                    $thumbnailPath = public_path('Profil_picture/');
                    $originalPath = public_path('Profil_picture/full/');
                    $time=time();
                    $thumbnailImage->save($originalPath.$time.$originalImage->getClientOriginalName());
                    $thumbnailImage->resize(150,150);
                    $thumbnailImage->save($thumbnailPath.$time.$originalImage->getClientOriginalName());
                    $imagepath=$time.$originalImage->getClientOriginalName();
                }
                $user_pic = $user_model->update_user_meta($data['user_id'], 'profil_picture', $imagepath);
            }
            if ($user_pic == 0) {
                $error=true;
                $message= 'Une erreur s\'est produite au cours de la modification. L\'image uploader n\'a pas pu être enregistrer';
            } else {
                $user=User::findOrFail($user->id);
                $error=false;
                $message= 'Votre profil utilisateur à été mis à jour avec succès.';
            }
        } else {
            $error=true;
            $message= 'Une erreur s\'est produite au cours de la modification';
        }
            $user= User::with('meta')->where('id',$user->id)->first();
             return json_encode(['error'=>$error,'message'=>$message,'user'=>$user]);
        }catch (\Exception $e){
            return json_encode($e->getMessage());
        }
    }

    public function resetPass(Request $request){
        $data=$request->all();
        try {
            $user = User::where('email', $data['email'])->orWhere('username', $data['email'])->first();
            $user=User::findOrFail($user->id);
            if (isset($user) && $user->id != null) {
                $subject = 'Récupération de votre mot de passe';
                $newpass = Str::slug($user->slug . time());
                $messages = ['email' => $user->username, 'password' => $newpass];
                $user->password = Hash::make($newpass);
                $user->save();
                $render = 2;
                MailController::SendPassMail($subject, $messages, $user->email, $render);
                $error = false;
                $message = 'Un nouveau mot de passe vous a été envoyer sur ' . $user->email . '. Veuillez consulter votre boîte mail pour le récupérer.';
            } else {
                $error = true;
                $message = 'Une erreure s\'est produite. Nous ne parvenons pas à trouver vos identifiants client. si cette erreur persiste veuillez s\'il vous plaît contacter le service client.';
            }
            return json_encode(['error' => $error, 'message' => $message]);
        }catch (\Exception $e){
            return json_encode($e->getMessage());

        }
    }


    public function paypalRredirect(Request $request)
    {
     try {
         $data = $request->all();
         /** Get the payment ID before session clear **/
         $payment_id = $data['paymentId'];
         $payerId = $data['PayerID'];
         $token = $data['token'];
         /** clear the session payment ID **/
         if (empty($payerId) || empty($token)) {
             return json_encode(['message' => 'Echec de paiement! la transaction n\'à pas aboutis', 'error' => true]);
         }
         $payment = Payment::get($payment_id, $this->_api_context);
         $execution = new PaymentExecution();
         $execution->setPayerId($payerId);
         /**Execute the payment **/
         $result = $payment->execute($execution, $this->_api_context);
         $transact = $result->getTransactions();
         if ($result->getState() == 'approved') {
             $status = 'SUCCESS';
             $comandes = json_decode($data['command'], true);
             for ($i = 0; $i < count($comandes); $i++) {
                 $cmd = Commandes::findOrFail($comandes[$i]);
                 $boutique = Boutique::with('meta')->where('slug', $cmd->boutique_slug)->first();
                 $cmd->paiement_type = 'paid_now';
                 $cmd->source = 'PAYPAL';
                 $cmd->source_name = 'paypal';
                 $reference = $payment_id;
                 $cmdt = CommandArticle::where('command_slug', $cmd->slug)->get();
                 foreach ($cmdt as $commandearticle) {
                     $article = CatalogueArticles::where('slug', $commandearticle->article_slug)->first();
                     if ($article['boutique_slug'] == $boutique['slug']) {
                         $modart = CatalogueArticles::findOrFail($article['id']);
                         $modart->quantity = (intval($modart->quantity) - intval($commandearticle->quantity));
                         $modart->save();
                     } else {
                         $helpers = new HelperController();
                         $stock = $helpers->get_meta_article('stock', $commandearticle->article_slug, $boutique['slug']);
                         $stock = (intval($stock) - intval($commandearticle->quantity));
                         $helpers->update_meta_article('stock', $commandearticle->article_slug, $stock, $boutique['slug']);
                     }
                 }
                 // Ajouter le montant à l'actif du détenteur de la boutique
                 $fportefeuille = Portefeuille::where('user_slug', $boutique['user_slug'])->where('devise', $boutique['meta']['currency_admin'])->first()['id'];
                 if (isset($fportefeuille) && $fportefeuille != null && $fportefeuille != "") {
                     $portefeuille = Portefeuille::findOrFail($fportefeuille);
                     $portefeuille->montant = $portefeuille->montant + $cmd->total_price;
                     $total_new_montant = $portefeuille->montant;
                     $time = false;
                     $portefeuille->save();
                 } else {
                     Portefeuille::create(['user_slug' => $boutique['user_slug'], 'montant' => $cmd->total_price]);
                     $time = true;
                 }
                 $boutique = Boutique::with('user', 'meta')->where('slug', $boutique['slug'])->first();
                 $metas = $boutique->meta;
                 $subject = 'Portefeuille incrementé sur la boutique ' . $boutique->nom_boutique;
                 $messages = ['first_name' => $boutique->user->first_name, 'last_name' => $boutique->user->last_name, 'montant' => $cmd->total_price, 'time' => $time, 'boutique' => $boutique->nom_boutique, 'devise' => $boutique['meta']['currency_admin']];
                 MailController::SendPortefeuilleMail($subject, $messages, $boutique->user->email);
                 $cmd->reference = $reference;
                 $cmd->statut_paiement = true;
                 $cmd->save();
             }
             return json_encode(['error' => false, 'message' => 'Commande validée avec succès ! Votre commande à été transmis au gestionnaire de la boutique cible. Vous serai contacter pour les formalitées de livraison. Accédé à la liste des commandes pour vérifier vos transactions.']);
         } else {
             return json_encode(['message' => 'Le paiement n\'a pas été effectué.', 'error' => true]);
         }

     }catch (\Exception $e){
         return json_encode(['message' => 'Le paiement n\'a pas été effectué.', 'error' => true]);
     }

    }


    public function paydunyaredirect(Request $request){
        //dd($request->all());
        $data=$request->all();
        try {
            $comandes = json_decode($data['command'],true);
           $invoice = new \Paydunya\Checkout\CheckoutInvoice();
            if ($invoice->confirm($data['token'])) {
                if ($invoice->getStatus() == "completed") {
                    for ($i = 0; $i < count($comandes); $i++) {
                        $cmd = Commandes::findOrFail($comandes[$i]);
                        $boutique = Boutique::with('meta')->where('slug', $cmd->boutique_slug)->first();
                        if ($invoice->getTotalAmount() == $cmd['total_price']) {
                            $status = 'SUCCESS';
                            $cmd->paiement_type = 'paid_now';
                            $cmd->source = 'PAYDUNYA';
                            $cmd->source_name = 'paydunya';
                            $reference = $data['token'];
                            $cmdt = CommandArticle::where('command_slug', $cmd->slug)->get();
                            foreach ($cmdt as $commandearticle) {
                                $article = CatalogueArticles::where('slug', $commandearticle->article_slug)->first();
                                if ($article['boutique_slug'] == $cmd->bouique_slug) {
                                    $modart = CatalogueArticles::findOrFail($article['id']);
                                    $modart->quantity = (intval($modart->quantity) - intval($commandearticle->quantity));
                                    $modart->save();
                                } else {
                                    $helpers = new HelperController();
                                    $stock = $helpers->get_meta_article('stock', $commandearticle->article_slug, $boutique['slug']);
                                    $stock = (intval($stock) - intval($commandearticle->quantity));
                                    $helpers->update_meta_article('stock', $commandearticle->article_slug, $stock, $boutique['slug']);
                                }
                            }
                            // Ajouter le montant à l'actif du détenteur de la boutique
                            $fportefeuille = Portefeuille::where('user_slug', $boutique['user_slug'])->where('devise', $boutique['meta']['currency_admin'])->first()['id'];
                            if (isset($fportefeuille) && $fportefeuille != null && $fportefeuille != "") {
                                $portefeuille = Portefeuille::findOrFail($fportefeuille);
                                $portefeuille->montant = $portefeuille->montant + $cmd->total_price;
                                $total_new_montant = $portefeuille->montant;
                                $time = false;
                                $portefeuille->save();
                            } else {
                                Portefeuille::create(['user_slug' => $boutique['user_slug'], 'montant' => $cmd->total_price]);
                                $time = true;
                            }
                            $boutique = Boutique::with('user', 'meta')->where('slug', $boutique['slug'])->first();
                            $metas = $boutique->meta;
                            $subject = 'Portefeuille incrementé sur la boutique ' . $boutique->nom_boutique;
                            $messages = ['first_name' => $boutique->user->first_name, 'last_name' => $boutique->user->last_name, 'montant' => $cmd->total_price, 'time' => $time, 'boutique' => $boutique->nom_boutique, 'devise' => $boutique['meta']['currency_admin']];
                            MailController::SendPortefeuilleMail($subject, $messages, $boutique->user->email);
                            $cmd->reference = $reference;
                            $cmd->statut_paiement = true;
                            $cmd->save();
                        }
                    }
                    return json_encode(['error'=>false,'message'=>'Commande validée avec succès ! Votre commande à été transmis au gestionnaire de la boutique cible. Vous serai contacter pour les formalitées de livraison. Accédé à la liste des commandes pour vérifier vos transactions.']);
                }
            }
        }catch (\Exception $e){
            return json_encode(['error'=>true,'message'=>'Une erreur s\'est produite. '.$e]);
        }
    }


    public function payDunyaCommand(Request $request){
        $data = $request->all();
        try{
            $comandes = $data['command'];
            $itemArray=[];
            for ($i = 0; $i < count($comandes); $i++) {
            $cmd = Commandes::findOrFail($comandes[$i]);
            $cmdt = CommandArticle::where('command_slug', $cmd->slug)->get();
            foreach ($cmdt as $commandearticle) {
                $article = CatalogueArticles::where('slug', $commandearticle->article_slug)->first();
                array_push($itemArray, ['name' => $article->name, 'quantity' => $commandearticle->quantity, 'unitaire' => $commandearticle->price, 'total' => $commandearticle->total_price]);
            }
        }
        $amount = $cmd->total_price;
        $description = "";
        $redirect_url = $data['return'];
        $val = $this->helpers->paydunyaPaiement($itemArray, $amount, $description, $redirect_url);
        if ($val !== null) {
            return ['error' => false, 'redirect_url' => $val];
        }
        return ['error' => true, 'message' => 'Une erreure s\'est produite.'];
    }catch (\Exception$e){
return json_encode(['error' => true, 'message' => 'Une erreure s\'est produite. '.$e]);
}
    }
    public function payCommandWithpaypal(Request $request)
    {
        try {
            $data = $request->all();
            $payer = new Payer();
            $payer->setPaymentMethod('paypal');
            $comandes = $data['command'];
            $total = 0;
            $helpers = new HelperController();
            $item = array();
            $currency = 'USD';
            for ($i = 0; $i < count($comandes); $i++) {
                $cmd = Commandes::findOrFail($comandes[$i]);
                $cmdt = CommandArticle::where('command_slug', $cmd->slug)->get();
                $currency = $cmd->currency;
                foreach ($cmdt as $commandearticle) {
                    $item_1 = new Item();
                    $article = CatalogueArticles::where('slug', $commandearticle->article_slug)->first();
                    $price = 'XOF';
                    if ($currency != 'USD' || $currency != 'EUR') {
                        $price = $helpers->convertCurrency($currency, 'USD', $commandearticle->price);
                        $currency = 'USD';
                    }
                    $price = (double)$price;
                    array_push($item, $item_1->setName($article->name)
                        ->setCurrency($currency)
                        ->setQuantity($commandearticle->quantity)
                        ->setPrice($price)
                    );
                }
                $currency = $cmd->currency;
                $total_price = $cmd->total_price;
                if ($currency != 'USD' || $currency != 'EUR') {
                    $total_price = $helpers->convertCurrency($currency, 'USD', $cmd->total_price);
                    $currency = 'USD';
                }
                $total += (double)$total_price;
            }
            $item_list = new ItemList();
            $item_list->setItems($item);
            $amount = new Amount();
            $amount->setCurrency('USD')->setTotal($total);
            $transaction = new Transaction();
            $transaction->setAmount($amount)
                ->setItemList($item_list)
                ->setDescription('Merci d\'avoir choisis sunmarket');
            $redirect_urls = new RedirectUrls();
            $redirect_urls->setReturnUrl($data['return'])/** Specify return URL **/
            ->setCancelUrl($data['return']);
            $payment = new Payment();
            $payment->setIntent('Sale')
                ->setPayer($payer)
                ->setRedirectUrls($redirect_urls)
                ->setTransactions(array($transaction));
            /** dd($payment->create($this->_api_context));exit; **/
            try {
                $payment->create($this->_api_context);
            } catch (\PayPal\Exception\PayPalConnectionException $ex) {
                if (Config::get('app.debug')) {
                    return json_encode(['item'=>$cmdt,'total'=>$total,'currency'=>$currency,'return_url' => $data['return'], 'error' => true, 'message' => 'Désolé votre connection à expirer sur paypal. Veuillez reéssayer un peu plus tard.' . $ex->getMessage()]);
                } else {
                    return json_encode(['item'=>$cmdt,'total'=>$total,'currency'=>$currency,'return_url' => $data['return'], 'error' => true, 'message' => 'Désolé une erreure est survenue. Veuillez reéssayer un peu plus tard.']);
                }
            }
            foreach ($payment->getLinks() as $link) {
                if ($link->getRel() == 'approval_url') {
                    $redirect_url = $link->getHref();
                    break;
                }
            }
            /** add payment ID to session **/
            if (isset($redirect_url)) {
                /** redirect to paypal **/
                return json_encode(['redirect_url' => $redirect_url, 'error' => false, 'paypal_payment_id' => $payment->getId()]);
            }
            return json_encode(['return_url' => $data['return'], 'error' => true, 'message' => 'Une erreure est survenue. Veuillez reéssayer un peu plus tard.']);
        }catch (\Exception $e){
            return json_encode(['error' => true, 'message' => 'Une erreure est survenue. Veuillez reéssayer un peu plus tard. '.$e]);
        }
        }


}
