<?php

namespace App\Http\Controllers\mib\Api;

use App\LotMib;
use App\Boutique;
use App\ClientMib;
use App\CategoriesMib;
use App\CotisationMib;
use App\panierMibYear;
use App\CategorieCatalogue;
use Illuminate\Support\Str;
use Illuminate\Http\Request;
use App\mibBoutiqueSouscription;
use Illuminate\Support\Facades\DB;
use App\Http\Controllers\Controller;

class MibController extends Controller
{

    public function __construct()
    {
        $this->middleware('auth:api');
    }

    public function mib_list_by_user()
    {

        $user = auth()->user();

        $boutiques = Boutique::where('user_slug', $user->slug)
            ->where('corbeil', false)
            ->get();

        $datas = [];

        foreach ($boutiques as $key => $boutique) {
            $mib_panner = mibBoutiqueSouscription::where('id_boutique', $boutique->id)
                ->with('boutique')
                ->get();

            if ($mib_panner->isNotEmpty()) {
                $datas[] = $mib_panner;
            }
        }

        return response()->json(['datas' => $datas], 200);
    }

    public function client_mib_index_year()
    {
        $user = auth()->user();

        try {
            DB::beginTransaction();
            $boutiques = Boutique::where('user_slug', $user->slug)
                ->where('corbeil', false)
                ->with('panier_mib_year')
                ->get();
            DB::commit();
            return response()->json(['datas' => $boutiques], 200);
        } catch (\Throwable $th) {
            DB::rollBack();
            return response()->json(['message' => 'Erreur inattendue: ' . $th->getMessage()], 401);
            throw $th;
        }
    }

    public function mib_category_by_boutique($boutique_id, $an)
    {
        try {
            DB::beginTransaction();
            $datas = CategoriesMib::where('boutique_id', $boutique_id)->where('an', $an)->with('lots')->get();
            DB::commit();
            return response()->json(['datas' => $datas], 200);
        } catch (\Throwable $th) {
            DB::rollBack();
            return response()->json(['message' => 'Erreur inatendu'], 401);
            throw $th;
        }
    }

    public function mib_lot_by_category($categorie_mib)
    {
        try {
            DB::beginTransaction();
            $datas = LotMib::where('categories_mib_id', $categorie_mib)->get();
            // dd($categorie_mib, $datas);
            DB::commit();
            return response()->json(['datas' => $datas], 200);
        } catch (\Throwable $th) {
            DB::rollBack();
            return response()->json(['message' => 'Erreur inatendu'], 401);
            throw $th;
        }
    }

    public function mib_client($boutique_id, $an)
    {
        $user = auth()->user();
        try {
            DB::beginTransaction();
            $datas = ClientMib::where('user_id', $user->id)
            ->where('boutique_id', $boutique_id)
            ->where('an', $an)
            ->get();
            DB::commit();
            return response()->json(['datas' => $datas], 200);
        } catch (\Throwable $th) {
            DB::rollBack();
            return response()->json(['message' => 'Erreur inatendu'], 401);
            throw $th;
        }
    }

    public function mib_store_client(Request $request)
    {
        $datas =  $request->validate([
            'nom' => 'required|string',
            'prenom' => 'required|string',
            'tel' => 'nullable|string',
            'adresse' => 'nullable|string',
            'nom_mandataire' => 'nullable|string',
            'tel_mandataire' => 'nullable|string',
            'adresse_mandataire' => 'nullable|string',
            'parainer' => 'nullable|string',
            'parain_id' => 'nullable|integer|exists:parains,id',
            'boutique_id' => 'required|integer|exists:boutiques,id',
            'categories_mib_id' => 'required|integer|exists:categories_mibs,id',
            'lot' => 'required|string|exists:lot_mibs,slug',
        ]);
        
        $user = auth()->user();
        $datas['slug'] = Str::slug('clientMib' . time());
        $datas['bonus'] = true;
        $datas['an'] = date('Y');
        $datas['user_id'] = $user->id;
        $pricing = CategoriesMib::where('id', $datas['categories_mib_id'])->first();
        try {
            DB::beginTransaction();
            $client = ClientMib::create($datas);
            CotisationMib::StaticCreate($client->id, $pricing->price);
            DB::commit();
            return response()->json(['message' => 'Client enregistre avec succès', 'datas' => $client], 200);
        } catch (\Throwable $th) {
            DB::rollBack();
            return response()->json(['message' => 'Erreur inatendu'], 401);
            throw $th;
        }
    }

    public function mib_show_client($client_id)
    {
        try {
            DB::beginTransaction();
            $client = ClientMib::where('id', $client_id)->with('cotisations','categorieMib','parrain','user','lotMib','boutique')->first();
            if ($client) {
                $cotisations = $client->cotisations;

                $nombreImpayer = $cotisations->first()->nombreImpayer($client_id, $client->boutique->id);
                $nombrePayer = $cotisations->first()->nombrePayer($client_id);
                $sumPayer = $cotisations->first()->sumPayer($client_id);
                $nombreRestePayer = $cotisations->first()->nombreRestePayer($client_id);

                $datas = [
                    'client' => $client,
                    'nombreImpayer' => $nombreImpayer,
                    'nombrePayer' => $nombrePayer,
                    'sumPayer' => $sumPayer,
                    'nombreRestePayer' => $nombreRestePayer
                ];
            } else {
                $datas = null;
            }

            DB::commit();
            return response()->json(['datas' => $datas], 200);
        } catch (\Throwable $th) {
            DB::rollBack();
            return response()->json(['message' => 'Erreur inatendu'], 401);
            throw $th;
        }
    }

    public function mib_update_client(Request $request, $clientID)
    {
        // dd($request->all());
        $client = ClientMib::find($clientID);
        $datas = $request->all();
        try {
            DB::beginTransaction();
            $client->update($datas);
            DB::commit();
            return response()->json(['message' => 'Donné modifier avec succes', 'datas' => $client], 200);
        } catch (\Throwable $th) {
            DB::rollBack();
            return response()->json(['message' => 'Erreur inatendu'], 401);
            throw $th;
        }
    }
}
