<?php

namespace App\Http\Controllers;

use App\AbonnementPaiment;
use App\Boutique;
use App\BoutiqueAbonnement;
use App\BoutiqueMeta;
use App\CatalogueArticles;
use App\CategorieCaracteristique;
use App\CategoriesMib;
use App\ClientMib;
use App\CodePromo;
use App\CommandArticle;
use App\Commandes;
use App\CotisationMib;
use App\EtatAbonnement;
use App\helpers\helper;
use App\Http\Traits\ProjectTrait;
use App\Images;
use App\InvestmentProject;
use App\mibBoutiqueSouscription;
use App\mibBoutiqueSouscriptionLogs;
use App\mibPricing;
use App\NewslettersAbonnementUser;
use App\NewslettersOptionAbonnement;
use App\PaiementEchelonner;
use App\Portefeuille;
use App\ServiceShipping;
use App\SgiPortefeuille;
use App\User;
use Illuminate\Http\Request;
use Illuminate\Support\Carbon;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Config;
use Illuminate\Support\Facades\DB;

use Illuminate\Support\Facades\Input;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\URL;
use Illuminate\Support\Str;
use PayPal\Api\Amount;
use PayPal\Api\Item;
use PayPal\Api\ItemList;
use PayPal\Api\Payer;
use PayPal\Api\Payment;
use PayPal\Api\PaymentExecution;
use PayPal\Api\RedirectUrls;
use PayPal\Api\Transaction;
use PayPal\Auth\OAuthTokenCredential;
use PayPal\Rest\ApiContext;
use WebLAgence\LaravelFacebookPixel\LaravelFacebookPixelFacade;

class paymentController extends Controller
{
    use ProjectTrait;

    protected  $helpers;

    public function __construct(helper $helper)
    {
        $this->helpers = $helper;
        /** PayPal api context **/
        $paypal_conf = Config::get('paypal');
        $this->_api_context = new ApiContext(
            new OAuthTokenCredential(
                $paypal_conf['client_id'],
                $paypal_conf['secret']
            )
        );
        $this->_api_context->setConfig($paypal_conf['settings']);
    }

    public function internationalizekkiapay(Request $request)
    {
        $data = $request->all();
        $data['transaction_id'] = $data['response']['transactionId'];
        $public_key = env('KKIAPAY_PUBLIC');
        $secret = env('KKIAPAY_SECRET');
        $private_key = env('KKIAPAY_PRIVATE');
        $kkiapay = new \Kkiapay\Kkiapay(
            $public_key,
            $private_key,
            $secret,
            env('KKIAPAY_SANDBOX') == '1'
        );
        $transaction_id = $data['transaction_id'];
        $verify = $kkiapay->verifyTransaction($transaction_id);
        // dd($boutique_abonnement);
        $status = $verify->status;
        if ($status == 'SUCCESS') {
            $boutique_slug = $data['boutique_slug'];
            $boutique = Boutique::where('slug', $boutique_slug)->first();
            $metas = BoutiqueMeta::where('boutique_id', $boutique['id'])->first();
            $metas = BoutiqueMeta::findOrFail($metas['id']);
            $metas->pay_internationalize = true;
            $metas->save();
            return ['response' => 'success', 'message' => 'Votre boutique est maintenant visible à l\'international.'];
        }
        return ['response' => 'error', 'message' => 'Une erreur s\'est produite. Veuilez contacter le service client si le paiement à été valider.'];
    }
    public function internationalizeIntram(Request $request)
    {
        $data = $request->all();
        $data['transaction_id'] = $data['response']['transactionId'];
        $public_key = env('INTRAM_PUBLIC');
        $secret = env('INTRAM_SECRET');
        $private_key = env('INTRAM_PRIVATE');
        $intram = new \Intram\Intram($public_key, $private_key, $secret, env('INTRAM_SANDBOX') == '1');
        $transaction_id = $data['transaction_id'];
        $verify = $intram->getTransactionStatus($transaction_id);
        $status = $verify->status;
        if ($status == 'SUCCESS') {
            $boutique_slug = $data['boutique_slug'];
            $boutique = Boutique::where('slug', $boutique_slug)->first();
            $metas = BoutiqueMeta::where('boutique_id', $boutique['id'])->first();
            $metas = BoutiqueMeta::findOrFail($metas['id']);
            $metas->pay_internationalize = true;
            $metas->save();
            return ['response' => 'success', 'message' => 'Votre boutique est maintenant visible à l\'international.'];
        }
        return ['response' => 'error', 'message' => 'Une erreur s\'est produite. Veuilez contacter le service client si le paiement à été valider.'];
    }

    public function paymentIntram(Request $request)
    {
        $data = $request->all();
        $data['transaction_id'] = $data['response']['transactionId'];
        $public_key = env('INTRAM_PUBLIC');
        $secret = env('INTRAM_SECRET');
        $private_key = env('INTRAM_PRIVATE');
        $intram = new \Intram\Intram($public_key, $private_key, $secret, env('INTRAM_SANDBOX') == '1');
        $transaction_id = $data['transaction_id'];
        $verify = $intram->getTransactionStatus($transaction_id);
        $status = $verify->status;
        if ($status == 'SUCCESS') {
            switch ($request->transaction_type) {
                case "distribution_gain":
                    $project = InvestmentProject::with($this->projectRelation())
                        ->whereSlug($request->project)
                        ->first();
                    if ($verify->amount == $project->total_distribution_gain) {
                        $project->pay_gain_status = true;
                        $project->pay_gain_at = now();
                        $project->save();
                        foreach ($project->contributions as $contribution) {
                            $contribution->statut = "gain_envoyer";
                            $contribution->get_at = now();
                            $contribution->save();
                            $user = User::find($contribution->sgi_user_id);
                            $portefeuille = Portefeuille::where("user_slug", $user->slug)->first();
                            if ($portefeuille) {
                                $amount = $portefeuille->montant + (intval($contribution->montant) + intval(($contribution->montant * ($project->pourcentage_gain / 100))));
                                $portefeuille->montant = $amount;
                                $portefeuille->save();
                            }
                        }
                        return ['response' => 'success', 'message' => 'La distribution des gains a été effectué'];
                    } else {
                        return ['response' => 'error', 'message' => "Le montant total payé n'est pas correcte. Vous devez payer " . $project->total_distribution_gain . " XOF au lieu de " . $verify->amount . " XOF"];
                    }

                    break;
            }
        }
        return ['response' => 'error', 'message' => 'Une erreur s\'est produite. Veuilez contacter le service client si le paiement à été valider.'];
    }


    public function paymentKkiapay(Request $request)
    {
        $data = $request->all();
        $data['transaction_id'] = $data['response']['transactionId'];
        $public_key = env('KKIAPAY_PUBLIC');
        $secret = env('KKIAPAY_SECRET');
        $private_key = env('KKIAPAY_PRIVATE');
        $kkiapay = new \Kkiapay\Kkiapay(
            $public_key,
            $private_key,
            $secret,
            env('KKIAPAY_SANDBOX') == '1'
        );
        $transaction_id = $data['transaction_id'];
        $verify = $kkiapay->verifyTransaction($transaction_id);
        $status = $verify->status;
        if ($status == 'SUCCESS') {
            switch ($request->transaction_type) {
                case "distribution_gain":
                    $project = InvestmentProject::with($this->projectRelation())
                        ->whereSlug($request->project)
                        ->first();
                    if ($verify->amount == $project->total_distribution_gain) {
                        $project->pay_gain_status = true;
                        $project->pay_gain_at = now();
                        $project->save();
                        foreach ($project->contributions as $contribution) {
                            $contribution->statut = "gain_envoyer";
                            $contribution->get_at = now();
                            $contribution->save();
                            $user = User::find($contribution->sgi_user_id);
                            $portefeuille = Portefeuille::where("user_slug", $user->slug)->first();
                            if ($portefeuille) {
                                $amount = $portefeuille->montant + (intval($contribution->montant) + intval(($contribution->montant * ($project->pourcentage_gain / 100))));
                                $portefeuille->montant = $amount;
                                $portefeuille->save();
                            }
                        }
                        return ['response' => 'success', 'message' => 'La distribution des gains a été effectué'];
                    } else {
                        return ['response' => 'error', 'message' => "Le montant total payé n'est pas correcte. Vous devez payer " . $project->total_distribution_gain . " XOF au lieu de " . $verify->amount . " XOF"];
                    }

                    break;
            }
        }
        return ['response' => 'error', 'message' => 'Une erreur s\'est produite. Veuilez contacter le service client si le paiement à été valider.'];
    }


    public function productorPaybyPaydunya(Request $request)
    {
        $data = $request->all();
        $itemArray = [['name' => 'Abonnement', 'quantity' => 1, 'unitaire' => $data['amount'], 'total' => $data['amount']]];
        $amount = $data['amount'];
        $description = "Souscription à un abonnement pour catalogue";
        $redirect_url = route('paydunyaredirectCatalogue');
        $val = $this->helpers->paydunyaPaiement($itemArray, $amount, $description, $redirect_url);
        if ($val !== null) {
            return ['error' => false, 'redirect_url' => $val];
        }
        return ['error' => true, 'message' => 'Une erreure s\'est produite.'];
    }

    public function paybyPaydunya(Request $request)
    {
        $data = $request->all();
        if (isset($data['data']))
            Session::put('data', $data['data']);
        $itemArray = [];
        try {
            switch ($data['transaction_type']) {
                case 'activation_boutique':
                    $itemArray = [['name' => 'Abonnement', 'quantity' => 1, 'unitaire' => $data['amount'], 'total' => $data['amount']]];
                    $amount = $data['amount'];
                    $description = "Souscription à un abonnement boutique";
                    $redirect_url = route('paydunyaredirectSubscription');
                    // $data= array_merge($data,json_decode(Session::get('data'),true));
                    if (isset($data['boutique_slug'])) {
                        $boutique_abonnement = $data['boutique_slug'];
                        $shop = Boutique::with('meta')->where('slug', $boutique_abonnement)->first();
                        if ($shop != null && $shop->meta->internationalize && $shop->meta->pay_internationalize) {
                            $amount = $data['amount'] + env('INTERNATIONAL_PAY_XOF');
                        }
                    }
                    break;
                case 'activation_catalogue':
                    $itemArray = [['name' => 'Abonnement', 'quantity' => 1, 'unitaire' => $data['price'], 'total' => $data['price']]];
                    $amount = $data['price'];
                    $description = "Souscription à un abonnement pour catalogue";
                    $redirect_url = route('paydunyaredirectCatalogue');
                    break;
                case 'commandes':
                    $cmd = Commandes::findOrFail(Session::get('command_id_new'));
                    $cmdt = CommandArticle::where('command_slug', $cmd->slug)->get();
                    foreach ($cmdt as $commandearticle) {
                        $article = CatalogueArticles::where('slug', $commandearticle->article_slug)->first();
                        array_push($itemArray, ['name' => $article->name, 'quantity' => $commandearticle->quantity, 'unitaire' => $commandearticle->price, 'total' => $commandearticle->total_price]);
                    }
                    $amount = $cmd->total_price;
                    $description = "";
                    $redirect_url = url('pay/by/paydunya/redirect');
                    break;
                case 'activation_internationalize':
                    $itemArray = [['name' => 'Activation service', 'quantity' => 1, 'unitaire' => $data['amount'], 'total' => $data['amount']]];
                    $amount = $data['amount'];
                    $description = "Activation du service de  visibilité international";
                    $redirect_url = route('paydunyaredirectAfterinternational');
                    break;
                case 'abonnement_newsletter';
                    $datas = json_decode($data['data'], true);
                    $abonnement = NewslettersOptionAbonnement::where('slug', $datas['data']['slug'])->first();
                    $user = Session::get('user')['slug'];
                    $abonnement_user = NewslettersAbonnementUser::where('user_slug', $user)->first();
                    if (isset($abonnement_user) && $abonnement_user != null) {
                        $action = 'Cumule abonnement newsletters';
                    } else {
                        $action = "Abonnement à la newsletters";
                    }
                    $price = $abonnement['prix'];
                    $itemArray = [['name' => $action, 'quantity' => 1, 'unitaire' => $price, 'total' => $price]];
                    $amount = $price;
                    $description = $action;
                    $redirect_url = route('abonnementNewsletterPaydunyaRedirect');
                    break;
                case 'paiement_echelonner':
                    $itemArray = [['name' => 'Paiement Echelonner', 'quantity' => 1, 'unitaire' => $data['amount'], 'total' => $data['amount']]];
                    $amount = $data['amount'];
                    $description = "Activation de la fonctionnalité de paiement echelonner";
                    $redirect_url = route('paydunyaredirectAfterPaiementEchelonner');
                    break;
                case 'souscription_mib':
                    $itemArray = [['name' => 'Souscription Panier Min', 'quantity' => 1, 'unitaire' => $data['amount'], 'total' => $data['amount']]];
                    $amount = $data['amount'];
                    $description = "Souscription au Panier Mib " . date('Y');
                    $redirect_url = route('pay.MibSouscription.Paydunya');
                    break;
                case 'panier_mib':
                    $itemArray = [['name' => 'Paiement module Panier Mib', 'quantity' => 1, 'unitaire' => $data['amount'], 'total' => $data['amount']]];
                    $amount = $data['amount'];
                    $description = "Activation de la fonctionnalité Panier Mib pour une année";
                    $redirect_url = route('paydunyaredirectAfterPanierMibAdminSouscription');
                    break;
                case 'cotisations':
                    $itemArray = [['name' => 'Paiement cotisation Panier Mib', 'quantity' => 1, 'unitaire' => $data['amount'], 'total' => $data['amount']]];
                    $amount = $data['amount'];
                    $description = "Paiement des tranches de cotisation Mib";
                    $redirect_url = route('paydunyaredirectAfterClientMibPaidCotisation');
                    break;
                default:
                    $itemArray = [];
                    $amount = 0;
                    $description = "Erreur";
                    $redirect_url = url('');
                    break;
            }

            $val = $this->helpers->paydunyaPaiement($itemArray, $amount, $description, $redirect_url);
            if ($val !== null) {
                return ['error' => false, 'redirect_url' => $val];
            }
            return ['error' => true, 'message' => 'Une erreure s\'est produite.'];
        } catch (\Exception $e) {
            return json_encode(['error' => true, 'message' => 'Une erreure s\'est produite. ' . $e]);
        }
    }

    public function paydunyaredirectAfterinternational(Request $request)
    {
        //dd($request->all());
        $data = $request->all();
        $data = array_merge($data, json_decode(Session::get('data'), true));
        $invoice = new \Paydunya\Checkout\CheckoutInvoice();
        if ($invoice->confirm($data['token'])) {
            if ($invoice->getStatus() == "completed") {
                $boutique_slug = $data['boutique_slug'];
                $boutique = Boutique::where('slug', $boutique_slug)->first();
                $metas = BoutiqueMeta::where('boutique_id', $boutique['id'])->first();
                $metas = BoutiqueMeta::findOrFail($metas['id']);
                $metas->pay_internationalize = true;
                $metas->save();
                return \redirect('boutique')->with('success', 'Votre boutique ' . $boutique['nom_boutique'] . ' est maintenant visible à l\'inernational.');
            }
        }
    }

    public function paydunyaredirectAfterPaiementEchelonner(Request $request)
    {
        //dd($request->all());
        $data = $request->all();
        $data = array_merge($data, json_decode(Session::get('data'), true));
        $invoice = new \Paydunya\Checkout\CheckoutInvoice();
        if ($invoice->confirm($data['token'])) {
            if ($invoice->getStatus() == "completed") {
                $boutique_slug = $data['boutique_slug'];
                $data['boutique_slug'] = $boutique_slug;
                $paiement_echelonner = PaiementEchelonner::where('boutique_slug', $boutique_slug)->first();
                if (isset($paiement_echelonner)) {
                    if (new \DateTime($paiement_echelonner['expired_at']) > new \DateTime(date("Y-m-d H:i:s"))) {
                        $oneYearOn = date('Y-m-d', strtotime(date($paiement_echelonner['expired_at'], time()) . " + 365 day"));
                    } else {
                        $oneYearOn = date('Y-m-d', strtotime(date("Y-m-d H:i:s", time()) . " + 365 day"));
                    }
                    DB::table('paiement_echelonners')->where('boutique_slug', $boutique_slug)->update([
                        'expired_at' => $oneYearOn,
                        'max' => $data['max']
                    ]);
                } else {
                    $oneYearOn = date('Y-m-d', strtotime(date("Y-m-d H:i:s", time()) . " + 365 day"));
                    $data['expired_at'] = $oneYearOn;
                    PaiementEchelonner::create($data);
                }
                $boutique = Boutique::where('slug', $boutique_slug)->first();
                $metas = BoutiqueMeta::where('boutique_id', $boutique['id'])->first();
                $metas = BoutiqueMeta::findOrFail($metas['id']);
                $metas->paiement_echelonner = $data['max'];
                $metas->save();
                return \redirect('boutique')->with('success', 'Vos clients pourront effectuer des paiements échelonnés à partir se maintenant sur la boutique ' . $boutique['nom_boutique'] . ' ');
            }
        }
    }

    public function paydunyaredirectAfterPanierMibAdminSouscription(Request $request)
    {
        //dd($request->all());
        $data = $request->all();
        $data = array_merge($data, json_decode(Session::get('data'), true));
        $invoice = new \Paydunya\Checkout\CheckoutInvoice();
        if ($invoice->confirm($data['token'])) {
            if ($invoice->getStatus() == "completed") {
                $boutique_slug = $data['boutique_slug'];
                $data['boutique_slug'] = $boutique_slug;
                $boutique_slug = $data['boutique_slug'];
                $pricing = mibPricing::where('name', 'like', '%' . $data['name'] . '%')->first();
                $portefeuille = DB::table('admin_portefeuilles')->where('devise', 'XOF')->first();
                $arg = 0;
                if (isset($portefeuille)) {
                    $arg = $portefeuille->montant + $pricing->price;
                }
                DB::table('admin_portefeuilles')->where('devise', 'XOF')->update(['montant' => $arg]);
                $boutique = Boutique::where('slug', $boutique_slug)->first();
                $req['id_boutique'] = $boutique['id'];
                $req['max_user'] = $pricing['max_user'];
                $oneYearOn = date('Y-m-d H:i:s', strtotime(date("Y-m-d H:i:s", time()) . " + 365 day"));
                $req['expired_at'] = $oneYearOn;
                $checkMibSouscription = mibBoutiqueSouscription::where('id_boutique', $boutique['id'])->first();
                if (isset($checkMibSouscription)) {
                    $souscription = DB::table('mib_boutique_souscriptions')->where('id', $checkMibSouscription['id'])->update(['max_user' => $req['max_user']]);
                    $souscription_id = $checkMibSouscription['id'];
                } else {
                    $souscription = mibBoutiqueSouscription::create($req);
                    $souscription_id = $souscription->id;
                }
                if (isset($souscription)) {
                    mibBoutiqueSouscriptionLogs::create(
                        [
                            'id_boutique' => $boutique['id'],
                            'id_mib_pricing' => $souscription_id
                        ]
                    );
                }
                $subject = 'ACHAT MODULE PANIER MIB';
                $messages = 'La boutique ' . $boutique['nom_boutique'] . ' à éffectuer un achat du module panier mib.';
                MailController::SendGeneralUniqueMail('Mail.generale_blade', $subject, $messages, env('MAIL_ADMIN'), env('MAIL_USERNAME'));
                return \redirect('boutique')->with('success', 'Panier Mib activer avec succès sur la boutique  ' . $boutique['nom_boutique'] . '. Accédez au menu pour gerer le module Panier Mib.');
            }
        }
    }

    public function paydunyaredirectAfterClientSouscription(Request $request)
    {
        $year = Session::get('mib_year');
        //dd($request->all());
        $data = $request->all();
        $data = array_merge($data, json_decode(Session::get('data'), true));
        $clientData = $data['data'];
        $invoice = new \Paydunya\Checkout\CheckoutInvoice();
        if ($invoice->confirm($data['token'])) {
            if ($invoice->getStatus() == "completed") {
                $boutique_slug = $data['boutique_slug'];
                $pricing = CategoriesMib::where('slug', $clientData['categorie_mib_slug'])->first();
                $boutique = Boutique::where('slug', $boutique_slug)->first();
                $params = new \App\ParametrageMib();
                $souscription_price = $params->getParametersByKeys('souscription', $boutique->id, $year);
                $parainnage = $params->getParametersByKeys('parainnage', $boutique->id, $year);
                $parrain = Session::get('prn-mib');
                $parainner = false;
                $user = null;
                $solde = $souscription_price;
                if (isset($parrain) && isset($parainnage) && $parainnage != null) {
                    $parainner = true;
                    $user_data = User::where('slug', $parrain)->first();
                    $user = $user_data['id'];
                    $pourcentage = $parainnage;
                    $arg = (($souscription_price * $pourcentage) / 100);
                    Portefeuille::createPortefeuilles(
                        $user_data['slug'],
                        $arg,
                        'PARRAINNAGE POUR SOUSCRIPTION PANIER MIB',
                        'Paiement de parraiange à la souscription panier mib à la boutique ' . $boutique['nom_boutique'],
                        'XOF',
                        ''
                    );
                    $solde = ($souscription_price - (($souscription_price * $pourcentage) / 100));
                }
                //add solde to boutique
                Portefeuille::createPortefeuilles(
                    $boutique['user_slug'],
                    $solde,
                    'SOUSCRIPTION PANIER MIB',
                    'Paiement de la souscription panier mib à la boutique ' . $boutique['nom_boutique'],
                    'XOF',
                    $boutique_slug
                );
                $client = [
                    'slug' => Str::slug('clientMib' . time()),
                    'nom' => $clientData['nom'],
                    'prenom' => $clientData['prenom'],
                    'tel' => $clientData['tel'],
                    'adresse' => $clientData['adresse'],
                    'bonus' => true,
                    'parainer' => $parainner,
                    'parain_id' => $user,
                    'an' => date('Y'),
                    'boutique_id' => $boutique['id'],
                    'categories_mib_id' => $pricing['id'],
                    'lot' => $clientData['lot_mib_slug'],
                    'brunch' => isset($clientData['brunch']),
                    'user_id' => Auth::id()
                ];
                if (isset($clientData['nom_mandataire'])) $client['nom_mandataire'] = $clientData['nom_mandataire'];
                if (isset($clientData['tel_mandataire'])) $client['tel_mandataire'] = $clientData['tel_mandataire'];
                if (isset($clientData['adresse_mandataire'])) $client['adresse_mandataire'] = $clientData['adresse_mandataire'];
                $client = ClientMib::create($client);
                //create cotisation
                CotisationMib::StaticCreate($client->id, $pricing->price);
                return \redirect($boutique['nom_boutique'] . '/mib/index/')->with('success', 'Souscription au panier Mib validée avec succès sur la boutique  ' . $boutique['nom_boutique']);
            }
        }
    }

    public function paydunyaredirectAfterClientMibPaidCotisation(Request $request)
    {
        //dd($request->all());
        $data = $request->all();
        $data = array_merge($data, json_decode(Session::get('data'), true));
        $clientData = $data['data'];
        $invoice = new \Paydunya\Checkout\CheckoutInvoice();
        if ($invoice->confirm($data['token'])) {
            if ($invoice->getStatus() == "completed") {
                $cotisations = $data['cotisations'];
                $boutique_slug = $data['boutique_slug'];
                $cotisations = explode(',', $cotisations);
                $cotisations = CotisationMib::whereIn('slug', $cotisations)->get();
                $boutique = Boutique::where('slug', $boutique_slug)->first();
                $solde = 0;
                $client = 0;
                foreach ($cotisations as $cotisation) {
                    DB::table('cotisation_mibs')->where('id', $cotisation->id)
                        ->update(['status' => true, 'reference_paiement' => $data['token'], 'paid_at' => Carbon::now(), 'validate_by' => Auth::user()->slug]);
                    $solde = +$cotisation->montant;
                    $client = $cotisation->client_mib_id;
                    if (!$cotisation->status) {
                        DB::table('cotisation_mibs')->where('id', $cotisation->id)
                            ->update(['status' => true, 'reference_paiement' => $data['token'], 'paid_at' => Carbon::now(), 'validate_by' => Auth::user()->slug]);
                        $solde = $solde + $cotisation->montant;
                        $client = $cotisation->client_mib_id;
                    }
                }
                //add solde to boutique
                Portefeuille::createPortefeuilles(
                    $boutique['user_slug'],
                    $solde,
                    'PAIEMENT COTISATION PANIER MIB',
                    'Paiement de la cotisation panier mib à la boutique ' . $boutique['nom_boutique'],
                    'XOF',
                    $boutique_slug
                );
                //update client Mib virtual Portefeuille
                ClientMib::createPortefeuille($client, $solde);
                //check if user paid all cotisation
                $cotisations = CotisationMib::where('client_mib_id', $client)->where('status', false)->count();
                if ($cotisations <= 0) {

                    DB::table('client_mibs')->where('id', $client)->update(['end_cotisation' => true]);
                }
                return \redirect($boutique['nom_boutique'] . '/mib/index/')->with('success', 'Souscription au panier Mib validée avec succès sur la boutique  ' . $boutique['nom_boutique']);
            }
        }
    }

    public function abonnementNewsletterPaydunyaRedirect(Request $request)
    {
        $data = $request->all();
        $data = array_merge($data, json_decode(Session::get('data'), true));
        $invoice = new \Paydunya\Checkout\CheckoutInvoice();
        if ($invoice->confirm($data['token'])) {
            if ($invoice->getStatus() == "completed") {
                $abonnement = NewslettersOptionAbonnement::where('slug', $data['data']['slug'])->first();
                $user = Session::get('user')['slug'];
                $abonnement_user = NewslettersAbonnementUser::where('user_slug', $user)->first();
                if (isset($abonnement_user) && $abonnement_user != null) {
                    $newsletter = NewslettersAbonnementUser::findOrFail($abonnement_user['id']);
                    $newsletter->status = true;
                    $newsletter->abonnement_slug = $abonnement['slug'];
                    $newsletter->montant = $newsletter->montant + $abonnement['prix'];
                    $newsletter->diffusion = $newsletter->diffusion + $abonnement['diffusion'];
                    $newsletter->boutique = $newsletter->boutique + $abonnement['boutique'];
                    $newsletter->cumule += 1;
                    $newsletter->save();
                    $motif = 'Cumule de votre abonnement ' . $abonnement->intitule . ' à  la newsletters.';
                    $action = 'Cumule Newsletters';
                    Session::flash('success', 'Cumule abonnement ' . $abonnement->intitule . ' effectué avec succès. Vous pouvez dès à present profiter de nos forfait sur cet abonnement.');
                } else {
                    $data['diffusion'] = $abonnement['diffusion'];
                    $data['boutique'] = $abonnement['boutique'];
                    $data['user_slug'] = Session::get('user')['slug'];
                    $data['slug'] = \Illuminate\Support\Str::slug(time() . 'user_abonnement' . time());
                    $data['corbeil'] = false;
                    $data['status'] = true;
                    $data['abonnement_slug'] = $data['data']['slug'];
                    $data['montant'] = $abonnement['prix'];
                    $newsletter = NewslettersAbonnementUser::create($data);
                    $motif = 'Paiement effectué pour abonnement ' . $abonnement['intitule'] . ' à  la newsletters.';
                    $action = 'Abonnement Newsletters';
                    Session::flash('success', 'Abonnement ' . $abonnement->intitule . ' effectué avec succès. vous pouvez dès à present profiter de nos forfait sur cet abonnement.');
                }
                $montant = $abonnement['prix'];
                AbonnementPaiment::createpaiement($user, $montant, $action, $motif, 'XOF');
                Session::forget('data');
                return redirect('user/abonnement/')->with('success', 'Abonnement activé avec succès');
            }
        }
    }

    public function paydunyaredirectSubscription(Request $request)
    {
        $data = $request->all();
        $data = array_merge($data, json_decode(Session::get('data'), true));
        $help = new Boutique();
        $help->storeAbonnement($data['token'], $data['slug'], $data['boutique_slug'], 'PAYDUNYA');
        $invoice = new \Paydunya\Checkout\CheckoutInvoice();
        if ($invoice->confirm($data['token'])) {
            if ($invoice->getStatus() == "completed") {
                if (isset($data['slug'])) {
                    $abonnement_slug = $data['slug'];
                    $boutique_abonnement = $data['boutique_slug'];
                    $abonnement = EtatAbonnement::where('slug', $abonnement_slug)->first();
                    $boutique = Boutique::where('slug', $boutique_abonnement)->first();
                    LaravelFacebookPixelFacade::createEvent('Subscribe', $parameters = ['predicted_ltv' => $abonnement['price'], 'currency' => 'XOF', 'value' => $abonnement['price']]);
                    if ((int)$invoice->getTotalAmount() == (int)$abonnement['price']) {
                        //send money to sunmarketers
                        $bonus = 0;
                        if ($boutique['sunmarketer'] != 'none' && $boutique['sunmarketer'] != null && $boutique['sunmarketer'] != 'almost') {
                            //                                $marketer=$boutique['sunmarketer'];
                            $marketer = DB::table('marketers')->where('user_slug', $boutique['sunmarketer'])->first();
                            $usermarketer = $boutique['sunmarketer'];
                            if (isset($marketer) && $marketer != null) {
                                $portefeuille = DB::table('portefeuilles')->where('user_slug', $marketer->user_slug)->where('devise', ($marketer->currency != null ? $marketer->currency : 'USD'))->first();
                                $ab = (float)$abonnement['price'];
                                $reduc = 10;
                                if ($boutique['sunmarketer_first_time'] == 0) {
                                    $reduc = 20;
                                    DB::table('boutiques')->where('slug', $boutique_abonnement)->update(['sunmarketer_first_time' => 1]);
                                }
                                $bonus = ($ab * $reduc) / 100;
                                if ($marketer->currency != 'XOF' || $marketer->currency) {
                                    $helpers = new HelperController();
                                    $bonus = $helpers->convertCurrency('XOF', 'USD', $bonus);
                                }
                                if (isset($portefeuille) && $portefeuille != null) {
                                    $montant = (float)$portefeuille->montant + $bonus;

                                    DB::table('portefeuilles')
                                        ->where('user_slug', $marketer->user_slug)
                                        ->where('devise', 'XOF')
                                        ->update(['montant' => $montant]);
                                } else {
                                    Portefeuille::create([
                                        'user_slug' => $marketer->user_slug,
                                        'devise' => ($marketer->currency != null ? $marketer->currency : 'USD'),
                                        'montant' => $bonus,
                                        'active' => true,
                                        'tentative' => 0,
                                        'created_at' => Carbon::now(),
                                        'updated_at' => Carbon::now(),
                                    ]);
                                }
                                $messages = "La boutique " . $boutique['nom_boutique'] . " à mis à jour son abonnement pour " . $abonnement['numberMonth'] . ' mois, pour un montant de ' . (float)$abonnement['price'] . '. Vous bénéficiez de 10% de la somme totale du montant soit ' . $bonus;
                                if ($boutique['sunmarketer_first_time'] == 0) {
                                    $messages = "La boutique " . $boutique['nom_boutique'] . " à mis à jour son abonnement pour " . $abonnement['numberMonth'] . ' mois, pour un montant de ' . (float)$abonnement['price'] . '. Vous bénéficiez de 20% de la somme totale du montant soit ' . $bonus;
                                }
                            } else {
                                $code = CodePromo::where('code', $boutique['sunmarketer'])->first();
                                if (isset($code) && $code != null) {
                                    $userData = DB::table('users')->where('id', $code['user_id'])->first();
                                    $usermarketer = $userData->slug;
                                    $portefeuille = DB::table('portefeuilles')->where('user_slug', $userData->slug)->where('devise',  'XOF')->first();
                                    $ab = (float)$abonnement['price'];
                                    $bonus = ($ab * 25) / 100;
                                    //
                                    if (isset($portefeuille) && $portefeuille != null) {
                                        $montant = (float)$portefeuille->montant + $bonus;

                                        DB::table('portefeuilles')
                                            ->where('user_slug', $userData->slug)
                                            ->where('devise', 'XOF')
                                            ->update(['montant' => $montant]);
                                    } else {
                                        Portefeuille::create([
                                            'user_slug' => $userData->user_slug,
                                            'devise' => 'XOF',
                                            'montant' => $bonus,
                                            'active' => true,
                                            'tentative' => 0,
                                            'created_at' => Carbon::now(),
                                            'updated_at' => Carbon::now(),
                                        ]);
                                    }
                                }
                                $messages = "La boutique " . $boutique['nom_boutique'] . " à mis à jour son abonnement pour " . $abonnement['numberMonth'] . ' mois, pour un montant de ' . (float)$abonnement['price'] . '. Vous bénéficiez de 25% de la somme totale du montant soit ' . $bonus;
                            }
                            //                                $sh= Boutique::findOrFail($boutique['id']);
                            //                                $sh->sunmarketer='almost';
                            //                                $sh->save();
                            $subject = 'Compte créditer';
                            MailController::SendGeneralUniqueMail('Mail.generale_blade', $subject, $messages, env('MAIL_ADMIN'), env('MAIL_USERNAME'));
                        }
                        //End sunmarketers bonus transaction

                        $data['slug'] = Str::slug(time() . 'boutique' . time() . 'abonnement');
                        $data['boutique_id'] = $boutique['id'];
                        $data['etat_abonnement_id'] = $abonnement['id'];
                        $data['expired'] = false;
                        DB::table('boutique_abonnements')->where('boutique_id', $boutique['id'])->where('etat_abonnement_id', $abonnement['id'])->update(['expired' => false]);
                        $boutique['expired']
                            ? $expireBoutique = Carbon::now()->format('M d Y H:i:s')
                            : $expireBoutique = Carbon::create($boutique['expired_to'])->format('M d Y H:i:s');
                        $expired_to = strtotime("+" . $abonnement['numberMonth'] . " months", strtotime($expireBoutique));
                        $myShop = Boutique::findOrFail($boutique['id']);
                        $myShop->expired_to = Carbon::createFromFormat('Y-m-d H:i:s', date('Y-m-d H:i:s', $expired_to));
                        $myShop->expired = false;
                        $myShop->save();
                        $data['expired_at'] = $myShop->expired_to;
                        BoutiqueAbonnement::create($data);
                        $user = Session::get('user')['slug'];
                        $boutique['expired']
                            ? $motif = 'Paiement effectué pour abonnement ' . $abonnement['name'] . ' de la boutique ' . $boutique['nom_boutique']
                            : $motif = 'Paiement effectué pour cumule d\'abonnement ' . $abonnement['name'] . ' de la boutique ' . $boutique['nom_boutique'];
                        $montant = $abonnement['price'];
                        $boutique['expired']
                            ? $action = 'Abonnement Boutique'
                            : $action = 'Cumule d\'abonnement Boutique';
                        if ($boutique['sunmarketer'] != 'none' && $boutique['sunmarketer'] != null && $boutique['sunmarketer'] != 'almost') {
                            if (isset($usermarketer))  AbonnementPaiment::createpaiement($usermarketer, (float)$bonus, 'Actif de parainage', $motif, 'XOF');
                            AbonnementPaiment::createpaiement($user, ((float)$montant - (float)$bonus), $action, $motif, 'XOF');
                        } else {
                            AbonnementPaiment::createpaiement($user, $montant, $action, $motif, 'XOF');
                        }
                        $help->removeAbonnement($data['boutique_slug']);
                        return \redirect('boutique')->with('success', $motif);
                    }
                } else {
                    return \redirect('boutique')->with('error', 'Nous ne parvenons pas à retrouvé l\'id de la transaction. Si vous êtes sûr d\'avoir effectué le paiement, veuillez s\'il vous plaît contacter le service client avec en appuis une capture de la validation du processus de paiement (acquerir sur paypal).');
                }
            }
        }
    }

    public function paydunyaredirectCatalogue(Request $request)
    {
        $data = $request->all();
        dd($data);
    }

    public function paydunyaredirect(Request $request)
    {
        $data = $request->all();
        $invoice = new \Paydunya\Checkout\CheckoutInvoice();
        $cmd = Commandes::findOrFail(Session::get('command_id_new'));
        if ($invoice->confirm($data['token'])) {
            if ($invoice->getStatus() == "completed") {
                //                $help=new Commandes();
                //                $help->removeCommandeAfterPaiementMake($cmd->slug);
                if ($invoice->getTotalAmount() == $cmd['total_price']) {
                    $status = 'SUCCESS';
                    $cmd->paiement_type = 'paid_now';
                    $cmd->source = 'PAYDUNYA';
                    $cmd->source_name = 'paydunya';
                    $reference = $data['token'];
                    if ($invoice->getTotalAmount() >= $cmd->total_price) {
                        $cmd->paiement_type = 'paid_now';
                    } else {
                        $cmd->paiement_type = 'paid_echellon';
                    }

                    $cmd->montant_payer = $cmd->montant_payer + $invoice->getTotalAmount();

                    $help = new Commandes();
                    $help->removeCommandeAfterPaiementMake($cmd->slug);
                    Session::flash('paiement', 'Paiement effectué pour ' . $cmd->total_price . ' ' . $cmd->currency . ' XOF avec succès . Veuillez patientez un opérateur vous contactera pour les modalités de livraison.');
                    Session::put(['panier' => 0, 'prix' => 0]);
                    Session::put('addedArticles', []);
                    Session::put('commandes', []);
                    if ($cmd->montant_payer >= $cmd->total_price) {
                        $cmdt = CommandArticle::where('command_slug', $cmd->slug)->get();
                        foreach ($cmdt as $commandearticle) {
                            $article = CatalogueArticles::where('slug', $commandearticle->article_slug)->first();
                            if ($article['boutique_slug'] == Session::get('boutique')['slug']) {
                                $modart = CatalogueArticles::findOrFail($article['id']);
                                $modart->quantity = (intval($modart->quantity) - intval($commandearticle->quantity));
                                $modart->save();
                            } else {
                                $helpers = new HelperController();
                                $stock = $helpers->get_meta_article('stock', $commandearticle->article_slug, Session::get('boutique')['slug']);
                                $stock = (intval($stock) - intval($commandearticle->quantity));
                                $helpers->update_meta_article('stock', $commandearticle->article_slug, $stock, Session::get('boutique')['slug']);
                            }
                        }

                        // Ajouter le montant à l'actif du détenteur de la boutique
                        $fportefeuille = Portefeuille::where('user_slug', Session::get('boutique')['user_slug'])->where('devise', Session::get('boutique')['meta']['currency_admin'])->first()['id'];
                        if (isset($fportefeuille) && $fportefeuille != null && $fportefeuille != "") {
                            $portefeuille = Portefeuille::findOrFail($fportefeuille);
                            $portefeuille->montant = $portefeuille->montant + $cmd->total_price;
                            $total_new_montant = $portefeuille->montant;
                            $time = false;
                            $portefeuille->save();
                        } else {
                            Portefeuille::create(['user_slug' => Session::get('boutique')['user_slug'], 'montant' => $cmd->total_price]);
                            $time = true;
                        }
                        $boutique = Boutique::with('user')->where('slug', Session::get('boutique')['slug'])->first();
                        $subject = 'Portefeuille incrementé sur la boutique ' . $boutique->nom_boutique;
                        $messages = ['first_name' => $boutique->user->first_name, 'last_name' => $boutique->user->last_name, 'montant' => $cmd->total_price, 'time' => $time, 'boutique' => $boutique->nom_boutique, 'devise' => Session::get('boutique')['meta']['currency_admin']];
                        MailController::SendPortefeuilleMail($subject, $messages, $boutique->user->email);
                    }
                    //BEGIN SEND MAIL TO SHIPPING AGENCE
                    $articlesCommand = CommandArticle::with('article_')->where('command_slug', $cmd->slug)->get();
                    $services = ServiceShipping::where('slug', $cmd->shipping_service)->first();
                    if (isset($services)) {
                        $shippingInfos = DB::table('marchand_shipping_informations')->where('boutique_slug', Session::get('boutique')['slug'])->first();
                        $boutiqueRelate = Boutique::with('meta', 'user', 'metier')->where('slug', Session::get('boutique')['slug'])->first();
                        $template = 'Mail.livraison_make';
                        $subject = "Commande enrégistré sur sungrocery";
                        $email = $services->email;
                        $from = env('MAIL_USERNAME');
                        $messages = ['commande' => $cmd, 'articles' => $articlesCommand, 'agence' => $services->name, 'name' => $boutique->nom_boutique, 'depart' => $shippingInfos->depart, 'description' => $shippingInfos->Description, 'adresse' => $shippingInfos->adresse, 'tel' => $boutiqueRelate->meta->telephone_boutique, 'first_name' => $boutiqueRelate->user->first_name, 'last_name' => $boutiqueRelate->user->last_name, 'metier' => $boutiqueRelate->metier->intitule_metier];
                        $mail = new MailController();
                        //send to agence
                        $mail->SendGeneralUniqueMail($template, $subject, $messages, $email, $from);
                        //end send mail to shipping agence
                    }
                    $cmd->statut_paiement = true;

                    $cmd->reference = $reference;
                    $cmd->save();
                    $commandes = Commandes::with('commande_article')->where('id', Session::get('command_id_new'))->get();
                    foreach ($commandes as $cmd) {
                        foreach ($cmd->commande_article as $cmd_art) {
                            $articles = CatalogueArticles::with('article_meta')->where('slug', $cmd_art->article_slug)->get();
                            $cmd_art->article = $articles;
                        }
                    }

                    $commande_echeloner = $commandes->where('paiement_type', 'paid_echellon');
                    $commande_en_cours = $commandes->where('statut_paiement', false)->where('statut_shipping', false)->where('paiement_type', '<>', 'paid_echellon');
                    $commande_valides = $commandes->where('statut_shipping', true);

                    $boutique = Session::get('boutique');
                    $categoriesListe = DB::table('selected_categories')->where('boutique_slug', $boutique['slug'])->pluck('categorie_slug')->toArray();
                    $categories = \App\CategorieCatalogue::whereIn('slug', $categoriesListe)->orwhere('boutique_slug', $boutique['slug'])->get();
                    $categories_id = \App\CategorieCatalogue::whereIn('slug', $categoriesListe)->orwhere('boutique_slug', $boutique['slug'])->pluck('id')->toArray();
                    $caracteristique = CategorieCaracteristique::whereIn('categorie_catalogue_id', $categories_id)->get();
                    $images = Images::all()->where('type', 'articles');
                    $helper = new helper();
                    $controler = new BoutiqueController($helper);
                    $controler->viewSahring();
                    return view('dashboard.Boutique.Boutique_template.pages.paiement_status', compact('commande_valides', 'commande_en_cours', 'commande_echeloner', 'metas', 'status', 'cmd', 'articles', 'images', 'categories', 'caracteristique', 'commandes'));
                }
            }
        }
    }

    public function payCommandWithpaypal(Request $request)
    {
        $data = $request->all();
        Session::put('data', json_encode($data));
        $payer = new Payer();
        $payer->setPaymentMethod('paypal');
        $cmd = Commandes::findOrFail(Session::get('command_id_new'));
        $cmdt =   CommandArticle::where('command_slug', $cmd->slug)->get();
        $currency = $cmd->currency;
        $helpers = new HelperController();
        $item = array();
        foreach ($cmdt as $commandearticle) {
            $item_1 = new Item();
            $article = CatalogueArticles::where('slug', $commandearticle->article_slug)->first();
            $price = $commandearticle->price;
            if ($currency != 'USD' || $currency != 'EUR') {
                $price = $helpers->convertCurrency($currency, 'USD', $commandearticle->price);
                $currency = 'USD';
            }
            $price = (float) $price;
            array_push(
                $item,
                $item_1->setName($article->name)
                    ->setCurrency($currency)
                    ->setQuantity($commandearticle->quantity)
                    ->setPrice($price)
            );
        }
        $currency = $cmd->currency;
        $total_price = $cmd->total_price;
        if ($currency != 'USD' || $currency != 'EUR') {
            $total_price = $helpers->convertCurrency($currency, 'USD', $cmd->total_price);
            $currency = 'USD';
        }
        $total_price = (float) $total_price;
        $item_list = new ItemList();
        $item_list->setItems($item);
        $amount = new Amount();
        $amount->setCurrency($currency)
            ->setTotal($total_price);
        $transaction = new Transaction();
        $transaction->setAmount($amount)
            ->setItemList($item_list)
            ->setDescription('Merci d\'avoir choisis sungrocery');
        $redirect_urls = new RedirectUrls();
        $redirect_urls->setReturnUrl($data['return'])
            /** Specify return URL **/
            ->setCancelUrl($data['return']);
        $payment = new Payment();
        $payment->setIntent('Sale')
            ->setPayer($payer)
            ->setRedirectUrls($redirect_urls)
            ->setTransactions(array($transaction));
        /** dd($payment->create($this->_api_context));exit; **/
        try {
            $payment->create($this->_api_context);
        } catch (\PayPal\Exception\PayPalConnectionException $ex) {
            if (Config::get('app.debug')) {
                return json_encode(['return_url' => $data['return'], 'error' => true, 'message' => 'Désolé votre connection à expirer sur paypal. Veuillez reéssayer un peu plus tard.' . $ex->getMessage()]);
            } else {
                return json_encode(['return_url' => $data['return'], 'error' => true, 'message' => 'Désolé une erreure est survenue. Veuillez reéssayer un peu plus tard.']);
            }
        }
        foreach ($payment->getLinks() as $link) {
            if ($link->getRel() == 'approval_url') {
                $redirect_url = $link->getHref();
                break;
            }
        }
        /** add payment ID to session **/
        Session::put('paypal_payment_id', $payment->getId());
        if (isset($redirect_url)) {
            /** redirect to paypal **/
            return json_encode(['redirect_url' => $redirect_url, 'error' => false]);
        }
        return json_encode(['return_url' => $data['return'], 'error' => true, 'message' => 'Une erreure est survenue. Veuillez reéssayer un peu plus tard.']);
    }

    public function payWithpaypal(Request $request)
    {
        $data = $request->all();
        Session::put('data', $data['data']);
        $payer = new Payer();
        $payer->setPaymentMethod('paypal');
        $helpers = new HelperController();
        $price = $data['amount'];
        if ($data['currency_code'] != 'USD') {
            $price = $helpers->convertCurrency('XOF', 'USD', $price);
            $price = (float) $price;
            $data['currency_code'] = 'USD';
        }
        $data = array_merge($data, json_decode(Session::get('data'), true));
        if (isset($data['boutique_slug'])) {
            $boutique_abonnement = $data['boutique_slug'];
            $shop = Boutique::with('meta')->where('slug', $boutique_abonnement)->first();
            if ($shop != null && $shop->meta->internationalize && $shop->meta->pay_internationalize) {
                $subprice = $helpers->convertCurrency('XOF', 'USD', 2500);
                $subprice = (float)$subprice;
                $price = $price + $subprice;
            }
        }
        $item_1 = new Item();
        $item_1->setName($data['transaction_type'])
            /** item name **/
            ->setCurrency($data['currency_code'])
            ->setQuantity(1)
            ->setPrice($price);
        /** unit price **/

        $item_list = new ItemList();
        $item_list->setItems(array($item_1));

        $amount = new Amount();
        $amount->setCurrency($data['currency_code'])
            ->setTotal($price);
        $transaction = new Transaction();
        $transaction->setAmount($amount)
            ->setItemList($item_list)
            ->setDescription('Paiement');
        $redirect_urls = new RedirectUrls();
        $redirect_urls->setReturnUrl($data['return'])
            /** Specify return URL **/
            ->setCancelUrl($data['return']);
        $payment = new Payment();
        $payment->setIntent('Sale')
            ->setPayer($payer)
            ->setRedirectUrls($redirect_urls)
            ->setTransactions(array($transaction));
        /** dd($payment->create($this->_api_context));exit; **/

        try {
            $payment->create($this->_api_context);
        } catch (\PayPal\Exception\PayPalConnectionException $ex) {
            if (Config::get('app.debug')) {
                return json_encode(['return_url' => $data['return'], 'error' => true, 'message' => 'Désolé votre connection à expirer sur paypal. Veuillez reéssayer un peu plus tard.' . $ex->getMessage()]);
            } else {
                return json_encode(['return_url' => $data['return'], 'error' => true, 'message' => 'Désolé une erreure est survenue. Veuillez reéssayer un peu plus tard.']);
            }
        }
        foreach ($payment->getLinks() as $link) {
            if ($link->getRel() == 'approval_url') {
                $redirect_url = $link->getHref();
                break;
            }
        }
        /** add payment ID to session **/
        Session::put('paypal_payment_id', $payment->getId());
        if (isset($redirect_url)) {
            /** redirect to paypal **/
            return json_encode(['redirect_url' => $redirect_url, 'error' => false]);
        }
        return json_encode(['return_url' => $data['return'], 'error' => true, 'message' => 'Une erreure est survenue. Veuillez reéssayer un peu plus tard.']);
    }

    public function payWithpaypalForNewsletters(Request $request)
    {
        $data = $request->all();
        Session::put('data', $data['data']);
        $payer = new Payer();
        $payer->setPaymentMethod('paypal');
        $helpers = new HelperController();
        $price = $data['amount'];
        if ($data['currency_code'] != 'USD') {
            $price = $helpers->convertCurrency('XOF', 'USD', $price);
            $price = (float) $price;
            $data['currency_code'] = 'USD';
        }
        $item_1 = new Item();
        $item_1->setName($data['transaction_type'])
            /** item name **/
            ->setCurrency($data['currency_code'])
            ->setQuantity(1)
            ->setPrice($price);
        /** unit price **/

        $item_list = new ItemList();
        $item_list->setItems(array($item_1));

        $amount = new Amount();
        $amount->setCurrency($data['currency_code'])
            ->setTotal($price);
        $transaction = new Transaction();
        $transaction->setAmount($amount)
            ->setItemList($item_list)
            ->setDescription('Your transaction description');
        $redirect_urls = new RedirectUrls();
        $redirect_urls->setReturnUrl($data['return'])
            /** Specify return URL **/
            ->setCancelUrl($data['return']);
        $payment = new Payment();
        $payment->setIntent('Sale')
            ->setPayer($payer)
            ->setRedirectUrls($redirect_urls)
            ->setTransactions(array($transaction));
        /** dd($payment->create($this->_api_context));exit; **/

        try {
            $payment->create($this->_api_context);
        } catch (\PayPal\Exception\PayPalConnectionException $ex) {
            if (Config::get('app.debug')) {
                return json_encode(['return_url' => $data['return'], 'error' => true, 'message' => 'Désolé votre connection à expirer sur paypal. Veuillez reéssayer un peu plus tard.' . $ex->getMessage()]);
            } else {
                return json_encode(['return_url' => $data['return'], 'error' => true, 'message' => 'Désolé une erreure est survenue. Veuillez reéssayer un peu plus tard.']);
            }
        }
        foreach ($payment->getLinks() as $link) {
            if ($link->getRel() == 'approval_url') {
                $redirect_url = $link->getHref();
                break;
            }
        }
        /** add payment ID to session **/
        Session::put('paypal_payment_id', $payment->getId());
        if (isset($redirect_url)) {
            /** redirect to paypal **/
            return json_encode(['redirect_url' => $redirect_url, 'error' => false]);
        }
        return json_encode(['return_url' => $data['return'], 'error' => true, 'message' => 'Une erreure est survenue. Veuillez reéssayer un peu plus tard.']);
    }

    public function payNewslettersWithpaypal(Request $request)
    {
        $data = $request->all();
        Session::put('data', $data['data']);
        $payer = new Payer();
        $payer->setPaymentMethod('paypal');
        $helpers = new HelperController();
        $datas = json_decode($data['data'], true);
        $abonnement = NewslettersOptionAbonnement::where('slug', $datas['data']['slug'])->first();
        $price = $abonnement['prix'];
        if ($abonnement['devise'] != 'USD' || Session::get('continent') == 'Africa') {
            $price = $helpers->convertCurrency('XOF', 'USD', $price);
            $price = (float) $price;
        }
        $item_1 = new Item();
        $item_1->setName($data['transaction_type'])
            /** item name **/
            ->setCurrency('USD')
            ->setQuantity(1)
            ->setPrice($price);
        /** unit price **/

        $item_list = new ItemList();
        $item_list->setItems(array($item_1));

        $amount = new Amount();
        $amount->setCurrency('USD')
            ->setTotal($price);
        $transaction = new Transaction();
        $transaction->setAmount($amount)
            ->setItemList($item_list)
            ->setDescription('Your transaction description');
        $redirect_urls = new RedirectUrls();
        $redirect_urls->setReturnUrl($data['return'])
            /** Specify return URL **/
            ->setCancelUrl($data['return']);

        $payment = new Payment();
        $payment->setIntent('Sale')
            ->setPayer($payer)
            ->setRedirectUrls($redirect_urls)
            ->setTransactions(array($transaction));
        /** dd($payment->create($this->_api_context));exit; **/
        try {
            $payment->create($this->_api_context);
        } catch (\PayPal\Exception\PayPalConnectionException $ex) {
            if (Config::get('app.debug')) {
                return json_encode(['return_url' => $data['return'], 'error' => true, 'message' => 'Désolé votre connection à expirer sur paypal. Veuillez reéssayer un peu plus tard.' . $ex->getMessage()]);
            } else {
                return json_encode(['return_url' => $data['return'], 'error' => true, 'message' => 'Désolé une erreure est survenue. Veuillez reéssayer un peu plus tard.']);
            }
        }
        foreach ($payment->getLinks() as $link) {
            if ($link->getRel() == 'approval_url') {
                $redirect_url = $link->getHref();
                break;
            }
        }
        /** add payment ID to session **/
        Session::put('paypal_payment_id', $payment->getId());
        if (isset($redirect_url)) {
            /** redirect to paypal **/
            return json_encode(['redirect_url' => $redirect_url, 'error' => false]);
        }
        return json_encode(['return_url' => $data['return'], 'error' => true, 'message' => 'Une erreure est survenue. Veuillez reéssayer un peu plus tard.']);
    }

    public function international_visibility(Request $request)
    {
        $data = $request->all();
        Session::put('data', $data['data']);
        $payer = new Payer();
        $helpers = new HelperController();
        $payer->setPaymentMethod('paypal');
        $price = $data['amount'];
        $price = $helpers->convertCurrency('XOF', 'USD', $price);
        $price = (float) $price;
        $item_1 = new Item();
        $item_1->setName('Activation services de visibilité international')
            /** item name **/
            ->setCurrency($data['currency_code'])
            ->setQuantity(1)
            ->setPrice($price);
        /** unit price **/
        $item_list = new ItemList();
        $item_list->setItems(array($item_1));

        $amount = new Amount();
        $amount->setCurrency($data['currency_code'])
            ->setTotal($price);
        $transaction = new Transaction();
        $transaction->setAmount($amount)
            ->setItemList($item_list)
            ->setDescription('');
        $redirect_urls = new RedirectUrls();
        $redirect_urls->setReturnUrl($data['return'])
            /** Specify return URL **/
            ->setCancelUrl($data['return']);
        $payment = new Payment();
        $payment->setIntent('Sale')
            ->setPayer($payer)
            ->setRedirectUrls($redirect_urls)
            ->setTransactions(array($transaction));
        /** dd($payment->create($this->_api_context));exit; **/
        try {
            $payment->create($this->_api_context);
        } catch (\PayPal\Exception\PayPalConnectionException $ex) {
            if (Config::get('app.debug')) {
                return json_encode(['return_url' => $data['return'], 'error' => true, 'message' => 'Désolé votre connection à expirer sur paypal. Veuillez reéssayer un peu plus tard. ' . $ex->getMessage()]);
            } else {
                return json_encode(['return_url' => $data['return'], 'error' => true, 'message' => 'Désolé une erreure est survenue. Veuillez reéssayer un peu plus tard.']);
            }
        }
        foreach ($payment->getLinks() as $link) {
            if ($link->getRel() == 'approval_url') {
                $redirect_url = $link->getHref();
                break;
            }
        }
        /** add payment ID to session **/
        Session::put('paypal_payment_id', $payment->getId());
        if (isset($redirect_url)) {
            /** redirect to paypal **/
            return json_encode(['redirect_url' => $redirect_url, 'error' => false]);
        }
        return json_encode(['return_url' => $data['return'], 'error' => true, 'message' => 'Une erreure est survenue. Veuillez reéssayer un peu plus tard.']);
    }

    public function paypalPaiementEchelonner(Request $request)
    {
        $data = $request->all();
        Session::put('data', $data['data']);
        $payer = new Payer();
        $helpers = new HelperController();
        $payer->setPaymentMethod('paypal');
        $price = $data['amount'];
        $price = $helpers->convertCurrency('XOF', 'USD', $price);
        $price = (float) $price;
        $item_1 = new Item();
        $item_1->setName('Activation services de paiement echelonner')
            /** item name **/
            ->setCurrency($data['currency_code'])
            ->setQuantity(1)
            ->setPrice($price);
        /** unit price **/
        $item_list = new ItemList();
        $item_list->setItems(array($item_1));

        $amount = new Amount();
        $amount->setCurrency($data['currency_code'])
            ->setTotal($price);
        $transaction = new Transaction();
        $transaction->setAmount($amount)
            ->setItemList($item_list)
            ->setDescription('');
        $redirect_urls = new RedirectUrls();
        $redirect_urls->setReturnUrl($data['return'])
            /** Specify return URL **/
            ->setCancelUrl($data['return']);
        $payment = new Payment();
        $payment->setIntent('Sale')
            ->setPayer($payer)
            ->setRedirectUrls($redirect_urls)
            ->setTransactions(array($transaction));
        /** dd($payment->create($this->_api_context));exit; **/
        try {
            $payment->create($this->_api_context);
        } catch (\PayPal\Exception\PayPalConnectionException $ex) {
            if (Config::get('app.debug')) {
                return json_encode(['return_url' => $data['return'], 'error' => true, 'message' => 'Désolé votre connection à expirer sur paypal. Veuillez reéssayer un peu plus tard. ' . $ex->getMessage()]);
            } else {
                return json_encode(['return_url' => $data['return'], 'error' => true, 'message' => 'Désolé une erreure est survenue. Veuillez reéssayer un peu plus tard.']);
            }
        }
        foreach ($payment->getLinks() as $link) {
            if ($link->getRel() == 'approval_url') {
                $redirect_url = $link->getHref();
                break;
            }
        }
        /** add payment ID to session **/
        Session::put('paypal_payment_id', $payment->getId());
        if (isset($redirect_url)) {
            /** redirect to paypal **/
            return json_encode(['redirect_url' => $redirect_url, 'error' => false]);
        }
        return json_encode(['return_url' => $data['return'], 'error' => true, 'message' => 'Une erreure est survenue. Veuillez reéssayer un peu plus tard.']);
    }

    public function paypalPaiementAbonnementMib(Request $request)
    {
        $data = $request->all();
        Session::put('data', $data['data']);
        $payer = new Payer();
        $helpers = new HelperController();
        $payer->setPaymentMethod('paypal');
        $price = $data['amount'];
        $price = $helpers->convertCurrency('XOF', 'USD', $price);
        $price = (float) $price;
        $item_1 = new Item();
        $item_1->setName('Activation module Panier Mib')
            /** item name **/
            ->setCurrency($data['currency_code'])
            ->setQuantity(1)
            ->setPrice($price);
        /** unit price **/
        $item_list = new ItemList();
        $item_list->setItems(array($item_1));

        $amount = new Amount();
        $amount->setCurrency($data['currency_code'])
            ->setTotal($price);
        $transaction = new Transaction();
        $transaction->setAmount($amount)
            ->setItemList($item_list)
            ->setDescription('');
        $redirect_urls = new RedirectUrls();
        $redirect_urls->setReturnUrl($data['return'])
            /** Specify return URL **/
            ->setCancelUrl($data['return']);
        $payment = new Payment();
        $payment->setIntent('Sale')
            ->setPayer($payer)
            ->setRedirectUrls($redirect_urls)
            ->setTransactions(array($transaction));
        /** dd($payment->create($this->_api_context));exit; **/
        try {
            $payment->create($this->_api_context);
        } catch (\PayPal\Exception\PayPalConnectionException $ex) {
            if (Config::get('app.debug')) {
                return json_encode(['return_url' => $data['return'], 'error' => true, 'message' => 'Désolé votre connection à expirer sur paypal. Veuillez reéssayer un peu plus tard. ' . $ex->getMessage()]);
            } else {
                return json_encode(['return_url' => $data['return'], 'error' => true, 'message' => 'Désolé une erreure est survenue. Veuillez reéssayer un peu plus tard.']);
            }
        }
        foreach ($payment->getLinks() as $link) {
            if ($link->getRel() == 'approval_url') {
                $redirect_url = $link->getHref();
                break;
            }
        }
        /** add payment ID to session **/
        Session::put('paypal_payment_id', $payment->getId());
        if (isset($redirect_url)) {
            /** redirect to paypal **/
            return json_encode(['redirect_url' => $redirect_url, 'error' => false]);
        }
        return json_encode(['return_url' => $data['return'], 'error' => true, 'message' => 'Une erreure est survenue. Veuillez reéssayer un peu plus tard.']);
    }

    public function paySouscriptionMibWithpaypal(Request $request)
    {
        $data = $request->all();
        Session::put('data', $data['data']);
        $payer = new Payer();
        $helpers = new HelperController();
        $payer->setPaymentMethod('paypal');
        $price = $data['amount'];
        $price = $helpers->convertCurrency('XOF', 'USD', $price);
        $price = (float) $price;
        $item_1 = new Item();
        $item_1->setName('Souscription Panier Mib')
            /** item name **/
            ->setCurrency($data['currency_code'])
            ->setQuantity(1)
            ->setPrice($price);
        /** unit price **/
        $item_list = new ItemList();
        $item_list->setItems(array($item_1));

        $amount = new Amount();
        $amount->setCurrency($data['currency_code'])
            ->setTotal($price);
        $transaction = new Transaction();
        $transaction->setAmount($amount)
            ->setItemList($item_list)
            ->setDescription('');
        $redirect_urls = new RedirectUrls();
        $redirect_urls->setReturnUrl($data['return'])
            /** Specify return URL **/
            ->setCancelUrl($data['return']);
        $payment = new Payment();
        $payment->setIntent('Sale')
            ->setPayer($payer)
            ->setRedirectUrls($redirect_urls)
            ->setTransactions(array($transaction));
        /** dd($payment->create($this->_api_context));exit; **/
        try {
            $payment->create($this->_api_context);
        } catch (\PayPal\Exception\PayPalConnectionException $ex) {
            if (Config::get('app.debug')) {
                return json_encode(['return_url' => $data['return'], 'error' => true, 'message' => 'Désolé votre connection à expirer sur paypal. Veuillez reéssayer un peu plus tard. ' . $ex->getMessage()]);
            } else {
                return json_encode(['return_url' => $data['return'], 'error' => true, 'message' => 'Désolé une erreure est survenue. Veuillez reéssayer un peu plus tard.']);
            }
        }
        foreach ($payment->getLinks() as $link) {
            if ($link->getRel() == 'approval_url') {
                $redirect_url = $link->getHref();
                break;
            }
        }
        /** add payment ID to session **/
        Session::put('paypal_payment_id', $payment->getId());
        if (isset($redirect_url)) {
            /** redirect to paypal **/
            return json_encode(['redirect_url' => $redirect_url, 'error' => false]);
        }
        return json_encode(['return_url' => $data['return'], 'error' => true, 'message' => 'Une erreure est survenue. Veuillez reéssayer un peu plus tard.']);
    }

    public function payCotisationMibWithpaypal(Request $request)
    {
        $data = $request->all();
        Session::put('data', $data['data']);
        $payer = new Payer();
        $helpers = new HelperController();
        $payer->setPaymentMethod('paypal');
        $price = $data['amount'];
        $price = $helpers->convertCurrency('XOF', 'USD', $price);
        $price = (float) $price;
        $item_1 = new Item();
        $item_1->setName('Paiement cotisation Panier Mib')
            /** item name **/
            ->setCurrency($data['currency_code'])
            ->setQuantity(1)
            ->setPrice($price);
        /** unit price **/
        $item_list = new ItemList();
        $item_list->setItems(array($item_1));

        $amount = new Amount();
        $amount->setCurrency($data['currency_code'])
            ->setTotal($price);
        $transaction = new Transaction();
        $transaction->setAmount($amount)
            ->setItemList($item_list)
            ->setDescription('');
        $redirect_urls = new RedirectUrls();
        $redirect_urls->setReturnUrl($data['return'])
            /** Specify return URL **/
            ->setCancelUrl($data['return']);
        $payment = new Payment();
        $payment->setIntent('Sale')
            ->setPayer($payer)
            ->setRedirectUrls($redirect_urls)
            ->setTransactions(array($transaction));
        /** dd($payment->create($this->_api_context));exit; **/
        try {
            $payment->create($this->_api_context);
        } catch (\PayPal\Exception\PayPalConnectionException $ex) {
            if (Config::get('app.debug')) {
                return json_encode(['return_url' => $data['return'], 'error' => true, 'message' => 'Désolé votre connection à expirer sur paypal. Veuillez reéssayer un peu plus tard. ' . $ex->getMessage()]);
            } else {
                return json_encode(['return_url' => $data['return'], 'error' => true, 'message' => 'Désolé une erreure est survenue. Veuillez reéssayer un peu plus tard.']);
            }
        }
        foreach ($payment->getLinks() as $link) {
            if ($link->getRel() == 'approval_url') {
                $redirect_url = $link->getHref();
                break;
            }
        }
        /** add payment ID to session **/
        Session::put('paypal_payment_id', $payment->getId());
        if (isset($redirect_url)) {
            /** redirect to paypal **/
            return json_encode(['redirect_url' => $redirect_url, 'error' => false]);
        }
        return json_encode(['return_url' => $data['return'], 'error' => true, 'message' => 'Une erreure est survenue. Veuillez reéssayer un peu plus tard.']);
    }

    public function getPaymentStatus(Request $request)
    {
        //       $amount= $this->helpers->convertCurrency('XOF','USD','10000');
        //        dd($amount);
        $data = $request->all();
        //        array_push($data,json_decode(Session::get('data'),true));
        $data = array_merge($data, json_decode(Session::get('data'), true));
        //   Session::forget('data');
        /** Get the payment ID before session clear **/
        $payment_id = $data['paymentId'];
        /** clear the session payment ID **/
        if (empty(Input::get('PayerID')) || empty(Input::get('token'))) {
            return json_encode(['message' => 'Echec de paiement! la transaction n\'à pas aboutis', 'error' => true]);
        }
        $payment = Payment::get($payment_id, $this->_api_context);
        $execution = new PaymentExecution();
        $execution->setPayerId(Input::get('PayerID'));
        /**Execute the payment **/
        $result = $payment->execute($execution, $this->_api_context);
        $transact = $result->getTransactions();
        if ($result->getState() == 'approved') {
            $status = 'SUCCESS';
            switch ($data['transaction_type']) {
                case 'commandes':
                    $cmd = Commandes::findOrFail(Session::get('command_id_new'));
                    if ((int)$transact[0]->amount->total == (int)$cmd->total_price) {
                        $cmd->paiement_type = 'paid_now';
                    } else {
                        $cmd->paiement_type = 'paid_echellon';
                    }
                    $cmd->source = 'PAYPAL';
                    $cmd->source_name = 'PAYPAL';
                    $cmd->montant_payer = $cmd->montant_payer + (int)$transact[0]->amount->total;
                    $reference = $payment_id;
                    $help = new Commandes();
                    $help->removeCommandeAfterPaiementMake($cmd->slug);
                    Session::flash('paiement', 'Paiement effectué pour ' . $cmd->total_price . ' ' . $cmd->currency . ' XOF avec succès . Veuillez patientez un opérateur vous contactera pour les modalités de livraison.');
                    Session::put(['panier' => 0, 'prix' => 0]);
                    Session::put('addedArticles', []);
                    Session::put('commandes', []);
                    if ($cmd->montant_payer >= $cmd->total_price) {
                        $cmdt = CommandArticle::where('command_slug', $cmd->slug)->get();
                        foreach ($cmdt as $commandearticle) {
                            $article = CatalogueArticles::where('slug', $commandearticle->article_slug)->first();
                            if ($article['boutique_slug'] == Session::get('boutique')['slug']) {
                                $modart = CatalogueArticles::findOrFail($article['id']);
                                $modart->quantity = (intval($modart->quantity) - intval($commandearticle->quantity));
                                $modart->save();
                            } else {
                                $helpers = new HelperController();
                                $stock = $helpers->get_meta_article('stock', $commandearticle->article_slug, Session::get('boutique')['slug']);
                                $stock = (intval($stock) - intval($commandearticle->quantity));
                                $helpers->update_meta_article('stock', $commandearticle->article_slug, $stock, Session::get('boutique')['slug']);
                            }
                        }

                        // Ajouter le montant à l'actif du détenteur de la boutique
                        $fportefeuille = Portefeuille::where('user_slug', Session::get('boutique')['user_slug'])->where('devise', Session::get('boutique')['meta']['currency_admin'])->first()['id'];
                        if (isset($fportefeuille) && $fportefeuille != null && $fportefeuille != "") {
                            $portefeuille = Portefeuille::findOrFail($fportefeuille);
                            $portefeuille->montant = $portefeuille->montant + $cmd->total_price;
                            $total_new_montant = $portefeuille->montant;
                            $time = false;
                            $portefeuille->save();
                        } else {
                            Portefeuille::create(['user_slug' => Session::get('boutique')['user_slug'], 'montant' => $cmd->total_price]);
                            $time = true;
                        }
                        $boutique = Boutique::with('user')->where('slug', Session::get('boutique')['slug'])->first();
                        $subject = 'Portefeuille incrementé sur la boutique ' . $boutique->nom_boutique;
                        $messages = ['first_name' => $boutique->user->first_name, 'last_name' => $boutique->user->last_name, 'montant' => $cmd->total_price, 'time' => $time, 'boutique' => $boutique->nom_boutique, 'devise' => Session::get('boutique')['meta']['currency_admin']];
                        MailController::SendPortefeuilleMail($subject, $messages, $boutique->user->email);
                    }
                    //BEGIN SEND MAIL TO SHIPPING AGENCE
                    $articlesCommand = CommandArticle::with('article_')->where('command_slug', $cmd->slug)->get();
                    $services = ServiceShipping::where('slug', $cmd->shipping_service)->first();
                    if (isset($services)) {
                        $shippingInfos = DB::table('marchand_shipping_informations')->where('boutique_slug', Session::get('boutique')['slug'])->first();
                        $boutiqueRelate = Boutique::with('meta', 'user', 'metier')->where('slug', Session::get('boutique')['slug'])->first();
                        $template = 'Mail.livraison_make';
                        $subject = "Commande enrégistré sur sungrocery";
                        $email = $services->email;
                        $from = env('MAIL_USERNAME');
                        $messages = ['commande' => $cmd, 'articles' => $articlesCommand, 'agence' => $services->name, 'name' => $boutique->nom_boutique, 'depart' => $shippingInfos->depart, 'description' => $shippingInfos->Description, 'adresse' => $shippingInfos->adresse, 'tel' => $boutiqueRelate->meta->telephone_boutique, 'first_name' => $boutiqueRelate->user->first_name, 'last_name' => $boutiqueRelate->user->last_name, 'metier' => $boutiqueRelate->metier->intitule_metier];
                        $mail = new MailController();
                        //send to agence
                        $mail->SendGeneralUniqueMail($template, $subject, $messages, $email, $from);
                        //end send mail to shipping agence
                    }
                    $cmd->statut_paiement = true;
                    $cmd->reference = $reference;
                    $cmd->save();
                    $commandes = Commandes::with('commande_article')->where('id', Session::get('command_id_new'))->get();
                    foreach ($commandes as $cmd) {
                        foreach ($cmd->commande_article as $cmd_art) {
                            $articles = CatalogueArticles::with('article_meta')->where('slug', $cmd_art->article_slug)->get();
                            $cmd_art->article = $articles;
                        }
                    }

                    $commande_echeloner = $commandes->where('paiement_type', 'paid_echellon');
                    $commande_en_cours = $commandes->where('statut_paiement', false)->where('statut_shipping', false)->where('paiement_type', '<>', 'paid_echellon');
                    $commande_valides = $commandes->where('statut_shipping', true);

                    $boutique = Session::get('boutique');
                    $categoriesListe = DB::table('selected_categories')->where('boutique_slug', $boutique['slug'])->pluck('categorie_slug')->toArray();
                    $categories = \App\CategorieCatalogue::whereIn('slug', $categoriesListe)->orwhere('boutique_slug', $boutique['slug'])->get();
                    $categories_id = \App\CategorieCatalogue::whereIn('slug', $categoriesListe)->orwhere('boutique_slug', $boutique['slug'])->pluck('id')->toArray();
                    $caracteristique = CategorieCaracteristique::whereIn('categorie_catalogue_id', $categories_id)->get();
                    $images = Images::all()->where('type', 'articles');
                    $helper = new helper();
                    $controler = new BoutiqueController($helper);
                    $controler->viewSahring();
                    return view('dashboard.Boutique.Boutique_template.pages.paiement_status', compact('commande_valides', 'commande_en_cours', 'commande_echeloner', 'metas', 'status', 'cmd', 'articles', 'images', 'categories', 'caracteristique', 'commandes'));
                    break;
                case 'activation_boutique':
                    if (isset($data['slug'])) {
                        $abonnement_slug = $data['slug'];
                        $boutique_abonnement = $data['boutique_slug'];
                        $abonnement = EtatAbonnement::where('slug', $abonnement_slug)->first();
                        $boutique = Boutique::where('slug', $boutique_abonnement)->first();
                        LaravelFacebookPixelFacade::createEvent('Subscribe', $parameters = ['predicted_ltv' => $abonnement['price'], 'currency' => 'XOF', 'value' => $abonnement['price']]);
                        if ((int)$transact[0]->amount->total == (int)$abonnement['price']) {
                            $bonus = 0;
                            //send money to sunmarketers
                            if ($boutique['sunmarketer'] != 'none' && $boutique['sunmarketer'] != null && $boutique['sunmarketer'] != 'almost') {
                                $marketer = DB::table('marketers')->where('user_slug', $boutique['sunmarketer'])->first();
                                if (isset($marketer) && $marketer != null) {
                                    $usermarketer = $boutique['sunmarketer'];
                                    $portefeuille = DB::table('portefeuilles')->where('user_slug', $marketer->user_slug)->where('devise', ($marketer->currency != null ? $marketer->currency : 'USD'))->first();
                                    $ab = (float)$abonnement['price'];
                                    $reduc = 10;
                                    if ($boutique['sunmarketer_first_time'] == 0) {
                                        $reduc = 20;
                                        DB::table('boutiques')->where('slug', $boutique_abonnement)->update(['sunmarketer_first_time' => 1]);
                                    }
                                    $bonus = ($ab * $reduc) / 100;
                                    if ($marketer->currency != 'XOF' || $marketer->currency) {
                                        $helpers = new HelperController();
                                        $bonus = $helpers->convertCurrency('XOF', 'USD', $bonus);
                                    }
                                    if (isset($portefeuille) && $portefeuille != null) {
                                        $montant = (float)$portefeuille->montant + $bonus;

                                        DB::table('portefeuilles')
                                            ->where('user_slug', $marketer->user_slug)
                                            ->where('devise', 'XOF')
                                            ->update(['montant' => $montant]);
                                    } else {
                                        Portefeuille::create([
                                            'user_slug' => $marketer->user_slug,
                                            'devise' => ($marketer->currency != null ? $marketer->currency : 'USD'),
                                            'montant' => $bonus,
                                            'active' => true,
                                            'tentative' => 0,
                                            'created_at' => Carbon::now(),
                                            'updated_at' => Carbon::now(),
                                        ]);
                                    }
                                    $messages = "La boutique " . $boutique['nom_boutique'] . " à mis à jour son abonnement pour " . $abonnement['numberMonth'] . ' mois, pour un montant de ' . (float)$abonnement['price'] . '. Vous bénéficiez de 10% de la somme totale du montant soit ' . $bonus;
                                    if ($boutique['sunmarketer_first_time'] == 0) {
                                        $messages = "La boutique " . $boutique['nom_boutique'] . " à mis à jour son abonnement pour " . $abonnement['numberMonth'] . ' mois, pour un montant de ' . (float)$abonnement['price'] . '. Vous bénéficiez de 20% de la somme totale du montant soit ' . $bonus;
                                    }
                                } else {
                                    $code = CodePromo::where('code', $boutique['sunmarketer'])->first();
                                    if (isset($code) && $code != null) {
                                        $userData = DB::table('users')->where('id', $code['user_id'])->first();
                                        $usermarketer = $userData->slug;
                                        $portefeuille = DB::table('portefeuilles')->where('user_slug', $userData->slug)->where('devise',  'USD')->first();
                                        $ab = (float)$abonnement['price'];
                                        $bonus = ($ab * 25) / 100;
                                        //                                   if ($marketer->currency != 'XOF' || $marketer->currency) {
                                        //                                       $helpers = new HelperController();
                                        //                                       $bonus = $helpers->convertCurrency('XOF', 'USD', $bonus);
                                        //                                   }
                                        if (isset($portefeuille) && $portefeuille != null) {
                                            $montant = (float)$portefeuille->montant + $bonus;

                                            DB::table('portefeuilles')
                                                ->where('user_slug', $userData->slug)
                                                ->where('devise', 'XOF')
                                                ->update(['montant' => $montant]);
                                        } else {
                                            Portefeuille::create([
                                                'user_slug' => $userData->user_slug,
                                                'devise' => 'USD',
                                                'montant' => $bonus,
                                                'active' => true,
                                                'tentative' => 0,
                                                'created_at' => Carbon::now(),
                                                'updated_at' => Carbon::now(),
                                            ]);
                                        }
                                    }
                                    $messages = "La boutique " . $boutique['nom_boutique'] . " à mis à jour son abonnement pour " . $abonnement['numberMonth'] . ' mois, pour un montant de ' . (float)$abonnement['price'] . '. Vous bénéficiez de 25% de la somme totale du montant soit ' . $bonus;
                                }
                                //                               $sh= Boutique::findOrFail($boutique['id']);
                                //                               $sh->sunmarketer='almost';
                                //                               $sh->save();
                                $subject = 'Compte créditer';
                                MailController::SendGeneralUniqueMail('Mail.generale_blade', $subject, $messages, env('MAIL_ADMIN'), env('MAIL_USERNAME'));
                            }
                            //End sunmarketers bonus transaction

                            $data['slug'] = Str::slug(time() . 'boutique' . time() . 'abonnement');
                            $data['boutique_id'] = $boutique['id'];
                            $data['etat_abonnement_id'] = $abonnement['id'];
                            $data['expired'] = false;
                            DB::table('boutique_abonnements')->where('boutique_id', $boutique['id'])->where('etat_abonnement_id', $abonnement['id'])->update(['expired' => false]);
                            $boutique['expired']
                                ? $expireBoutique = Carbon::now()->format('M d Y H:i:s')
                                : $expireBoutique = Carbon::create($boutique['expired_to'])->format('M d Y H:i:s');
                            $expired_to = strtotime("+" . $abonnement['numberMonth'] . " months", strtotime($expireBoutique));
                            $myShop = Boutique::findOrFail($boutique['id']);
                            $myShop->expired_to = Carbon::createFromFormat('Y-m-d H:i:s', date('Y-m-d H:i:s', $expired_to));
                            $myShop->expired = false;
                            $myShop->save();
                            $data['expired_at'] = $myShop->expired_to;
                            BoutiqueAbonnement::create($data);
                            $user = Session::get('user')['slug'];
                            $boutique['expired']
                                ? $motif = 'Paiement effectué pour abonnement ' . $abonnement['name'] . ' de la boutique ' . $boutique['nom_boutique']
                                : $motif = 'Paiement effectué pour cumule d\'abonnement ' . $abonnement['name'] . ' de la boutique ' . $boutique['nom_boutique'];
                            $montant = $abonnement['price'];
                            $boutique['expired']
                                ? $action = 'Abonnement Boutique'
                                : $action = 'Cumule d\'abonnement Boutique';
                            if ($boutique['sunmarketer'] != 'none' && $boutique['sunmarketer'] != null && $boutique['sunmarketer'] != 'almost') {
                                if (isset($usermarketer))  AbonnementPaiment::createpaiement($usermarketer, (float)$bonus, 'Actif de parainage', $motif, 'XOF');
                                AbonnementPaiment::createpaiement($user, ((float)$montant - (float)$bonus), $action, $motif, 'USD');
                            } else {
                                AbonnementPaiment::createpaiement($user, $montant, $action, $motif, 'USD');
                            }
                            return \redirect('boutique')->with('success', $motif);
                        }
                    } else {
                        return \redirect('boutique')->with('error', 'Nous ne parvenons pas à retrouvé l\'id de la transaction. Si vous êtes sûr d\'avoir effectué le paiement, veuillez s\'il vous plaît contacter le service client avec en appuis une capture de la validation du processus de paiement (acquerir sur paypal).');
                    }
                    break;
                case 'activation_internationalize':
                    $boutique_slug = $data['boutique_slug'];
                    $boutique = Boutique::where('slug', $boutique_slug)->first();
                    $metas = BoutiqueMeta::where('boutique_id', $boutique['id'])->first();
                    $metas = BoutiqueMeta::findOrFail($metas['id']);
                    $metas->pay_internationalize = true;
                    $metas->save();
                    return \redirect('boutique')->with('success', 'Votre boutique ' . $boutique['nom_boutique'] . ' est maintenant visible à l\'inernational.');
                    break;
                case 'paiement_echelonner':
                    $boutique_slug = $data['boutique_slug'];
                    $data['boutique_slug'] = $boutique_slug;
                    $paiement_echelonner = PaiementEchelonner::where('boutique_slug', $boutique_slug)->first();
                    if (isset($paiement_echelonner)) {
                        if (new \DateTime($paiement_echelonner['expired_at']) > new \DateTime(date("Y-m-d H:i:s"))) {
                            $oneYearOn = date('Y-m-d', strtotime(date($paiement_echelonner['expired_at'], time()) . " + 365 day"));
                        } else {
                            $oneYearOn = date('Y-m-d', strtotime(date("Y-m-d H:i:s", time()) . " + 365 day"));
                        }
                        DB::table('paiement_echelonners')->where('boutique_slug', $boutique_slug)->update([
                            'expired_at' => $oneYearOn,
                            'max' => $data['max']
                        ]);
                    } else {
                        $oneYearOn = date('Y-m-d', strtotime(date("Y-m-d H:i:s", time()) . " + 365 day"));
                        $data['expired_at'] = $oneYearOn;
                        PaiementEchelonner::create($data);
                    }
                    $boutique = Boutique::where('slug', $boutique_slug)->first();
                    $metas = BoutiqueMeta::where('boutique_id', $boutique['id'])->first();
                    $metas = BoutiqueMeta::findOrFail($metas['id']);
                    $metas->paiement_echelonner = $data['max'];
                    $metas->save();
                    return \redirect('boutique')->with('success', 'Vos clients peuvent dès à présent payer par echellon sur votre boutique');
                    break;
                case 'panier_mib':
                    $boutique_slug = $data['boutique_slug'];
                    $pricing = mibPricing::where('name', 'like', '%' . $data['name'] . '%')->first();
                    $portefeuille = DB::table('admin_portefeuilles')->where('devise', 'USD')->first();
                    $arg = 0;
                    if (isset($portefeuille)) {
                        $arg = $portefeuille->montant + $pricing->price;
                    }
                    DB::table('admin_portefeuilles')->where('devise', 'USD')->update(['montant' => $arg]);

                    $boutique = Boutique::where('slug', $boutique_slug)->first();
                    $req['id_boutique'] = $boutique['id'];
                    $req['max_user'] = $pricing['max_user'];
                    $oneYearOn = date('Y-m-d H:i:s', strtotime(date("Y-m-d H:i:s", time()) . " + 365 day"));
                    $req['expired_at'] = $oneYearOn;
                    $checkMibSouscription = mibBoutiqueSouscription::where('id_boutique', $boutique['id'])->first();
                    if (isset($checkMibSouscription)) {
                        $souscription = DB::table('mib_boutique_souscriptions')->where('id', $checkMibSouscription['id'])->update(['max_user' => $req['max_user']]);
                        $souscription_id = $checkMibSouscription['id'];
                    } else {
                        $souscription = mibBoutiqueSouscription::create($req);
                        $souscription_id = $souscription->id;
                    }
                    if (isset($souscription)) {
                        mibBoutiqueSouscriptionLogs::create(
                            [
                                'id_boutique' => $boutique['id'],
                                'id_mib_pricing' => $souscription_id
                            ]
                        );
                    }
                    $subject = 'ACHAT MODULE PANIER MIB';
                    $messages = 'La boutique ' . $boutique['nom_boutique'] . ' à éffectuer un achat du module panier mib.';
                    MailController::SendGeneralUniqueMail('Mail.generale_blade', $subject, $messages, env('MAIL_ADMIN'), env('MAIL_USERNAME'));
                    return \redirect('boutique')->with('success', 'Panier Mib activer avec succès sur cette boutique. Accédez au menu pour gerer le module Panier Mib.');
                    break;
                case 'souscription_mib':
                    $year = Session::get('mib_year');
                    $boutique_slug = $data['boutique_slug'];
                    $clientData = $data['data'];
                    $pricing = CategoriesMib::where('slug', $clientData['categorie_mib_slug'])->first();
                    $boutique = Boutique::where('slug', $boutique_slug)->first();
                    $params = new \App\ParametrageMib();
                    $souscription_price = $params->getParametersByKeys('souscription', $boutique->id, $year);
                    $parainnage = $params->getParametersByKeys('parainnage', $boutique->id, $year);
                    $parrain = Session::get('prn-mib');
                    $parainner = false;
                    $user = null;
                    $solde = $souscription_price;
                    if (isset($parrain) && isset($parainnage) && $parainnage != null) {
                        $parainner = true;
                        $user_data = User::where('slug', $parrain)->first();
                        $user = $user_data['id'];
                        $pourcentage = $parainnage;
                        $arg = (($souscription_price * $pourcentage) / 100);
                        Portefeuille::createPortefeuilles(
                            $user_data['slug'],
                            $arg,
                            'PARRAINNAGE POUR SOUSCRIPTION PANIER MIB',
                            'Paiement de parraiange à la souscription panier mib à la boutique ' . $boutique['nom_boutique'],
                            'XOF',
                            ''
                        );
                        $solde = ($souscription_price - (($souscription_price * $pourcentage) / 100));
                    }
                    //add solde to boutique
                    Portefeuille::createPortefeuilles(
                        $boutique['user_slug'],
                        $solde,
                        'SOUSCRIPTION PANIER MIB',
                        'Paiement de la souscription panier mib à la boutique ' . $boutique['nom_boutique'],
                        'XOF',
                        $boutique_slug
                    );
                    $client = [
                        'slug' => Str::slug('clientMib' . time()),
                        'nom' => $clientData['nom'],
                        'prenom' => $clientData['prenom'],
                        'tel' => $clientData['tel'],
                        'adresse' => $clientData['adresse'],
                        'bonus' => true,
                        'parainer' => $parainner,
                        'parain_id' => $user,
                        'an' => date('Y'),
                        'boutique_id' => $boutique['id'],
                        'categories_mib_id' => $pricing['id'],
                        'lot' => $clientData['lot_mib_slug'],
                        'brunch' => isset($clientData['brunch']),
                        'user_id' => Auth::id()
                    ];
                    if (isset($clientData['nom_mandataire'])) $client['nom_mandataire'] = $clientData['nom_mandataire'];
                    if (isset($clientData['tel_mandataire'])) $client['tel_mandataire'] = $clientData['tel_mandataire'];
                    if (isset($clientData['adresse_mandataire'])) $client['adresse_mandataire'] = $clientData['adresse_mandataire'];
                    $client = ClientMib::create($client);
                    //create cotisation
                    CotisationMib::StaticCreate($client->id, $pricing->price);
                    return \redirect($boutique['nom_boutique'] . '/mib/index/')->with('success', 'Souscription au panier Mib validée avec succès sur la boutique  ' . $boutique['nom_boutique']);
                    break;
                case 'cotisations':
                    $cotisations = $data['cotisations'];
                    $boutique_slug = $data['boutique_slug'];
                    $cotisations = explode(',', $cotisations);
                    $cotisations = CotisationMib::whereIn('slug', $cotisations)->get();
                    $boutique = Boutique::where('slug', $boutique_slug)->first();
                    $solde = 0;
                    $client = 0;
                    foreach ($cotisations as $cotisation) {
                        if (!$cotisation->status) {
                            DB::table('cotisation_mibs')->where('id', $cotisation->id)
                                ->update(['status' => true, 'reference_paiement' => $payment_id, 'paid_at' => Carbon::now(), 'validate_by' => Auth::user()->slug]);
                            $solde = $solde + $cotisation->montant;
                            $client = $cotisation->client_mib_id;
                        }
                    }
                    //add solde to boutique
                    Portefeuille::createPortefeuilles(
                        $boutique['user_slug'],
                        $solde,
                        'PAIEMENT COTISATION PANIER MIB',
                        'Paiement de la cotisation panier mib à la boutique ' . $boutique['nom_boutique'],
                        'XOF',
                        $boutique_slug
                    );
                    //update client Mib virtual Portefeuille
                    ClientMib::createPortefeuille($client, $solde);
                    //check if user paid all cotisation
                    $cotisations = CotisationMib::where('client_mib_id', $client)->where('status', false)->count();
                    if ($cotisations <= 0) {

                        DB::table('client_mibs')->where('id', $client)->update(['end_cotisation' => true]);
                    }
                    return \redirect($boutique['nom_boutique'] . '/mib/index/')->with('success', 'Souscription au panier Mib validée avec succès sur la boutique  ' . $boutique['nom_boutique']);
                    break;
                case 'abonnement_newsletter':
                    $abonnement = NewslettersOptionAbonnement::where('slug', $data['data']['slug'])->first();
                    $user = Session::get('user')['slug'];
                    $abonnement_user = NewslettersAbonnementUser::where('user_slug', $user)->first();
                    if (isset($abonnement_user) && $abonnement_user != null) {
                        $newsletter = NewslettersAbonnementUser::findOrFail($abonnement_user['id']);
                        $newsletter->status = true;
                        $newsletter->abonnement_slug = $abonnement['slug'];
                        $newsletter->montant = $newsletter->montant + $abonnement['prix'];
                        $newsletter->diffusion = $newsletter->diffusion + $abonnement['diffusion'];
                        $newsletter->boutique = $newsletter->boutique + $abonnement['boutique'];
                        $newsletter->cumule += 1;
                        $newsletter->save();
                        $motif = 'Cumule de votre abonnement ' . $abonnement->intitule . ' à  la newsletters.';
                        $action = 'Cumule Newsletters';
                        Session::flash('success', 'Cumule abonnement ' . $abonnement->intitule . ' effectué avec succès. Vous pouvez dès à present profiter de nos forfait sur cet abonnement.');
                    } else {
                        $data['diffusion'] = $abonnement['diffusion'];
                        $data['boutique'] = $abonnement['boutique'];
                        $data['user_slug'] = Session::get('user')['slug'];
                        $data['slug'] = \Illuminate\Support\Str::slug(time() . 'user_abonnement' . time());
                        $data['corbeil'] = false;
                        $data['status'] = true;
                        $data['abonnement_slug'] = $data['data']['slug'];
                        $data['montant'] = $abonnement['prix'];
                        $newsletter = NewslettersAbonnementUser::create($data);
                        $motif = 'Paiement effectué pour abonnement ' . $abonnement['intitule'] . ' à  la newsletters.';
                        $action = 'Abonnement Newsletters';
                        Session::flash('success', 'Abonnement ' . $abonnement->intitule . ' effectué avec succès. vous pouvez dès à present profiter de nos forfait sur cet abonnement.');
                    }
                    $montant = $abonnement['prix'];
                    AbonnementPaiment::createpaiement($user, $montant, $action, $motif, 'USD');
                    Session::forget('data');
                    return redirect('user/abonnement/')->with('success', $action);
                    break;
                default:
                    break;
            }
        }
        return json_encode(['message' => 'Echec de paiement.', 'error' => true]);
    }
}
