<?php

namespace App\Http\Traits;

use App\Meta;
use App\User;
use Carbon\Carbon;
use App\Models\Message;
use App\Jobs\ProcessSmsJob;
use App\Traits\HelperTrait;
use App\Mail\SendMessageByMail;
use App\Notifications\AlertAdmin;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Notification;


trait GoogleActionTrait
{
    public function authorizationGoogleAuthV2()
    {
        $data = [
            "grant_type" => "authorization_code",
            "code" => "",
            "client_id" => "",
            "client_secret" => "",
            "redirect_uri" => "",
            "scope" => "https://www.googleapis.com/auth/firebase.messaging"
        ];
        $ch = curl_init();
        curl_setopt_array($ch, array(
            CURLOPT_URL => 'https://accounts.google.com/o/oauth2/token',
            CURLOPT_POST => true,
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_TIMEOUT => 30,
            CURLOPT_POSTFIELDS => http_build_query($data),
        ));
        $result = curl_exec($ch);
        $response = json_decode($result, true);
        Log::info("auth token");
        Log::info($response);
        if (isset($response["access_token"])) {
            return $response;
        }
        return null;
    }

    public function refreshTokenGoogleAuthV2()
    {

        $google_auth_refresh_token = Meta::where("key", "google_auth_refresh_token")->first();
        Log::info($google_auth_refresh_token);
        $data = [
            "grant_type" => "refresh_token",
            "client_id" => "",
            "client_secret" => "",
            "refresh_token" => $google_auth_refresh_token->value,
        ];
        $ch = curl_init();
        curl_setopt_array($ch, array(
            CURLOPT_URL => 'https://oauth2.googleapis.com/token',
            CURLOPT_POST => true,
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_TIMEOUT => 30,
            CURLOPT_POSTFIELDS => http_build_query($data),
        ));
        $result = curl_exec($ch);
        $response = json_decode($result, true);
        Log::info("refresh");
        Log::info($response);
        if (isset($response["error"])) {

            $auth_response = $this->authorizationGoogleAuthV2();
            if ($auth_response!=null){
                Meta::updateOrCreate(
                    [
                        'key' => "google_auth_token"
                    ],
                    [
                        "title" => "Google Auth Token",
                        "key" => "google_auth_token",
                        "value" => $auth_response["access_token"],
                    ]
                );

                Meta::updateOrCreate(
                    [
                        'key' => "google_auth_token_expire_at"
                    ],
                    [
                        "title" => "Google Auth Token Expire At",
                        "key" => "google_auth_token_expire_at",
                        "value" => Carbon::now()->addSeconds($auth_response["expires_in"]),
                    ]
                );

                Meta::updateOrCreate(
                    [
                        'key' => "google_auth_refresh_token"
                    ],
                    [
                        "title" => "Google Auth Refresh Token",
                        "key" => "google_auth_refresh_token",
                        "value" => Carbon::now()->addSeconds($auth_response["refresh_token"]),
                    ]
                );


            }

        }
        if (isset($response["access_token"])) {
            return $response;
        }

        return null;
    }

    public function getGoogleValidAuthToken()
    {

        $google_auth_token_expire_at = Meta::where("key", "google_auth_token_expire_at")->first();
        $google_auth_token_expire_at = Carbon::parse($google_auth_token_expire_at->value);
        if ($google_auth_token_expire_at->isPast()) {
            Log::info("is Past");
            $refresh = $this->refreshTokenGoogleAuthV2();
            if ($refresh != null) {
                Meta::updateOrCreate(
                    [
                        'key' => "google_auth_token"
                    ],
                    [
                        "title" => "Google Auth Token",
                        "key" => "google_auth_token",
                        "value" => $refresh["access_token"],
                    ]
                );

                Meta::updateOrCreate(
                    [
                        'key' => "google_auth_token_expire_at"
                    ],
                    [
                        "title" => "Google Auth Token Expire At",
                        "key" => "google_auth_token_expire_at",
                        "value" => Carbon::now()->addSeconds($refresh["expires_in"]),
                    ]
                );

            }
        }
        $google_auth_token = Meta::where("key", "google_auth_token")->first();
        Log::info($google_auth_token->value);
        return $google_auth_token->value;
    }


    public function sendNotificationToToken($authToken,$phoneToken,$messageData=[])
    {

        /*
         * "message" => [
                "notification" => [
                    "title" => "Breaking News back",
                    "body" => "New news story available. back"
                ],
                "data" => [
                    "story_id" => "story_12345"
                ],
                "token" => $phoneToken
            ]
         */
        $messageData["token"] = $phoneToken;
        $data = [
            "message" => $messageData
        ];

        $response = Http::withHeaders([
            "Authorization" => "Bearer " . $authToken
        ])->post('https://fcm.googleapis.com/v1/projects/transporter-atr/messages:send', $data);

        Log::info($response);
        if (isset($response["name"])) {
            return $response;
        }
        return null;
    }


    public function sendNotificationToUser($user_id,$messageData=[])
    {
        Log::info("user id ".$user_id);
        $user = User::find($user_id);
        if ($user!=null){
            if ($user->remember_token!=null){
                $authToken = $this->getGoogleValidAuthToken();
                return $this->sendNotificationToToken($authToken,
                    $user->remember_token,
                    $messageData);
            }
        }
       return null;
    }


}
