<?php

namespace App\Http\Traits;

use App\LotMib;
use App\Boutique;
use App\ClientMib;
use Carbon\Carbon;
use App\Portefeuille;
use App\CategoriesMib;
use App\CotisationMib;
use Illuminate\Support\Str;
use App\mibBoutiqueSouscription;
use Illuminate\Http\Response;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Auth;

trait MibTrait
{
    public function mibListByUser()
    {
        $user = auth()->user();
        $boutiques = Boutique::where('user_slug', $user->slug)
            ->where('corbeil', false)
            ->get();

        $datas = [];

        foreach ($boutiques as $boutique) {
            $mib_panner = mibBoutiqueSouscription::where('id_boutique', $boutique->id)
                ->with('boutique')
                ->get();

            if ($mib_panner->isNotEmpty()) {
                $datas[] = $mib_panner;
            }
        }

        return $datas;
    }

    public function clientMibIndexYear()
    {
        $user = auth()->user();


        try {
            DB::beginTransaction();
            $boutiques = Boutique::where('user_slug', $user->slug)
                ->where('corbeil', false)
                ->with('panier_mib_year')
                ->get();
            DB::commit();
            return $boutiques;
        } catch (\Throwable $th) {
            DB::rollBack();
            return response()->json(['message' => 'Erreur inattendue: ' . $th->getMessage()], Response::HTTP_UNAUTHORIZED);
        }
    }

    public function mibCategoryByBoutique($boutique_id, $an)
    {

        try {
            DB::beginTransaction();
            $datas = CategoriesMib::where('boutique_id', $boutique_id)
                ->where('an', $an)
                ->with('lots')
                ->get();
            DB::commit();
            return $datas;
        } catch (\Throwable $th) {
            DB::rollBack();
            return response()->json(['message' => 'Erreur inatendu'], Response::HTTP_UNAUTHORIZED);
        }
    }

    public function mibLotByCategory($categorie_mib)
    {

        try {
            DB::beginTransaction();
            $datas = LotMib::where('categories_mib_id', $categorie_mib)->get();
            DB::commit();
            return $datas;
        } catch (\Throwable $th) {
            DB::rollBack();
            return response()->json(['message' => 'Erreur inatendu'], Response::HTTP_UNAUTHORIZED);
        }
    }

    public function mibClient($boutique_id, $an)
    {
        $user = auth()->user();
        try {
            DB::beginTransaction();
            $datas = ClientMib::where('user_id', $user->id)
                ->where('boutique_id', $boutique_id)
                ->where('an', $an)
                ->get();
            DB::commit();
            return $datas;
        } catch (\Throwable $th) {
            DB::rollBack();
            return response()->json(['message' => 'Erreur inatendu'], Response::HTTP_UNAUTHORIZED);
        }
    }

    public function storeMibClient($validatedData)
    {
        $user = auth()->user();
        $validatedData['slug'] = Str::slug('clientMib' . time());
        $validatedData['bonus'] = true;
        $validatedData['an'] = date('Y');
        $validatedData['user_id'] = $user->id;
        $pricing = CategoriesMib::where('id', $validatedData['categories_mib_id'])->first();
        try {
            DB::beginTransaction();
            $client = ClientMib::create($validatedData);
            CotisationMib::StaticCreate($client->id, $pricing->price);
            DB::commit();
            return $client;
        } catch (\Throwable $th) {
            DB::rollBack();
            return response()->json(['message' => 'Erreur inatendu'], Response::HTTP_UNAUTHORIZED);
        }
    }

    public function showMibClient($client_id)
    {

        try {
            DB::beginTransaction();
            $client = ClientMib::where('id', $client_id)
                ->with('cotisations', 'categorieMib', 'parrain', 'user', 'lotMib', 'boutique')
                ->first();

            if ($client) {
                $cotisations = $client->cotisations;
                $nombreImpayer = $cotisations->first()->nombreImpayer($client_id, $client->boutique->id);
                $nombrePayer = $cotisations->first()->nombrePayer($client_id);
                $sumPayer = $cotisations->first()->sumPayer($client_id);
                $nombreRestePayer = $cotisations->first()->nombreRestePayer($client_id);

                $datas = [
                    'client' => $client,
                    'nombreImpayer' => $nombreImpayer,
                    'nombrePayer' => $nombrePayer,
                    'sumPayer' => $sumPayer,
                    'nombreRestePayer' => $nombreRestePayer
                ];
            } else {
                $datas = null;
            }
            DB::commit();
            return $datas;
        } catch (\Throwable $th) {
            DB::rollBack();
            return response()->json(['message' => 'Erreur inatendu'], Response::HTTP_UNAUTHORIZED);
        }
    }

    public function updateMibClient($request, $clientID)
    {
        $datas = $request->all();
        try {
            DB::beginTransaction();
            $client = ClientMib::find($clientID);
            $client->update($datas);
            DB::commit();
            return $client;
        } catch (\Throwable $th) {
            DB::rollBack();
            return response()->json(['message' => 'Erreur inatendu'], Response::HTTP_UNAUTHORIZED);
        }
    }


    public function paymentMibCotisation($data)
    {
        $cotisationsIds = $data['cotisations'];
        $data['transaction_id'] = $data['response']['transactionId'];
        $data['reference'] = $data['response']['transactionId'];

        $public_key = env('INTRAM_PUBLIC');
        $secret = env('INTRAM_SECRET');
        $private_key = env('INTRAM_PRIVATE');
        $intram = new \Intram\Intram($public_key, $private_key, $secret, env('INTRAM_SANDBOX') == true);

        $transaction_id = $data['transaction_id'];
        $verify = $intram->getTransactionStatus($transaction_id);
        $status = $verify->status;
        $total = $verify->amount;

        try {
            DB::beginTransaction();

            if ($status !== 'SUCCESS') {
                return response()->json(['message' => 'Une erreur s\'est produite. Nous ne parvenons pas à vérifier votre paiement.'], Response::HTTP_PAYMENT_REQUIRED);
            }

            $boutique_slug = $data['boutique_slug'];
            // $cotisationsData = explode(',', $cotisations);
            $cotisations = CotisationMib::whereIn('id', $cotisationsIds)->get();
            $cotisationsMontant = CotisationMib::whereIn('id', $cotisationsIds)->sum('montant');
            
            if ($cotisationsMontant > $total) {
                return response()->json(['message' => 'Une erreur s\'est produite. La somme payée ne correspond pas au total dû.'], Response::HTTP_UNAUTHORIZED);
            }
            
            if (count($cotisations) !== count($cotisationsIds)) {
                return response()->json(['message' => 'Une erreur s\'est produite.  Le nombre de paiements choisis ne correspond pas à la somme payée..'], Response::HTTP_UNAUTHORIZED);
            }
            
            $boutique = Boutique::where('slug', $boutique_slug)->first();
            $solde = 0;
            $client = 0;
            
            foreach ($cotisations as $cotisation) {
                if ($cotisation->status == 0) {
                    DB::table('cotisation_mibs')
                        ->where('id', $cotisation->id)
                        ->update([
                            'status' => true,
                            'reference_paiement' => $transaction_id,
                            'paid_at' => Carbon::now(),
                            'validate_by' => Auth::user()->slug
                        ]);

                    $solde += $cotisation->montant;
                    $client = $cotisation->client_mib_id;
                }
            }

            Portefeuille::createPortefeuilles(
                $boutique['user_slug'],
                $solde,
                'PAIEMENT COTISATION PANIER MIB',
                'Paiement de la cotisation panier mib à la boutique ' . $boutique['nom_boutique'],
                'XOF',
                $boutique_slug
            );

            ClientMib::createPortefeuille($client, $solde);

            $remainingCotisations = CotisationMib::where('client_mib_id', $client)->where('status', false)->count();

            if ($remainingCotisations <= 0) {
                DB::table('client_mibs')->where('id', $client)->update(['end_cotisation' => true]);
            }

            DB::commit();

            return $cotisations;
        } catch (\Throwable $th) {
            DB::rollBack();
            return response()->json(['message' => 'Une erreur s\'est produite. Veuillez contacter le service client si le paiement a été validé. Erreur: ' . $th->getMessage()], 500);
        }
    }
}
