<?php

namespace App;

use Carbon\Carbon;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\Log;


class InvestmentProject extends Model
{
    protected $guarded = [];
    protected $appends = ['diff_date','percent_date','date_debut_participation_cast','date_gain_cast',"total_contribution","total_distribution_gain","date_gain_old","date_participation_old","total_rsi","total_investissement","total_gain","total_remboursement","total_action_took"];

    public function files()
    {
        return $this->morphMany(File::class, 'attachmentable');
    }

    public function comments()
    {
        return $this->morphMany(Comment::class, 'attachmentable');
    }

    public function user()
    {
        return $this->belongsTo(User::class);
    }

    public function contributions()
    {
        return $this->hasMany( InvestmentProjetContribution::class);
    }

    public function getDiffDateAttribute() {
        return diffDate(now(),$this->attributes['date_fin_participation']);
    }
    public function getDateDebutParticipationCastAttribute() {

        return date("d-m-Y",strtotime($this->attributes["date_debut_participation"]));
    }
    public function getDateGainCastAttribute() {

        return date("d-m-Y",strtotime($this->attributes["date_gain"]));
    }

    public function getTotalContributionAttribute() {
        $value = 0;
        $contributions = InvestmentProjetContribution::where("investment_project_id",$this->attributes["id"])->get();
        foreach ($contributions as $item){
            $value+= $item->montant;
        }
        return $value;
    }
    public function getTotalDistributionGainAttribute() {
        $value = 0;
        $contributions = InvestmentProjetContribution::where("investment_project_id",$this->attributes["id"])->get();
        foreach ($contributions as $item){
            $value+= (intval($item->montant)+intval(($item->montant*($this->attributes["pourcentage_gain"]/100))));
        }
        return $value;
    }

    public function getPercentDateAttribute() {
        $total_days = diffDate($this->attributes['date_debut_participation'],$this->attributes['date_fin_participation']);
        $now_diff_days = diffDate(now(),$this->attributes['date_fin_participation']);
        return 100-(($now_diff_days*100)/$total_days);
    }

    public function getDateGainOldAttribute() {
        return ($this->attributes['date_gain']<=date("Y-m-d",strtotime(now()))?true:false);
    }

    public function getDateParticipationOldAttribute() {
        return ($this->attributes['date_fin_participation']<=date("Y-m-d",strtotime(now()))?true:false);
    }


public function getTotalRsiAttribute() {
    $contributions  = InvestmentProjetContribution::with("investment")
        ->where("investment_project_id",$this->attributes['id'])->get();
    $sum = 0;
    foreach ($contributions as $contribution){
        if(isset($contribution->investment)) $sum+= (intVal($contribution->investment->action_prix * $contribution->part)+intVal((($contribution->investment->action_prix * $contribution->part)*($contribution->investment->pourcentage_gain/100)) * $contribution->investment->date_gain ));
    }
    return $sum;
}

public function getTotalActionTookAttribute() {
    $contributions  = InvestmentProjetContribution::where("investment_project_id",$this->attributes['id'])->get();
    $sum = 0;
    foreach ($contributions as $contribution){
        $sum+= $contribution->part;
    }
    return $sum;
}

public function getTotalInvestissementAttribute() {
    $contributions  = InvestmentProjetContribution::where("investment_project_id",$this->attributes['id'])->count();
    return $contributions;
}

public function getTotalGainAttribute() {
    $contributions  = InvestmentProjetContribution::with("investment")
        ->where("investment_project_id",$this->attributes['id'])->get();
    $sum = 0;
    foreach ($contributions as $contribution){
        if(isset($contribution->investment))  $sum+= (intVal((($contribution->investment->action_prix * $contribution->part)*($contribution->investment->pourcentage_gain/100)) * $contribution->investment->date_gain ));
    }
    return $sum;
}


public function getTotalRemboursementAttribute() {
    $contributions  = InvestmentProjetContribution::with(["remboursements"=>function($q){
        $q->where('status','done')->get();
    }])->where("investment_project_id",$this->attributes['id'])->get();
    $sum = 0;
    foreach ($contributions as $contribution){
        foreach ($contribution->remboursements as $remboursement){
         $sum+= intVal($remboursement->montant);
        }
    }
    return $sum;
}


}
