<?php

namespace App;

use App\Http\Controllers\MailController;
use App\Http\Traits\GoogleActionTrait;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Carbon;
use Illuminate\Support\Facades\DB;

class Portefeuille extends Model
{
    use GoogleActionTrait;
    protected $fillable = ['user_slug', 'montant', 'devise', 'active', 'tentative'];

    public function user()
    {
        return $this->belongsTo('App\User', 'user_slug', 'slug');
    }
    static function createPortefeuilles($user, $montant, $action, $motif, $devise, $boutique)
    {
        $portefeuille = DB::table('portefeuilles')->where('user_slug', $user)->where('devise', $devise)->first();
        if (isset($portefeuille) && $portefeuille != null) {
            $addmontant = $portefeuille->montant + $montant;
            DB::table('portefeuilles')
                ->where('user_slug', $user)
                ->where('devise', $devise)
                ->update(['montant' => $addmontant]);
        } else {
            Portefeuille::create([
                'user_slug' => $user,
                'devise' => $devise,
                'montant' => $montant,
                'active' => true,
                'tentative' => 0
            ]);
        }
        $subject = $action;
        $user = User::where('slug', $user)->first();
        $messages = $motif;
        $send = env('MAIL_SEND');
        $send_notify = env('NOTIFY_SEND');
        if ($send == 1) {
            MailController::SendGeneralUniqueMail('Mail.generale_blade', $subject, $messages, $user['email'], env('MAIL_USERNAME'));
        }
        $auth = auth()->user();
        $message = [
            "notification" => [
                "title" => "Breaking News back",
                "body" => "New news story available. back"
            ],
        ];
        if ($send_notify == 1 && $auth->remember_token != null) {
            $this->sendNotificationToUser($auth->id, $message);
        }
        PortefeuilleUserLogs::createLogs($action, $motif, $montant, $devise, false, $boutique);
        return true;
    }
    static function incrementAdminPortefeuille($montant, $action, $motif, $devise)
    {
        // $portefeuille = DB::table('portefeuilles')->where('user_slug', $user)->where('devise', $devise)->first();
        $portefeuille_check = adminPortefeuilles::where('devise', $devise)->first();
        if ($portefeuille_check == null) {
            adminPortefeuilles::create([
                'devise' => $devise,
                'montant' => $montant,
            ]);
        } else {
            $portefeuille = adminPortefeuilles::findOrFail($portefeuille_check['id']);
            $portefeuille->montant = (float)$portefeuille->montant + (float)$montant;
            $portefeuille->save();
        }
        PortefeuilleUserLogs::createLogs($action, $motif, $montant, $devise, true, 'admin');
        return true;
    }
}
