<?php

namespace App;

use Illuminate\Database\Eloquent\Model;

class SgiUser extends Model
{
    protected $guarded = [];
    protected $appends = ["total_investir","total_gain","total_comming_gain","total_rsi","total_investissement","total_pending_investissement",'total_finished_investissement','sum_commande'];

    public function portefeuille()
    {
        return $this->hasOne(SgiPortefeuille::class,"sgi_user_id");
    }

    public function getTotalInvestirAttribute() {
        $sum  = InvestmentProjetContribution::where("sgi_user_id",$this->attributes['id'])->where("active",1)->sum("montant");
        return $sum;
    }
    public function getTotalGainAttribute() {
        $contributions  = InvestmentProjetContribution::with("investment")
            ->where("sgi_user_id",$this->attributes['id'])
            ->where("active",1)
            ->whereStatut("gain_envoyer")->get();
        $sum = 0;
        foreach ($contributions as $contribution){
            $sum+= (intVal((($contribution->investment->action_prix * $contribution->part)*($contribution->investment->pourcentage_gain/100)) * $contribution->investment->date_gain ));
        }
        return $sum;
    }


    public function getTotalCommingGainAttribute() {
        $contributions  = InvestmentProjetContribution::with("investment")
            ->where("sgi_user_id",$this->attributes['id'])
            ->where("active",1)
            ->whereStatut("investir")->get();
        $sum = 0;
        foreach ($contributions as $contribution){
          if(isset($contribution->investment))  $sum+= (intVal((($contribution->investment->action_prix * $contribution->part)*($contribution->investment->pourcentage_gain/100)) * $contribution->investment->date_gain ));
        }
        return $sum;
    }

public function getTotalRsiAttribute() {
        $contributions  = InvestmentProjetContribution::with("investment")
            ->where("sgi_user_id",$this->attributes['id'])->where("active",1)->get();
        $sum = 0;
        foreach ($contributions as $contribution){
            if(isset($contribution->investment))  $sum+= (intVal($contribution->investment->action_prix * $contribution->part)+intVal((($contribution->investment->action_prix * $contribution->part)*($contribution->investment->pourcentage_gain/100)) * $contribution->investment->date_gain ));
        }
        return $sum;
    }

public function getTotalInvestissementAttribute() {
        $contributions  = InvestmentProjetContribution::where("sgi_user_id",$this->attributes['id'])->count();
        return $contributions;
    }

public function getTotalPendingInvestissementAttribute() {
        $contributions  = InvestmentProjetContribution::where("sgi_user_id",$this->attributes['id'])
            ->whereStatut("investir")->where("active",1)->count();
        return $contributions;
    }

public function getTotalFinishedInvestissementAttribute() {
        $contributions  = InvestmentProjetContribution::where("sgi_user_id",$this->attributes['id'])
            ->whereStatut("gain_envoyer")->where("active",1)->count();
        return $contributions;
    }

    public function getSumCommandeAttribute() {
        $commandes  = Commandes::where("user_slug",$this->attributes['slug'])
            ->where("statut_shipping",1)->sum('total_price');
        return $commandes;
    }
}
