<?php

namespace App;

use Laravel\Sanctum\HasApiTokens;
use Illuminate\Notifications\Notifiable;
use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Foundation\Auth\User as Authenticatable;

class User extends Authenticatable
{
    use Notifiable, HasApiTokens;

    /**
     * The attributes that are mass assignable
     *
     * @var array
     */
    protected $fillable = [
        'slug','first_name','last_name','username', 'email','type', 'password','telephone','sexe','country',
        'cni','cnir','cniv','doc_validated','continent','country','region','city','code','country_id','token', 'remember_token',
        'validated_at','country_id','is_investissor','is_locaux_consommateurs_or_community_member','community_or_locaux_consommateur_name'
    ];

    protected $appends = ["total_investir","total_gain","total_comming_gain","total_rsi","total_investissement","total_pending_investissement",'total_finished_investissement','sum_commande'];

    /**
     * The attributes that should be hidden for arrays
     *
     * @var array
     */
    protected $hidden = [
        'password', 'remember_token',
    ];

    public function portefeuille(){
        return $this->hasMany('App\Portefeuille','user_slug','slug');
    }
    public function portefeuilleDevice($device){
        return $this->hasOne('App\Portefeuille','user_slug','slug')->where('devise',$device)->first('montant');
    }
    public function retrait(){
        return $this->hasMany('App\Retrait','user_slug');
    }
    public function retrait_admin(){
        return $this->hasMany('App\Retrait','admin_validate');
    }
public function boutique(){
        return $this->hasMany('App\Boutique','user_slug','slug');
    }

    public function meta(){

        return $this->hasMany('App\Users_meta','user_id','id');
    }

    public function canManageBlogEtcPosts()
    {
        // Enter the logic needed for your app->
        // Maybe you can just hardcode in a user id that you
        //   know is always an admin ID?

        if (       $this->id === 12
            && $this->email === "oualid@suntech->tech"
        ){

            // return true so this user CAN edit/post/delete
            // blog posts (and post any HTML/JS)

            return true;
        }

        // otherwise return false, so they have no access
        // to the admin panel (but can still view posts)

        return false;
    }

    public function code_promo(){
        return $this->hasOne(CodePromo::class,'user_id','id');
    }
    public function investment_project_allow(){
        return $this->hasOne(InvestmentProjectAllow::class,'user_id','id');
    }
    public function ask_investment_project_allow(){
        return $this->hasOne(AskInvestmentProjectAllow::class,'user_id','id');
    }


    public function portefeuille_inv()
    {
        return $this->hasOne(Portefeuille::class,"user_slug","slug");
    }

    public function getTotalInvestirAttribute() {
        $sum  = InvestmentProjetContribution::where("sgi_user_id",$this->attributes['id'])->where("active",1)->sum("montant");
        return $sum;
    }

    public function getTotalGainAttribute() {
        $contributions  = InvestmentProjetContribution::with("investment")
            ->where("sgi_user_id",$this->attributes['id'])
            ->where("active",1)
            ->whereStatut("gain_envoyer")->get();
        $sum = 0;
        foreach ($contributions as $contribution){
            $sum+= (intVal((($contribution->investment->action_prix * $contribution->part)*($contribution->investment->pourcentage_gain/100)) * $contribution->investment->date_gain ));
        }
        return $sum;
    }


    public function getTotalCommingGainAttribute() {
        $contributions  = InvestmentProjetContribution::with("investment")
            ->where("sgi_user_id",$this->attributes['id'])
            ->where("active",1)
            ->whereStatut("investir")->get();
        $sum = 0;
        foreach ($contributions as $contribution){
          if(isset($contribution->investment))  $sum+= (intVal((($contribution->investment->action_prix * $contribution->part)*($contribution->investment->pourcentage_gain/100)) * $contribution->investment->date_gain ));
        }
        return $sum;
    }

public function getTotalRsiAttribute() {
        $contributions  = InvestmentProjetContribution::with("investment")
            ->where("sgi_user_id",$this->attributes['id'])->where("active",1)->get();
        $sum = 0;
        foreach ($contributions as $contribution){
            if(isset($contribution->investment))  $sum+= (intVal($contribution->investment->action_prix * $contribution->part)+intVal((($contribution->investment->action_prix * $contribution->part)*($contribution->investment->pourcentage_gain/100)) * $contribution->investment->date_gain ));
        }
        return $sum;
    }

public function getTotalInvestissementAttribute() {
        $contributions  = InvestmentProjetContribution::where("sgi_user_id",$this->attributes['id'])->where("active",1)->count();
        return $contributions;
    }

public function getTotalPendingInvestissementAttribute() {
        $contributions  = InvestmentProjetContribution::where("sgi_user_id",$this->attributes['id'])->where("active",1)
            ->whereStatut("investir")->count();
        return $contributions;
    }

public function getTotalFinishedInvestissementAttribute() {
        $contributions  = InvestmentProjetContribution::where("sgi_user_id",$this->attributes['id'])->where("active",1)
            ->whereStatut("gain_envoyer")->count();
        return $contributions;
    }

public function getSumCommandeAttribute() {
    $commandes  = Commandes::where("user_slug",$this->attributes['slug'])
        ->where("statut_shipping",1)->whereYear('created_at','=',date('Y'))->sum('total_price');
    return $commandes;
}

}
